@@ -1372,7 +1372,13 @@ bool AI_Allocation::stackReinforce(Stack *s)
 void AI_Allocation::searchRuin(Stack *stack, Ruin *ruin)
 {
   bool stack_died = false;
-  d_owner->stackSearchRuin(stack, ruin, stack_died);
+  Reward *reward = d_owner->stackSearchRuin(stack, ruin, stack_died);
+  if (reward && ruin->isSearched() == true && stack_died == false)
+    {
+      StackReflist *stacks = new StackReflist();
+      d_owner->giveReward(stack, reward, stacks);
+      delete stacks;
+    }
   // what to do if the ruin search fails?
 }
 
@@ -1551,12 +1557,12 @@ void AI_Allocation::setParked(Stack *stack, bool force_park)
   if (force_park == false)
     {
       if (stack->hasPath() > 0 && stack->enoughMoves())
-        stack->setParked(true);
+        d_owner->stackPark(stack);
       else if (stack->canMove() == false)
-        stack->setParked(true);
+        d_owner->stackPark(stack);
     }
   else
-    stack->setParked(true);
+    d_owner->stackPark(stack);
 }
 
 bool AI_Allocation::groupStacks(Stack *stack)
