@@ -61,9 +61,6 @@ class CreateScenario : public CreateScenarioRandomize
 
         // setters
 
-        //! Set the type of the map to be created
-        void setMaptype(MapType type);
-
         //! Set the terrain distribution; differences to 100% are grass; sum may exceed 100%
         void setPercentages(int pgrass, int pwater, int pforest, int pswamp,
                             int phills, int pmountains);
@@ -149,10 +146,6 @@ class CreateScenario : public CreateScenarioRandomize
         //! Get the number of temples
         int getNoTemples() const;
 
-        //! Get the tileset to be used for the map
-        std::string getMapTiles() const;
-        
-        
         /** Creates a map
           * 
           * Calling this function will initiate the creation process itself. The
@@ -177,6 +170,7 @@ class CreateScenario : public CreateScenarioRandomize
         //! Emitted when the generator generates something
 	sigc::signal<void> progress;
 
+        static int calculateNumberOfSignposts(int width, int height, int grass);
     private:
         //! Creates the map and distributes cities, temples and ruins
         bool createMap();
@@ -191,8 +185,6 @@ class CreateScenario : public CreateScenarioRandomize
         bool setupCities(bool cities_can_produce_allies, 
 			 int number_of_armies_factor);
 
-        bool setupCities2(bool quick_start);
-
         //! Setup temple names
         bool setupTemples();
         
@@ -235,10 +227,6 @@ class CreateScenario : public CreateScenarioRandomize
 	//players do not have to pay for more armies.
 	void getCityDifficulty (int difficulty, int *number_of_armies_factor);
 
-	//! Based on the difficulty, get how much gold each player should
-	//start with.
-	void getBaseGold (int difficulty, int *base_gold);
-
 	void on_progress(double percent, std::string description);
 
         //data
