@@ -1,7 +1,7 @@
 // Copyright (C) 2000, 2001, 2002, 2003 Michael Bartl
 // Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2004, 2005, 2006 Andrea Paternesi
-// Copyright (C) 2006, 2007, 2008, 2009, 2010 Ben Asselstine
+// Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011 Ben Asselstine
 // Copyright (C) 2007 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
@@ -64,6 +64,16 @@ namespace
     }
 }
 
+bool File::nameEndsWith(std::string filename, std::string extension)
+{
+  std::string::size_type idx = filename.rfind(extension);
+  if (idx == std::string::npos)
+    return false;
+  if (idx == filename.length() - extension.length())
+    return true;
+  return false;
+}
+
 std::string File::add_ext_if_necessary(std::string file, std::string ext)
 {
   if (nameEndsWith(file, ext) == true)
@@ -268,7 +278,16 @@ std::string File::getUserArmysetDir()
 
 std::list<std::string> File::scanForFiles(std::string dir, std::string extension)
 {
-  return get_files (dir, extension);
+  std::list<std::string> files;
+  try
+    {
+      files = get_files (dir, extension);
+    }
+  catch(const Glib::Exception &ex)
+    {
+      return files;
+    }
+    return files;
 }
 
 
@@ -307,16 +326,6 @@ std::string File::getUserCitysetDir()
 }
 
 
-bool File::nameEndsWith(std::string filename, std::string extension)
-{
-  std::string::size_type idx = filename.rfind(extension);
-  if (idx == std::string::npos)
-    return false;
-  if (idx == filename.length() - extension.length())
-    return true;
-  return false;
-}
-
 void File::erase(std::string filename)
 {
   remove(filename.c_str());
