@@ -1,7 +1,7 @@
 // Copyright (C) 2000, 2001, 2002, 2003 Michael Bartl
 // Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2004, 2005, 2006 Andrea Paternesi
-// Copyright (C) 2006, 2007, 2008, 2009 Ben Asselstine
+// Copyright (C) 2006, 2007, 2008, 2009, 2010 Ben Asselstine
 // Copyright (C) 2007 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
@@ -124,13 +124,20 @@ class File
 	//! delete an empty directory from the filesystem.
 	static void erase_dir(std::string filename);
 
+        //! delete a directory and the files it contains from the filesystem.
+        static void clean_dir(std::string filename);
+
 	static std::string add_slash_if_necessary(std::string dir);
 
 	static std::string getSetConfigurationFilename(std::string dir, std::string subdir, std::string ext);
 
 	static std::string get_dirname(std::string path);
 
-	static std::list<std::string> scanFiles(std::string dir, std::string ext);
+        static std::list<std::string> scanForFiles(std::string dir, std::string extension);
+
+        static std::string add_ext_if_necessary(std::string file, std::string ext);
+
+        static char *sanify(const char *string);
 };
 
 #endif //FILE_H
