@@ -1,7 +1,7 @@
 // Copyright (C) 2003 Michael Bartl
 // Copyright (C) 2003, 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2003, 2005, 2006 Andrea Paternesi
-// Copyright (C) 2006, 2007, 2008, 2009, 2010 Ben Asselstine
+// Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011 Ben Asselstine
 // Copyright (C) 2007 Ole Laursen
 // Copyright (C) 2008 Janek Kozicki
 //
@@ -1195,9 +1195,20 @@ void GameMap::groupStacks(Stack *stack)
   getStacks(stack->getPos())->group(Playerlist::getActiveplayer(), stack);
 }
   
+void GameMap::clearStackPositions()
+{
+  Playerlist *plist = Playerlist::getInstance();
+  for (Playerlist::iterator i = plist->begin(); i != plist->end(); i++)
+    {
+      Stacklist *sl = (*i)->getStacklist();
+      for (Stacklist::iterator s = sl->begin(); s != sl->end(); s++)
+	getStacks((*s)->getPos())->clear();
+    }
+}
 void GameMap::updateStackPositions()
 {
   Playerlist *plist = Playerlist::getInstance();
+  //okay, clear them all first.
   for (Playerlist::iterator i = plist->begin(); i != plist->end(); i++)
     {
       Stacklist *sl = (*i)->getStacklist();
@@ -1237,14 +1248,16 @@ void GameMap::switchTileset(Tileset *tileset)
 
 void GameMap::reloadTileset()
 {
+  bool broken = false;
   Tileset *tileset = GameMap::getTileset();
-  tileset->reload();
+  tileset->reload(broken);
 }
 
 void GameMap::reloadShieldset()
 {
+  bool broken = false;
   Shieldset *shieldset = GameMap::getShieldset();
-  shieldset->reload();
+  shieldset->reload(broken);
   Playerlist::getInstance()->setNewColours(shieldset);
 }
 
@@ -1325,8 +1338,9 @@ guint32 GameMap::countBuildings(Maptile::Building building_type)
 
 void GameMap::reloadCityset()
 {
+  bool broken = false;
   Cityset *cityset = GameMap::getCityset();
-  cityset->reload();
+  cityset->reload(broken);
   switchCityset(cityset);
 }
 
@@ -1380,7 +1394,8 @@ void GameMap::switchArmysets(Armyset *armyset)
 
 void GameMap::reloadArmyset(Armyset *armyset)
 {
-  armyset->reload();
+  bool broken = false;
+  armyset->reload(broken);
 }
 
 bool GameMap::canPutBuilding(Maptile::Building bldg, guint32 size, Vector<int> to, bool making_islands)
@@ -2027,7 +2042,7 @@ bool GameMap::putStack(Stack *s)
 void GameMap::removeStack(Stack *s)
 {
   getStacks(s->getPos())->leaving(s);
-  Playerlist::getActiveplayer()->deleteStack(s);
+  s->getOwner()->deleteStack(s);
 }
 	
 guint32 GameMap::countArmyUnits(Vector<int> pos)
@@ -2400,3 +2415,4 @@ bool GameMap::can_plant_flag(Stack *stack)
     }
   return false;
 }
+
