@@ -1,7 +1,7 @@
 // Copyright (C) 2000, 2001, 2002, 2003 Michael Bartl
 // Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2004, 2006 Andrea Paternesi
-// Copyright (C) 2006, 2007, 2008, 2010 Ben Asselstine
+// Copyright (C) 2006, 2007, 2008, 2010, 2011 Ben Asselstine
 // Copyright (C) 2007, 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
@@ -66,6 +66,7 @@
 #include "tarhelper.h"
 #include "stacktile.h"
 #include "GraphicsCache.h"
+#include "profile.h"
 
 std::string GameScenario::d_tag = "scenario";
 using namespace std;
@@ -108,6 +109,13 @@ GameScenario::GameScenario(string savegame, bool& broken)
       File::erase(filename);
       helper.close();
       t.Close();
+      if (broken)
+        cleanup();
+    }
+  else
+    {
+      t.Close();
+      cleanup();
     }
 }
 
@@ -120,8 +128,8 @@ bool GameScenario::loadArmysets(Tar_Helper *t)
        it != armysets.end(); it++)
     {
       Armyset *armyset = Armysetlist::getInstance()->import(t, *it, broken);
-      if (armyset)
-        Armysetlist::getInstance()->getArmyset(armyset->getId())->instantiateImages();
+      if (armyset && !broken)
+        Armysetlist::getInstance()->getArmyset(armyset->getId())->instantiateImages(broken);
     }
   return !broken;
 }
@@ -136,8 +144,8 @@ bool GameScenario::loadTilesets(Tar_Helper *t)
        it != tilesets.end(); it++)
     {
       Tileset *tileset = tlist->import(t, *it, broken);
-      if (tileset)
-        tlist->getTileset(tileset->getId())->instantiateImages();
+      if (tileset && !broken)
+        tlist->getTileset(tileset->getId())->instantiateImages(broken);
     }
   return !broken;
 }
@@ -152,8 +160,8 @@ bool GameScenario::loadCitysets(Tar_Helper *t)
        it != citysets.end(); it++)
     {
       Cityset *cityset = clist->import(t, *it, broken);
-      if (cityset)
-        clist->getCityset(cityset->getId())->instantiateImages();
+      if (cityset && !broken)
+        clist->getCityset(cityset->getId())->instantiateImages(broken);
     }
   return !broken;
 }
@@ -169,7 +177,7 @@ bool GameScenario::loadShieldsets(Tar_Helper *t)
     {
       Shieldset *shieldset = slist->import(t, *it, broken);
       if (shieldset)
-        slist->getShieldset(shieldset->getId())->instantiateImages();
+        slist->getShieldset(shieldset->getId())->instantiateImages(broken);
     }
   return !broken;
 }
@@ -235,10 +243,7 @@ void GameScenario::quickStartEvenlyDivided()
 		}
 
 	      //now give the city to us.
-	      c->conquer(p);
-	      History_CityWon *item = new History_CityWon();
-	      item->fillData(c);
-	      p->addHistory(item);
+              p->conquerCity(c, NULL);
 	    }
 	}
     }
@@ -287,10 +292,7 @@ void GameScenario::quickStartAIHeadStart()
 		}
 
 	      //now give the city to us.
-	      c->conquer(p);
-	      History_CityWon *item = new History_CityWon();
-	      item->fillData(c);
-	      p->addHistory(item);
+              p->conquerCity(c, NULL);
 	    }
 	}
     }
@@ -387,16 +389,18 @@ bool GameScenario::setupRuinRewards()
 
 bool GameScenario::setupItemRewards()
 {
+  guint32 count = 0;
   debug("GameScenario::setupItemRewards")
   Itemlist *il = Itemlist::getInstance();
   Itemlist::iterator iter;
   for (iter = il->begin(); iter != il->end(); iter++)
     {
-      Item templateItem = *iter->second;
-      Item *newItem = new Item(templateItem); //instantiate it
+      const ItemProto* templateItem = (*iter).second;
+      Item *newItem = new Item(*templateItem, count); //instantiate it
       Reward_Item *newReward = new Reward_Item(newItem); //make a reward
       newReward->setName(newReward->getDescription());
       Rewardlist::getInstance()->push_back(newReward); //add it
+      count++;
     }
 
   return true;
@@ -426,9 +430,7 @@ bool GameScenario::setupCities(GameParameters::QuickStartPolicy quick_start)
       if (city)
 	{
 	  city->deFog(city->getOwner());
-	  History_CityWon *item = new History_CityWon();
-	  item->fillData(city);
-	  city->getOwner()->addHistory(item);
+          (*it)->conquerCity(city, NULL);
 	}
     }
 
@@ -494,12 +496,12 @@ void GameScenario::setupDiplomacy(bool diplomacy)
 	    if (diplomacy == false)
 	      {
 		(*pit)->proposeDiplomacy(Player::PROPOSE_WAR, *it);
-		(*pit)->declareDiplomacy(Player::AT_WAR, *it);
+		(*pit)->declareDiplomacy(Player::AT_WAR, *it, false);
 	      }
 	    else 
 	      {
 		(*pit)->proposeDiplomacy(Player::NO_PROPOSAL, *it);
-		(*pit)->declareDiplomacy(Player::AT_PEACE, *it);
+		(*pit)->declareDiplomacy(Player::AT_PEACE, *it, false);
 	      }
 	  }
       }
@@ -535,8 +537,11 @@ bool GameScenario::loadWithHelper(XML_Helper& helper)
   if (!helper.parse())
     broken = true;
 
-  GameMap::getInstance()->updateStackPositions();
-  GameMap::getInstance()->calculateBlockedAvenues();
+  if (!broken)
+    {
+      GameMap::getInstance()->updateStackPositions();
+      GameMap::getInstance()->calculateBlockedAvenues();
+    }
 
   return broken;
 }
@@ -544,26 +549,7 @@ bool GameScenario::loadWithHelper(XML_Helper& helper)
 
 GameScenario::~GameScenario()
 {
-  // GameMap is a Singleton so we need a function to delete it
-  Itemlist::deleteInstance();
-  Playerlist::deleteInstance();
-  Citylist::deleteInstance();
-  Templelist::deleteInstance();
-  Ruinlist::deleteInstance();
-  Rewardlist::deleteInstance();
-  Signpostlist::deleteInstance();
-  Portlist::deleteInstance();
-  Bridgelist::deleteInstance();
-  Roadlist::deleteInstance();
-  QuestsManager::deleteInstance();
-  VectoredUnitlist::deleteInstance();
-  GameMap::deleteInstance();
-
-  if (fl_counter)
-    {
-      delete fl_counter;
-      fl_counter = 0;
-    }
+  cleanup();
   if (Configuration::s_autosave_policy == 1 && 
       inhibit_autosave_removal == false)
     {
@@ -571,22 +557,15 @@ GameScenario::~GameScenario()
       File::erase(filename);
     }
   clean_tmp_dir();
-  GameScenarioOptions::s_round = 0;
 } 
 
-std::string GameScenario::getName(bool translate) const
+std::string GameScenario::getName() const
 {
-  if (translate)
-    return __(d_name);
-
   return d_name;
 }
 
-std::string GameScenario::getComment(bool translate) const
+std::string GameScenario::getComment() const
 {
-  if (translate)
-    return __(d_comment);
-
   return d_comment;
 }
 
@@ -943,7 +922,7 @@ GameScenario::PlayMode GameScenario::playModeFromString(const std::string str)
 	
 void GameScenario::setNewRandomId()
 {
-  d_id = String::ucompose("%1%2%3", time(NULL), getpid(), rand());
+  d_id = generate_guid();
 }
 	
 bool GameScenario::validate(std::list<std::string> &errors, std::list<std::string> &warnings)
@@ -1040,6 +1019,7 @@ bool GameScenario::validate(std::list<std::string> &errors, std::list<std::strin
 
 void GameScenario::initialize(GameParameters g)
 {
+  Playerlist::getInstance()->clearAllActions();
   setupFog(g.hidden_map);
   setupCities(g.quick_start);
   setupStacks(g.hidden_map);
@@ -1171,7 +1151,7 @@ public:
 	return false;
       };
     GameParameters game_params;
-    int d_neutral;
+    guint32 d_neutral;
 };
 GameParameters GameScenario::loadGameParameters(std::string filename, bool &broken)
 {
@@ -1249,6 +1229,7 @@ public:
 	  {
 	    helper->getData(name, "name");
 	    helper->getData(comment, "comment");
+	    helper->getData(id, "id");
 	    return true;
 	  }
 	if (tag == Player::d_tag)
@@ -1266,8 +1247,10 @@ public:
     Tar_Helper *t;
     std::string name, comment;
     guint32 player_count, city_count;
+    std::string id;
 };
-void GameScenario::loadDetails(std::string filename, bool &broken, guint32 &player_count, guint32 &city_count, std::string &name, std::string &comment)
+
+void GameScenario::loadDetails(std::string filename, bool &broken, guint32 &player_count, guint32 &city_count, std::string &name, std::string &comment, std::string &id)
 {
   DetailsLoader loader(filename, broken);
   if (broken == false)
@@ -1276,6 +1259,7 @@ void GameScenario::loadDetails(std::string filename, bool &broken, guint32 &play
       city_count = loader.city_count;
       name = loader.name;
       comment = loader.comment;
+      id = loader.id;
     }
   return;
 }
@@ -1285,3 +1269,41 @@ void GameScenario::clean_tmp_dir() const
   if (loaded_game_filename != "")
     Tar_Helper::clean_tmp_dir(loaded_game_filename);
 }
+
+std::string GameScenario::generate_guid()
+{
+  Glib::TimeVal now;
+  now.assign_current_time();
+  double n = now.as_double();
+  n -= (int) n ;
+  n *= 100000000;
+  Glib::Rand r(n);
+  char buf[40];
+  //this is a very poor guid generator.
+  snprintf (buf, sizeof (buf), "{%08X-%04X-%04X-%02X%02X-%02X%02X%02X%02X%02X%02X}", r.get_int(), rand() % 4096, r.get_int_range(0, 4096), r.get_int_range(0, 256), r.get_int_range(0, 256), r.get_int_range(0, 256) % 256, r.get_int_range(0, 256), r.get_int_range(0, 256), r.get_int_range(0, 256), r.get_int_range(0, 256), r.get_int_range(0, 256));
+
+  return std::string(buf);
+}
+
+void GameScenario::cleanup()
+{
+  Itemlist::deleteInstance();
+  Playerlist::deleteInstance();
+  Citylist::deleteInstance();
+  Templelist::deleteInstance();
+  Ruinlist::deleteInstance();
+  Rewardlist::deleteInstance();
+  Signpostlist::deleteInstance();
+  Portlist::deleteInstance();
+  Bridgelist::deleteInstance();
+  Roadlist::deleteInstance();
+  QuestsManager::deleteInstance();
+  VectoredUnitlist::deleteInstance();
+  GameMap::deleteInstance();
+  if (fl_counter)
+    {
+      delete fl_counter;
+      fl_counter = 0;
+    }
+  GameScenarioOptions::s_round = 0;
+}
