@@ -97,10 +97,10 @@ class GameScenario: public GameScenarioOptions
 	void setNewRandomId();
 
         //! Returns the name of the scenario.
-        std::string getName(bool translate = true) const;
+        std::string getName() const;
 
         //! Returns the comment for the scenario.
-        std::string getComment(bool translate = true) const;
+        std::string getComment() const;
 
         //! Returns the copyright for the scenario.
         std::string getCopyright() const {return d_copyright; };
@@ -129,7 +129,7 @@ class GameScenario: public GameScenarioOptions
           * @param filename     the full name of the save game file
           * @return true if all went well, false otherwise
           */
-        bool saveGame(std::string filename, std::string extension = "sav") const;
+        bool saveGame(std::string filename, std::string extension = SAVE_EXT) const;
         bool loadWithHelper(XML_Helper &helper);
         bool saveWithHelper(XML_Helper &helper) const;
 
@@ -147,7 +147,11 @@ class GameScenario: public GameScenarioOptions
 
 	static PlayMode loadPlayMode(std::string filename, bool &broken);
 
-	static void loadDetails(std::string filename, bool &broken, guint32 &player_count, guint32 &city_count, std::string &name, std::string &comment);
+	static void loadDetails(std::string filename, bool &broken, guint32 &player_count, guint32 &city_count, std::string &name, std::string &comment, std::string &id);
+
+        static std::string generate_guid();
+
+        static void cleanup();
 
 	void inhibitAutosaveRemoval(bool i) {inhibit_autosave_removal = i;}
     private:
