@@ -1,4 +1,4 @@
-// Copyright (C) 2008, 2009, 2010 Ben Asselstine
+// Copyright (C) 2008, 2009, 2010, 2011 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -82,10 +82,13 @@ class ItemProto: public Renamable
           PICK_UP_BAGS    = 0x00004000,
           //! Provide 2 movement points to the stack.
           ADD_2MP_STACK   = 0x00008000,
+          //! Kill all of the giant worms
+          BANISH_WORMS    = 0x00010000,
         };
 
         enum UsableItems {
-          USABLE = STEAL_GOLD | SINK_SHIPS | PICK_UP_BAGS | ADD_2MP_STACK,
+          USABLE = STEAL_GOLD | SINK_SHIPS | PICK_UP_BAGS | ADD_2MP_STACK
+            | BANISH_WORMS,
         };
 
 
@@ -99,7 +102,7 @@ class ItemProto: public Renamable
         ItemProto(const ItemProto& orig);
 
 	//! Creates a new Item Prototype from scratch.
-        ItemProto(std::string name, guint32 id);
+        ItemProto(std::string name);
 
         //! Destructor.
         virtual ~ItemProto();
@@ -119,12 +122,6 @@ class ItemProto: public Renamable
 	//! Remove a bonus from the Item.
 	void removeBonus(ItemProto::Bonus bonus);
         
-        //! Return the Id of the Item prototype.
-        guint32 getTypeId() const {return d_type_id;};
-
-	//! Set the id of the item prototype.
-	void setTypeId(guint32 id) {d_type_id = id;};
-
 	//! Return some text describing the item's special abilities.
         std::string getBonusDescription() const;
 
@@ -149,13 +146,6 @@ class ItemProto: public Renamable
         guint32 d_uses_left;
     private:
 
-	//! The Id of the Item.
-	/**
-	 * This value is a unique Id among all other game objects.
-	 * This value does not change during gameplay.
-	 */
-        guint32 d_type_id;
-
 	static std::string bonusFlagToString(ItemProto::Bonus type);
 	static ItemProto::Bonus bonusFlagFromString(std::string str);
 
