@@ -48,6 +48,7 @@
 #include "bridgelist.h"
 #include "bridge.h"
 #include "armysetlist.h"
+#include "tilesetlist.h"
 #include "army.h"
 #include "vector.h"
 #include "RoadPathCalculator.h"
@@ -285,6 +286,9 @@ bool MapGenerator::canPlaceBridge(Vector<int> pos, int type, Vector<int> &src, V
 
 void MapGenerator::makeBridges()
 {
+  std::string orig_tileset = GameMap::getInstance()->getTilesetName();
+  std::string orig_shieldset = GameMap::getInstance()->getShieldsetName();
+  std::string orig_cityset = GameMap::getInstance()->getCitysetName();
   GameMap::deleteInstance();
   Citylist::deleteInstance();
   Roadlist::deleteInstance();
@@ -301,7 +305,7 @@ void MapGenerator::makeBridges()
   for (int y = 0; y < d_height; y++)
     for (int x = 0; x < d_width; x++)
       d_terrain[y*d_width + x] = 
-	GameMap::getInstance()->getTile(x, y)->getMaptileType();
+        GameMap::getInstance()->getTile(x, y)->getType();
 
   //load up the roadlist, and stuff.
 
@@ -374,6 +378,7 @@ void MapGenerator::makeBridges()
   Citylist::deleteInstance();
   Portlist::deleteInstance();
   Bridgelist::deleteInstance();
+  GameMap::getInstance(orig_tileset, orig_shieldset, orig_cityset);
 }
 
 void MapGenerator::printMap(int j, int i)
@@ -1404,7 +1409,7 @@ bool MapGenerator::makeRoad(int src_x, int src_y, int dest_x, int dest_y)
 	{
 	  int x = (*it).x;
 	  int y = (*it).y;
-	  if (gm->getTile(x, y)->getMaptileType() == Tile::WATER &&
+	  if (gm->getTile(x, y)->getType() == Tile::WATER &&
 	      gm->getTile(x, y)->getBuilding() != Maptile::BRIDGE)
 	    {
 	      retval = false;
@@ -1465,6 +1470,7 @@ bool MapGenerator::makeAccessible(int src_x, int src_y, int dest_x, int dest_y)
 {
   bool retval = true;
   GameMap *gm = GameMap::getInstance();
+  Tileset *ts = Tilesetlist::getInstance()->getTileset(gm->getTilesetName());
   Vector<int> src(src_x, src_y);
   Vector<int> dest(dest_x, dest_y);
 
@@ -1502,8 +1508,7 @@ bool MapGenerator::makeAccessible(int src_x, int src_y, int dest_x, int dest_y)
 	  if (d_terrain[y*d_width + x] == Tile::MOUNTAIN)
 	    {
 	      d_terrain[y*d_width +x] = Tile::HILLS;
-	      Maptile *t = new Maptile(gm->getTileset(), 
-				       x, y, Tile::HILLS, NULL);
+	      Maptile *t = new Maptile(ts, x, y, Tile::HILLS, NULL);
 	      gm->setTile(x, y, t);
 	      calculateBlockedAvenue(x, y);
 	    }
@@ -1637,6 +1642,9 @@ std::vector<pair<int , Vector<int> > > MapGenerator::findBridgePlaces()
 
 void MapGenerator::makeRoads()
 {
+  std::string orig_tileset = GameMap::getInstance()->getTilesetName();
+  std::string orig_shieldset = GameMap::getInstance()->getShieldsetName();
+  std::string orig_cityset = GameMap::getInstance()->getCitysetName();
   GameMap::deleteInstance();
   Citylist::deleteInstance();
   Roadlist::deleteInstance();
@@ -1644,13 +1652,13 @@ void MapGenerator::makeRoads()
 
   GameMap::setWidth(d_width);
   GameMap::setHeight(d_height);
-  GameMap::getInstance("default", "default", cityset->getSubDir())->fill(this);
+  GameMap::getInstance("default", "default", cityset->getBaseName())->fill(this);
   Roadlist::getInstance();
   //the game map class smooths the map, so let's take what it smoothed.
   for (int y = 0; y < d_height; y++)
     for (int x = 0; x < d_width; x++)
       d_terrain[y*d_width + x] = 
-	GameMap::getInstance()->getTile(x, y)->getMaptileType();
+	GameMap::getInstance()->getTile(x, y)->getType();
 
   for (int y = 0; y < d_height; y++)
     for (int x = 0; x < d_width; x++)
@@ -1696,6 +1704,7 @@ void MapGenerator::makeRoads()
   GameMap::deleteInstance();
   Citylist::deleteInstance();
   Portlist::deleteInstance();
+  GameMap::getInstance(orig_tileset, orig_shieldset, orig_cityset);
 }
 
 void MapGenerator::rescueLoneTiles(Tile::Type FIND_THIS, Tile::Type REPLACE, bool grow)
