@@ -1,7 +1,7 @@
 // Copyright (C) 2003 Michael Bartl
 // Copyright (C) 2003, 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2005 Andrea Paternesi
-// Copyright (C) 2006, 2007, 2008, 2009 Ben Asselstine
+// Copyright (C) 2006, 2007, 2008, 2009, 2010 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #include "GameMap.h"
 #include "player.h"
 #include "FogMap.h"
+#include "GraphicsCache.h"
 
 using namespace std;
 
@@ -35,7 +36,7 @@ MapRenderer::MapRenderer(Glib::RefPtr<Gdk::Pixmap> surface)
  
 bool MapRenderer::saveAsBitmap(std::string filename)
 {
-  int tilesize = GameMap::getInstance()->getTileset()->getTileSize();
+  int tilesize = GameMap::getInstance()->getTileSize();
   int width = GameMap::getWidth() * tilesize;
   int height = GameMap::getHeight() * tilesize;
   Glib::RefPtr<Gdk::Pixmap> surf = Gdk::Pixmap::create(Glib::RefPtr<Gdk::Drawable>(d_surface), width, height, 24);
@@ -78,20 +79,37 @@ void MapRenderer::render_tile(Vector<int> draw, Vector<int> tile,
   Maptile *mtile = GameMap::getInstance()->getTile(tile);
 
   TileStyle *style = mtile->getTileStyle();
+  bool use_default_pic = false;
   if (style == NULL)
-    printf ("style for tile %d at col=%d,row=%d is null\n",
-	    mtile->getMaptileType(), tile.x, tile.y);
+    {
+      printf ("style for tile %d at col=%d,row=%d is null\n",
+              mtile->getType(), tile.x, tile.y);
+      use_default_pic = true;
+    }
   else
     {
       if (style->getImage() == false)
 	{
 	  printf ("pic for style %d for tile %d at %d,%d is null\n",
-		  style->getType(),
-		  mtile->getMaptileType(), tile.x, tile.y);
+		  style->getType(), mtile->getType(), tile.x, tile.y);
+          use_default_pic = true;
 	}
     }
 		
-  style->getImage()->blit(surface, draw.x, draw.y);
+  if (use_default_pic == true)
+    {
+      guint32 type = TileStyle::OTHER;
+      if (style)
+        type = style->getType();
+      int tilesize = GameMap::getInstance()->getTileSize();
+      PixMask *img = 
+        GraphicsCache::getInstance()->getDefaultTileStylePic(type,
+                                                             tilesize);
+      if (img)
+        img->blit(surface, draw.x, draw.y);
+    }
+  else
+    style->getImage()->blit(surface, draw.x, draw.y);
 }
 
 void MapRenderer::render(int x, int y, int tileStartX, int tileStartY,
@@ -100,12 +118,9 @@ void MapRenderer::render(int x, int y, int tileStartX, int tileStartY,
     GameMap* map = GameMap::getInstance();
     int width = GameMap::getWidth();
     int height = GameMap::getHeight();
-    int tilesize = map->getTileset()->getTileSize();
+    int tilesize = map->getTileSize();
     int drawY = y;
 
-    Gdk::Color background_color = Gdk::Color();
-    background_color.set_rgb_p(0,0,0);
-    
     for (int tileY = tileStartY; tileY < (tileStartY + rows); tileY++)
     {
         int drawX = x;
@@ -113,7 +128,7 @@ void MapRenderer::render(int x, int y, int tileStartX, int tileStartY,
         {
 	    // first check if we're out of the map bounds
 	    if (tileX >= width || tileY >= height) {
-		context->set_rgb_fg_color(background_color);
+		context->set_rgb_fg_color(FOG_COLOUR);
 		surface->draw_rectangle(context, true, drawX, drawY, 
 					tilesize, tilesize);
 	    }
