@@ -1,11 +1,11 @@
 // Copyright (C) 2003 Michael Bartl
 // Copyright (C) 2003, 2004 Ulf Lorenz
 // Copyright (C) 2005 Andrea Paternesi
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -21,8 +21,9 @@
 #ifndef MAPRENDERER_H
 #define MAPRENDERER_H
 
-#include <SDL.h>
+#include <gtkmm.h>
 #include <string>
+#include "vector.h"
 
 /** Class which cares about rendering of the map.
   * 
@@ -38,7 +39,7 @@ class MapRenderer
           * 
           * @param surface      the surface which is rendered with render()
           */
-        MapRenderer(SDL_Surface* surface);
+        MapRenderer(Glib::RefPtr<Gdk::Pixmap> surface);
         ~MapRenderer();
 
         /** Render a portion of the map.
@@ -51,7 +52,12 @@ class MapRenderer
         void render(int x, int y, int tileX, int tileY, int columns, int rows);
 
 	void render(int x, int y, int tileStartX, int tileStartY,
-		    int columns, int rows, SDL_Surface *surface);
+		    int columns, int rows, Glib::RefPtr<Gdk::Pixmap> surface,
+		    Glib::RefPtr<Gdk::GC> context);
+
+	void render_tile(Vector<int> draw, Vector<int> tile,
+			 Glib::RefPtr<Gdk::Pixmap> surface, 
+			 Glib::RefPtr<Gdk::GC> context);
 
 	//! Save the current view of map tiles as an image (bmp file).
 	bool saveViewAsBitmap(std::string filename);
@@ -60,7 +66,8 @@ class MapRenderer
 	bool saveAsBitmap(std::string filename);
     private:
         //Data
-        SDL_Surface* d_surface;
+	Glib::RefPtr<Gdk::Pixmap> d_surface;
+	Glib::RefPtr<Gdk::GC> gc;
 
 };
 
