@@ -1,5 +1,6 @@
 // Copyright (C) 2004 John Farrell
 // Copyright (C) 2005, 2007 Ulf Lorenz
+// Copyright (C) 2009, 2010 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -66,8 +67,22 @@ class MoveResult
         void setMoveAborted(bool a) {d_move_aborted = a;}
         bool getMoveAborted() const {return d_move_aborted;}
 
+        void setComputerGotQuest(bool got_quest) {d_computer_got_quest = got_quest;}
+        bool getComputerGotQuest() const {return d_computer_got_quest;}
+
+        void setComputerSearchedTemple(bool searched) {d_computer_searched_temple = searched;}
+        bool getComputerSearchedTemple() {return d_computer_searched_temple;}
+
+        void setComputerSearchedRuin(bool searched) {d_computer_searched_ruin = searched;}
+        bool getComputerSearchedRuin() {return d_computer_searched_ruin;}
+
+        void setRuinFightResult(Fight::Result result) {d_ruinfightResult = result;}
+        Fight::Result getRuinFightResult() const {return d_ruinfightResult;}
+
+        void setComputerPickedUpBag(bool picked_up) {d_computer_picked_up_bag = picked_up;}
+        bool getComputerPickedUpBag() {return d_computer_picked_up_bag;}
 	//! fill up d_out_of_moves, d_reached_end, and d_stepCount
-	void fillData(Stack *s, int stepCount);
+	void fillData(Stack *s, int stepCount, bool searched_temple, bool searched_ruin, bool got_quest, bool picked_up);
 
     private:
         bool d_result;
@@ -81,6 +96,11 @@ class MoveResult
         bool d_too_large_stack_in_the_way;
         Fight::Result d_fightResult;
         bool d_move_aborted;
+        bool d_computer_searched_temple;
+        bool d_computer_searched_ruin;
+        bool d_computer_got_quest;
+        Fight::Result d_ruinfightResult;
+        bool d_computer_picked_up_bag;
 };
 
 #endif // MOVE_RESULT_H
