@@ -1,4 +1,4 @@
-// Copyright (C) 2009 Ben Asselstine
+// Copyright (C) 2009, 2010 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -184,7 +184,7 @@ bool PathCalculator::calcFinalMoves(Vector<int> pos, Vector<int> next)
     return false;
   //flyers can't go through the void
   if (flying && is_blocked_dir &&
-      GameMap::getInstance()->getTile(next)->getMaptileType() == Tile::VOID)
+      GameMap::getInstance()->getTile(next)->getType() == Tile::VOID)
     return false;
 
   int dsxy = nodes[next.toIndex()].moves;
@@ -247,7 +247,7 @@ bool PathCalculator::calcMoves(Vector<int> pos, Vector<int> next)
     return false;
   //flyers can't go through the void
   if (flying && is_blocked_dir &&
-      GameMap::getInstance()->getTile(next)->getMaptileType() == Tile::VOID)
+      GameMap::getInstance()->getTile(next)->getType() == Tile::VOID)
     return false;
 
   int dsxy = nodes[next.toIndex()].moves;
@@ -366,7 +366,8 @@ int PathCalculator::pointsToMoveTo(Vector<int> pos, Vector<int> next) const
   if (enemy_city_avoidance >= 1)
     {
       //We will still try to avoid enemy cities a little.
-      if (GameMap::getEnemyCity(pos))
+      City *enemy = GameMap::getEnemyCity(pos);
+      if (enemy && enemy->isBurnt() == false)
 	moves += enemy_city_avoidance;
     }
   if (enemy_stack_avoidance >= 1)
@@ -377,7 +378,7 @@ int PathCalculator::pointsToMoveTo(Vector<int> pos, Vector<int> next) const
     }
 
   // does everything in the stack have a bonus to move onto this square?
-  if (tile->getMaptileType() & d_bonus && moves != 1)
+  if (tile->getType() & d_bonus && moves != 1)
     return 2;
 
   return moves;
@@ -458,8 +459,7 @@ bool PathCalculator::canMoveThere(Vector<int> dest)
 {
   Vector<int> pos = stack->getPos();
   if (flying && isBlockedDir(pos, dest) &&
-      GameMap::getInstance()->getTile(dest)->getMaptileType()
-      == Tile::VOID)
+      GameMap::getInstance()->getTile(dest)->getType() == Tile::VOID)
     return false;
   if (isBlocked(pos))
     {
@@ -476,9 +476,8 @@ bool PathCalculator::canMoveThere(Vector<int> dest)
 int PathCalculator::calculate(Vector<int> dest, bool zigzag)
 {
   int retval = 0;
-  guint32 moves = 0;
-  guint32 turns = 0;
-  Path *p = calculate(dest, moves, turns, zigzag);
+  guint32 moves = 0, turns = 0, left = 0;
+  Path *p = calculate(dest, moves, turns, left, zigzag);
   if (p->size() == 0)
     retval = -1;
   delete p;
@@ -487,7 +486,7 @@ int PathCalculator::calculate(Vector<int> dest, bool zigzag)
   return retval;
 }
 
-Path* PathCalculator::calculate(Vector<int> dest, guint32 &moves, guint32 &turns, bool zigzag)
+Path* PathCalculator::calculate(Vector<int> dest, guint32 &moves, guint32 &turns, guint32 &left, bool zigzag)
 {
   Path *path = new Path();
   int width = GameMap::getWidth();
@@ -598,6 +597,7 @@ Path* PathCalculator::calculate(Vector<int> dest, guint32 &moves, guint32 &turns
 
   moves = nodes[idx].moves;
   turns = nodes[idx].turns;
+  left = nodes[idx].moves_left;
 
   //change dest back
   nodes[idx] = orig_dest;
@@ -651,7 +651,7 @@ bool PathCalculator::isReachable(Vector<int> pos)
   return nodes[pos.toIndex()].moves >= 0;
 }
 
-Path *PathCalculator::calculateToCity (City *c, guint32 &moves, guint32 &turns, bool zigzag)
+Path *PathCalculator::calculateToCity (City *c, guint32 &moves, guint32 &turns, guint32 &left, bool zigzag)
 {
   int min_dist = -1;
   Vector<int> shortest = c->getPos();
@@ -676,7 +676,7 @@ Path *PathCalculator::calculateToCity (City *c, guint32 &moves, guint32 &turns,
 	      }
 	  }
       }
-  Path *p = calculate(shortest, moves, turns, zigzag);
+  Path *p = calculate(shortest, moves, turns, left, zigzag);
   if (p->size() > 0)
     return p;
   delete p;
@@ -692,7 +692,8 @@ Path *PathCalculator::calculateToCity (City *c, guint32 &moves, guint32 &turns,
 	    if (other_stack && GameMap::canJoin(stack, other_stack) == false)
 	      continue;
 	  }
-	p = calculate(c->getPos() + Vector<int>(i,j), moves, turns, zigzag);
+	p = calculate(c->getPos() + Vector<int>(i,j), moves, turns, left,
+                      zigzag);
 	int dist = (int) moves;
 	delete p;
 	if (dist > 0)
@@ -704,7 +705,7 @@ Path *PathCalculator::calculateToCity (City *c, guint32 &moves, guint32 &turns,
 	      }
 	  }
       }
-  return calculate(shortest, moves, turns, zigzag);
+  return calculate(shortest, moves, turns, left, zigzag);
 }
 
 std::list<Vector<int> > PathCalculator::getReachablePositions(int mp)
