@@ -33,108 +33,107 @@ using namespace std;
 //#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl<<flush;}
 #define debug(x)
 
-//=======================================================================
 QuestCitySack::QuestCitySack (QuestsManager& mgr, guint32 hero) 
-    : Quest(mgr, hero, Quest::CITYSACK)
+  : Quest(mgr, hero, Quest::CITYSACK)
 {
-    // find us a victim
-    City* c = chooseToSack(getHero()->getOwner());
-    assert(c);      // should never fail because isFeasible is checked first
+  // find us a victim
+  City* c = chooseToSack(getHero()->getOwner());
+  assert(c);      // should never fail because isFeasible is checked first
 
-    d_city = c->getId();
-    d_targets.push_back(c->getPos());
-    debug("city_id = " << d_city);
-    initDescription();
+  d_city = c->getId();
+  d_targets.push_back(c->getPos());
+  debug("city_id = " << d_city);
+  initDescription();
 }
-//=======================================================================
+
 QuestCitySack::QuestCitySack (QuestsManager& q_mgr, XML_Helper* helper) 
-     : Quest(q_mgr, helper)
+  : Quest(q_mgr, helper)
 {
-    // let us stay in touch with the world...
-    helper->getData(d_city, "city");
-    d_targets.push_back(getCity()->getPos());
-    initDescription();
+  // let us stay in touch with the world...
+  helper->getData(d_city, "city");
+  d_targets.push_back(getCity()->getPos());
+  initDescription();
 }
-//=======================================================================
+
 QuestCitySack::QuestCitySack (QuestsManager& mgr, guint32 hero, guint32 target) 
-    : Quest(mgr, hero, Quest::CITYSACK)
+  : Quest(mgr, hero, Quest::CITYSACK)
 {
-    d_city = target;
-    d_targets.push_back(getCity()->getPos());
-    initDescription();
+  d_city = target;
+  d_targets.push_back(getCity()->getPos());
+  initDescription();
 }
-//=======================================================================
+
 bool QuestCitySack::isFeasible(guint32 heroId)
 {
   if (QuestCitySack::chooseToSack(getHeroById(heroId)->getOwner()))
     return true;
   return false;
 }
-//=======================================================================
+
 bool QuestCitySack::save(XML_Helper* helper) const
 {
-    bool retval = true;
+  bool retval = true;
 
-    retval &= helper->openTag(Quest::d_tag);
-    retval &= Quest::save(helper);
-    retval &= helper->saveData("city", d_city);
-    retval &= helper->closeTag();
+  retval &= helper->openTag(Quest::d_tag);
+  retval &= Quest::save(helper);
+  retval &= helper->saveData("city", d_city);
+  retval &= helper->closeTag();
 
-    return retval;
+  return retval;
 }
-//=======================================================================
+
 std::string QuestCitySack::getProgress() const
 {
-    return _("You aren't afraid of doing it, are you?");
+  return _("You aren't afraid of doing it, are you?");
 }
-//=======================================================================
+
 void QuestCitySack::getSuccessMsg(std::queue<std::string>& msgs) const
 {
-    msgs.push(_("The priests thank you for sacking this evil place."));
+  msgs.push(_("The priests thank you for sacking this evil place."));
 }
-//=======================================================================
+
 void QuestCitySack::getExpiredMsg(std::queue<std::string>& msgs) const
 {
-    const City* c = getCity();
-    msgs.push(String::ucompose(_("The sacking of \"%1\" could not be accomplished."), 
-			       c->getName()));
+  const City* c = getCity();
+  msgs.push(String::ucompose(_("The sacking of \"%1\" could not be accomplished."), 
+			     c->getName()));
 }
-//=======================================================================
+
 City* QuestCitySack::getCity() const
 {
-    Citylist* cl = Citylist::getInstance();
-    for (Citylist::iterator it = cl->begin(); it != cl->end(); it++)
-        if ((*it)->getId() == d_city)
-            return (*it);
+  Citylist* cl = Citylist::getInstance();
+  for (Citylist::iterator it = cl->begin(); it != cl->end(); it++)
+    if ((*it)->getId() == d_city)
+      return (*it);
 
-    return 0;
+  return 0;
 }
-//=======================================================================
+
 void QuestCitySack::initDescription()
 {
-    const City* c = getCity();
-    d_description = String::ucompose (_("You must take over and sack the city of \"%1\"."), c->getName());
+  const City* c = getCity();
+  d_description = String::ucompose (_("You must take over and sack the city of \"%1\"."), c->getName());
 }
-//=======================================================================
+
 City * QuestCitySack::chooseToSack(Player *p)
 {
-    std::vector<City*> cities;
+  std::vector<City*> cities;
 
-    // Collect all cities
-    Citylist* cl = Citylist::getInstance();
-    for (Citylist::iterator it = cl->begin(); it != cl->end(); ++it)
-        if (!(*it)->isBurnt() && (*it)->getOwner() != p && 
-            (*it)->getNoOfProductionBases() > 1 &&
-	    (*it)->getOwner() != Playerlist::getInstance()->getNeutral())
-            cities.push_back((*it));
+  // Collect all cities
+  Citylist* cl = Citylist::getInstance();
+  for (Citylist::iterator it = cl->begin(); it != cl->end(); ++it)
+    if (!(*it)->isBurnt() && (*it)->getOwner() != p && 
+	(*it)->getNoOfProductionBases() > 1 &&
+	(*it)->getOwner() != Playerlist::getInstance()->getNeutral())
+      cities.push_back((*it));
 
-    // Find a suitable city for us to sack
-    if (cities.empty())
-        return 0;
+  // Find a suitable city for us to sack
+  if (cities.empty())
+    return 0;
 
-    return cities[rand() % cities.size()];
+  return cities[rand() % cities.size()];
 }
-	 
+
 void QuestCitySack::armyDied(Army *a, bool heroIsCulprit)
 {
   ;
@@ -144,8 +143,14 @@ void QuestCitySack::armyDied(Army *a, bool heroIsCulprit)
 void QuestCitySack::cityAction(City *c, CityDefeatedAction action, 
 			       bool heroIsCulprit, int gold)
 {
-  if (!isActive())
+  if (isPendingDeletion())
     return;
+  Hero *h = getHero();
+  if (!h || h->getHP() <= 0)
+    {
+      deactivate();
+      return;
+    }
   if (!c)
     return;
   if (c->getId() != d_city)
