@@ -1,4 +1,4 @@
-// Copyright (C) 2008, 2009 Ben Asselstine
+// Copyright (C) 2008, 2009, 2010 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -114,6 +114,10 @@ oeeeeeee
 	//! Default constructor.
 	SmallTile();
 
+
+        //! Copying constructor.
+        SmallTile(const SmallTile &orig);
+
         //! Loading constructor.
 	/**
 	 * Loads the tileset.tile XML entities in the tileset configuration 
