@@ -1,7 +1,7 @@
 // Copyright (C) 2004 John Farrell
 // Copyright (C) 2004, 2005 Ulf Lorenz
 // Copyright (C) 2005 Andrea Paternesi
-// Copyright (C) 2007, 2009 Ben Asselstine
+// Copyright (C) 2007, 2009, 2010 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -40,8 +40,25 @@ Threatlist::~Threatlist()
 {
 }
 
+bool Threatlist::compareValue(const Threat *lhs, const Threat *rhs)  
+{
+  return lhs->getValue() > rhs->getValue(); 
+}
 void Threatlist::sortByValue()
 {
+  sort(compareValue);
+  /*
+  int count = 0;
+  for (Threatlist::iterator it = begin(); it != end(); it++)
+    {
+      if ((*it)->isCity())
+        {
+      printf ("%d. %f (%f)\n", count, (*it)->getValue(), (*it)->getStrength());
+              count++;
+                }
+    }
+  */
+  /*
     // bubble sort is the easiest thing I remember
     bool sorted = false;
 
@@ -67,6 +84,7 @@ void Threatlist::sortByValue()
                 it = insert(nextit, tmp);
             }
     }
+    */
 }
 
 void Threatlist::sortByDistance(Vector<int> pos)
@@ -166,13 +184,13 @@ void Threatlist::findThreats(AICityInfo *info) const
         debug("moves to " << threat->toString() << " is " << movesToThreat)
 
         //Ignore threats too far away
-        if (movesToThreat > 3.0)
+        if (movesToThreat > 10.0)
             continue;
 
-        if (movesToThreat == 0.0)
-            movesToThreat++;
+        if (movesToThreat <= 0.0)
+            movesToThreat = 1.0;
 
-        float strength = threat->strength();
+        float strength = threat->getStrength();
         if (strength == 0.0)
             continue;
 
@@ -246,4 +264,12 @@ bool Threatlist::flRemove(Threat* object)
     return false;
 }
 
+void Threatlist::changeOwnership(Player *old_owner, Player *new_owner)
+{
+  for (iterator it = begin(); it != end(); it++)
+    {
+      (*it)->changeOwnership(old_owner, new_owner);
+    }
+}
+
 // End of file
