@@ -5,7 +5,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -34,7 +34,7 @@ UniquelyIdentified::UniquelyIdentified(const UniquelyIdentified& obj)
 {
 }
 
-UniquelyIdentified::UniquelyIdentified(Uint32 id)
+UniquelyIdentified::UniquelyIdentified(guint32 id)
 {
     d_id = id;
     d_unique = false;
