@@ -1,6 +1,6 @@
 // Copyright (C) 2002, 2003, 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2003 Michael Bartl
-// Copyright (C) 2007, 2008, 2010 Ben Asselstine
+// Copyright (C) 2007, 2008, 2010, 2011 Ben Asselstine
 // Copyright (C) 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
@@ -43,6 +43,7 @@
 #include "armyprodbase.h"
 #include "heroproto.h"
 #include "Item.h"
+#include "stacklist.h" //remove me
 
 std::string Action::d_tag = "action";
 using namespace std;
@@ -176,6 +177,28 @@ Action* Action::handle_load(XML_Helper* helper)
           return (new Action_Loot(helper));
       case USE_ITEM:
           return (new Action_UseItem(helper));
+      case STACK_ORDER:
+          return (new Action_ReorderArmies(helper));
+      case STACKS_RESET:
+          return (new Action_ResetStacks(helper));
+      case RUINS_RESET:
+          return (new Action_ResetRuins(helper));
+      case COLLECT_TAXES_AND_PAY_UPKEEP:
+          return (new Action_CollectTaxesAndPayUpkeep(helper));
+      case KILL_PLAYER:
+          return (new Action_Kill(helper));
+      case STACK_DEFEND:
+          return (new Action_DefendStack(helper));
+      case STACK_UNDEFEND:
+          return (new Action_UndefendStack(helper));
+      case STACK_PARK:
+          return (new Action_ParkStack(helper));
+      case STACK_UNPARK:
+          return (new Action_UnparkStack(helper));
+      case STACK_SELECT:
+          return (new Action_SelectStack(helper));
+      case STACK_DESELECT:
+          return (new Action_DeselectStack(helper));
     }
 
   return 0;
@@ -284,6 +307,42 @@ Action* Action::copy(const Action* a)
             return 
               (new Action_UseItem
                 (*dynamic_cast<const Action_UseItem*>(a)));
+        case STACK_ORDER:
+            return 
+              (new Action_ReorderArmies
+                (*dynamic_cast<const Action_ReorderArmies*>(a)));
+        case STACKS_RESET:
+            return 
+              (new Action_ResetStacks
+                (*dynamic_cast<const Action_ResetStacks*>(a)));
+        case RUINS_RESET:
+            return 
+              (new Action_ResetRuins
+                (*dynamic_cast<const Action_ResetRuins*>(a)));
+        case COLLECT_TAXES_AND_PAY_UPKEEP:
+            return 
+              (new Action_CollectTaxesAndPayUpkeep
+                (*dynamic_cast<const Action_CollectTaxesAndPayUpkeep*>(a)));
+        case KILL_PLAYER:
+            return (new Action_Kill (*dynamic_cast<const Action_Kill*>(a)));
+        case STACK_DEFEND:
+            return (new Action_DefendStack
+                    (*dynamic_cast<const Action_DefendStack*>(a)));
+        case STACK_UNDEFEND:
+            return (new Action_UndefendStack
+                    (*dynamic_cast<const Action_UndefendStack*>(a)));
+        case STACK_PARK:
+            return (new Action_ParkStack
+                    (*dynamic_cast<const Action_ParkStack*>(a)));
+        case STACK_UNPARK:
+            return (new Action_UnparkStack
+                    (*dynamic_cast<const Action_UnparkStack*>(a)));
+        case STACK_SELECT:
+            return (new Action_SelectStack
+                    (*dynamic_cast<const Action_SelectStack*>(a)));
+        case STACK_DESELECT:
+            return (new Action_DeselectStack
+                    (*dynamic_cast<const Action_DeselectStack*>(a)));
     }
 
     return 0;
@@ -466,21 +525,31 @@ Action_Fight::Action_Fight(XML_Helper* helper)
 {
     std::string s;
     std::istringstream si;
-    guint32 ui;
+    int ival = -1;
 
     helper->registerTag(Item::d_tag, sigc::mem_fun(this, &Action_Fight::loadItem));
 
     // get attacking and defending stacks
     helper->getData(s, "attackers");
     si.str(s);
-    while (si >> ui)
-        d_attackers.push_back(ui);
+    while (si.eof() == false)
+      {
+        ival = -1;
+        si >> ival;
+        if (ival != -1)
+          d_attackers.push_back((guint32)ival);
+      }
     si.clear();
 
     helper->getData(s, "defenders");
     si.str(s);
-    while (si >> ui)
-        d_defenders.push_back(ui);
+    while (si.eof() == false)
+      {
+        ival = -1;
+        si >> ival;
+        if (ival != -1)
+          d_defenders.push_back((guint32) ival);
+      }
 }
 
 Action_Fight::~Action_Fight()
@@ -551,6 +620,53 @@ bool Action_Fight::fillData(const Fight* f)
     return true;
 }
 
+bool Action_Fight::stack_ids_to_stacks(std::list<guint32> stack_ids, std::list<Stack*> &stacks, guint32 &stack_id) const
+{
+  for (std::list<guint32>::iterator i = stack_ids.begin(); i != stack_ids.end(); i++)
+    {
+      bool found = false;
+      for (Playerlist::iterator j = Playerlist::getInstance()->begin(), jend = Playerlist::getInstance()->end();
+           j != jend; ++j) 
+        {
+          Stack *s = (*j)->getStacklist()->getStackById(*i);
+          if (s)
+            {
+              found = true;
+              stacks.push_back(s);
+              break;
+            }
+        }
+      if (found == false)
+        {
+          stack_id = *i;
+          return false;
+        }
+    }
+  return true;
+}
+
+bool Action_Fight::is_army_id_in_stacks(guint32 id, std::list<guint32> stack_ids) const
+{
+  std::list<Stack*> stacks;
+  guint32 stack_id = 0;
+  bool success = stack_ids_to_stacks(stack_ids, stacks, stack_id);
+  if (!success)
+    return false;
+  bool found = false;
+  for (std::list<Stack*>::iterator i = stacks.begin(); i != stacks.end(); i++)
+    {
+      if ((*i)->getArmyById(id))
+        {
+          found = true;
+          break;
+        }
+    }
+  if (found)
+    return true;
+  else
+    return false;
+}
+
 bool Action_Fight::loadItem(std::string tag, XML_Helper* helper)
 {
     FightItem item;
@@ -1079,6 +1195,7 @@ bool Action_Production::fillData(City* c, int slot)
 Action_Reward::Action_Reward()
     :Action(Action::REWARD)
 {
+  d_reward = NULL;
 }
 
 bool Action_Reward::load(std::string tag, XML_Helper *helper)
@@ -1111,13 +1228,17 @@ Action_Reward::Action_Reward (const Action_Reward &action)
 : Action(action), d_stack(action.d_stack)
 {
   const Reward *reward = action.d_reward;
-  d_reward = Reward::copy(reward);
+  if (reward)
+    d_reward = Reward::copy(reward);
+  else
+    d_reward = NULL;
 }
 
 Action_Reward::Action_Reward(XML_Helper* helper)
 :Action(helper)
 {
   helper->getData(d_stack, "stack");
+  d_reward = NULL;
   helper->registerTag(Reward::d_tag, sigc::mem_fun(this, &Action_Reward::load));
 }
 
@@ -1738,13 +1859,18 @@ bool Action_Plant::fillData(Hero *hero, Item *item)
 Action_Produce::Action_Produce()
 :Action(Action::PRODUCE_UNIT)
 {
+  d_army = NULL;
 }
 
 Action_Produce::Action_Produce(const Action_Produce &action)
 : Action(action), d_city(action.d_city), d_vectored(action.d_vectored),
-    d_dest(action.d_dest), d_army_id(action.d_army_id)
+    d_dest(action.d_dest), d_army_id(action.d_army_id), 
+    d_stack_id(action.d_stack_id)
 {
-  d_army = new ArmyProdBase (*action.d_army);
+  if (action.d_army)
+    d_army = new ArmyProdBase (*action.d_army);
+  else
+    d_army = NULL;
 }
 
 Action_Produce::Action_Produce(XML_Helper* helper)
@@ -1755,6 +1881,8 @@ Action_Produce::Action_Produce(XML_Helper* helper)
   helper->getData(d_dest.x, "dest_x");
   helper->getData(d_dest.y, "dest_y");
   helper->getData(d_army_id, "army_id");
+  helper->getData(d_stack_id, "stack_id");
+  d_army = NULL;
   helper->registerTag(ArmyProdBase::d_tag, sigc::mem_fun(this, &Action_Produce::load));
 }
 
@@ -1782,7 +1910,7 @@ std::string Action_Produce::dump() const
   if (d_vectored)
     s <<" but it is vectored to another city at " << d_dest.x << "," << d_dest.y;
   else
-    s <<" at position " << d_dest.x << "," << d_dest.y;
+    s <<" at position " << d_dest.x << "," << d_dest.y << " in stack " << d_stack_id ;
   s <<"\n";
 
   return s.str();
@@ -1797,18 +1925,20 @@ bool Action_Produce::doSave(XML_Helper* helper) const
   retval &= helper->saveData("dest_x", d_dest.x);
   retval &= helper->saveData("dest_y", d_dest.y);
   retval &= helper->saveData("army_id", d_army_id);
+  retval &= helper->saveData("stack_id", d_stack_id);
   retval &= d_army->save(helper);
 
   return retval;
 }
 
-bool Action_Produce::fillData(const ArmyProdBase *army, City *city, bool vectored, Vector<int> pos, guint32 army_id)
+bool Action_Produce::fillData(const ArmyProdBase *army, City *city, bool vectored, Vector<int> pos, guint32 army_id, guint32 stack_id)
 {
   d_army = new ArmyProdBase(*army);
   d_city = city->getId();
   d_vectored = vectored;
   d_dest = pos;
   d_army_id = army_id;
+  d_stack_id = stack_id;
   return true;
 }
 
@@ -1844,6 +1974,7 @@ Action_ProduceVectored::Action_ProduceVectored(XML_Helper* helper)
   d_src.x = i;
   helper->getData(i, "src_y");
   d_src.y = i;
+  d_army = NULL;
   helper->registerTag(ArmyProdBase::d_tag, sigc::mem_fun(this, &Action_ProduceVectored::load));
 }
 
@@ -2109,12 +2240,12 @@ bool Action_EndTurn::doSave(XML_Helper* helper) const
 //Action_ConquerCity
 
 Action_ConquerCity::Action_ConquerCity()
-  :Action(Action::CITY_CONQUER), d_city(0), d_stack(0)
+  :Action(Action::CITY_CONQUER), d_city(0)
 {
 }
 
 Action_ConquerCity::Action_ConquerCity(const Action_ConquerCity &action)
-: Action(action), d_city(action.d_city), d_stack(action.d_stack)
+: Action(action), d_city(action.d_city)
 {
 }
 
@@ -2122,7 +2253,6 @@ Action_ConquerCity::Action_ConquerCity(XML_Helper* helper)
   :Action(helper)
 {
     helper->getData(d_city, "city");
-    helper->getData(d_stack, "stack");
 }
 
 Action_ConquerCity::~Action_ConquerCity()
@@ -2133,7 +2263,7 @@ std::string Action_ConquerCity::dump() const
 {
     std::stringstream s;
 
-    s <<"City " <<d_city <<" occupied by " << d_stack << "\n";
+    s <<"City " <<d_city <<" occupied." << std::endl;
 
     return s.str();
 }
@@ -2143,15 +2273,13 @@ bool Action_ConquerCity::doSave(XML_Helper* helper) const
     bool retval = true;
 
     retval &= helper->saveData("city", d_city);
-    retval &= helper->saveData("stack", d_stack);
 
     return retval;
 }
 
-bool Action_ConquerCity::fillData(City* c, Stack *s)
+bool Action_ConquerCity::fillData(City* c)
 {
     d_city = c->getId();
-    d_stack = s->getId();
     return true;
 }
 
@@ -2481,6 +2609,524 @@ bool Action_UseItem::fillData(Hero *hero, Item *item, Player *victim)
   return true;
 }
 
+//-----------------------------------------------------------------------------
+// Action_ReorderArmies
+
+Action_ReorderArmies::Action_ReorderArmies()
+:Action(Action::STACK_ORDER), d_stack_id(0), d_player_id(MAX_PLAYERS + 1)
+{
+}
+
+Action_ReorderArmies::Action_ReorderArmies(const Action_ReorderArmies &action)
+: Action(action), d_stack_id(action.d_stack_id), 
+    d_player_id(action.d_player_id), d_army_ids(action.d_army_ids)
+{
+}
+
+Action_ReorderArmies::Action_ReorderArmies(XML_Helper* helper)
+:Action(helper)
+{
+
+  helper->getData(d_stack_id, "stack_id");
+  helper->getData(d_player_id, "player_id");
+  std::string armies;
+  helper->getData(armies, "armies");
+  std::stringstream sarmies;
+  sarmies.str(armies);
+  int ival = -1;
+  while (sarmies.eof() == false)
+    {
+      ival = -1;
+      sarmies >> ival;
+      if (ival != -1)
+        d_army_ids.push_back((guint32)ival);
+    }
+}
+
+Action_ReorderArmies::~Action_ReorderArmies()
+{
+}
+
+std::string Action_ReorderArmies::dump() const
+{
+  std::stringstream ss;
+
+  ss <<"Stack " <<d_stack_id <<" belonging to " << d_player_id << " has new order: ";
+ 
+  for (std::list<guint32>::const_iterator i = d_army_ids.begin(); 
+       i != d_army_ids.end(); i++)
+    ss << (*i) << " ";
+  ss << "\n";
+
+  return ss.str();
+}
+
+bool Action_ReorderArmies::doSave(XML_Helper* helper) const
+{
+  bool retval = true;
+
+  retval &= helper->saveData("stack_id", d_stack_id);
+  retval &= helper->saveData("player_id", d_player_id);
+
+  std::stringstream armies;
+  std::list<guint32>::const_iterator tit = d_army_ids.begin();
+  std::list<guint32>::const_iterator tend = d_army_ids.end();
+  for(;tit != tend;++tit)
+    armies << (*tit) << " ";
+  retval &= helper->saveData("armies", armies.str());
+  return retval;
+}
+
+bool Action_ReorderArmies::fillData(Stack *s)
+{
+  d_stack_id = s->getId();
+  d_player_id = s->getOwner()->getId();
+  for (Stack::iterator i = s->begin(); i != s->end(); i++)
+    d_army_ids.push_back((*i)->getId());
+
+  return true;
+}
+
+//-----------------------------------------------------------------------------
+// Action_ResetStacks
+
+Action_ResetStacks::Action_ResetStacks()
+:Action(Action::STACKS_RESET), d_player_id(0)
+{
+}
+
+Action_ResetStacks::Action_ResetStacks(const Action_ResetStacks &action)
+: Action(action), d_player_id(action.d_player_id)
+{
+}
+
+Action_ResetStacks::Action_ResetStacks(XML_Helper* helper)
+:Action(helper)
+{
+  helper->getData(d_player_id, "player_id");
+}
+
+Action_ResetStacks::~Action_ResetStacks()
+{
+}
+
+std::string Action_ResetStacks::dump() const
+{
+  std::stringstream ss;
+
+  ss <<"Stacks for " <<d_player_id <<" are being recharged.";
+  ss << "\n";
+
+  return ss.str();
+}
+
+bool Action_ResetStacks::doSave(XML_Helper* helper) const
+{
+  bool retval = true;
+
+  retval &= helper->saveData("player_id", d_player_id);
+  return retval;
+}
+
+bool Action_ResetStacks::fillData(Player *p)
+{
+  d_player_id = p->getId();
+
+  return true;
+}
+
+//-----------------------------------------------------------------------------
+// Action_ResetStack
+
+Action_ResetRuins::Action_ResetRuins()
+:Action(Action::RUINS_RESET)
+{
+}
+
+Action_ResetRuins::Action_ResetRuins(const Action_ResetRuins &action)
+: Action(action)
+{
+}
+
+Action_ResetRuins::Action_ResetRuins(XML_Helper* helper)
+:Action(helper)
+{
+}
+
+Action_ResetRuins::~Action_ResetRuins()
+{
+}
+
+std::string Action_ResetRuins::dump() const
+{
+  std::stringstream ss;
+  ss <<"Ruins are being recharged.";
+  ss << "\n";
+
+  return ss.str();
+}
+
+bool Action_ResetRuins::doSave(XML_Helper* helper) const
+{
+  bool retval = true;
+  return retval;
+}
+
+bool Action_ResetRuins::fillData()
+{
+  return true;
+}
+
+//-----------------------------------------------------------------------------
+// Action_CollectTaxesAndPayUpkeep
+
+Action_CollectTaxesAndPayUpkeep::Action_CollectTaxesAndPayUpkeep()
+:Action(Action::COLLECT_TAXES_AND_PAY_UPKEEP)
+{
+}
+
+Action_CollectTaxesAndPayUpkeep::Action_CollectTaxesAndPayUpkeep(const Action_CollectTaxesAndPayUpkeep &action)
+: Action(action)
+{
+}
+
+Action_CollectTaxesAndPayUpkeep::Action_CollectTaxesAndPayUpkeep(XML_Helper* helper)
+:Action(helper)
+{
+}
+
+Action_CollectTaxesAndPayUpkeep::~Action_CollectTaxesAndPayUpkeep()
+{
+}
+
+std::string Action_CollectTaxesAndPayUpkeep::dump() const
+{
+  std::stringstream ss;
+  ss <<"Collecting taxes from cities and paying the troops.";
+  ss << "\n";
+
+  return ss.str();
+}
+
+bool Action_CollectTaxesAndPayUpkeep::doSave(XML_Helper* helper) const
+{
+  bool retval = true;
+  return retval;
+}
+
+bool Action_CollectTaxesAndPayUpkeep::fillData()
+{
+  return true;
+}
+
+//-----------------------------------------------------------------------------
+// Action_Kill
+
+Action_Kill::Action_Kill()
+:Action(Action::KILL_PLAYER)
+{
+}
+
+Action_Kill::Action_Kill(const Action_Kill &action)
+: Action(action)
+{
+}
+
+Action_Kill::Action_Kill(XML_Helper* helper)
+:Action(helper)
+{
+}
+
+Action_Kill::~Action_Kill()
+{
+}
+
+std::string Action_Kill::dump() const
+{
+  std::stringstream ss;
+  ss <<"player is vanquished.";
+  ss << "\n";
+
+  return ss.str();
+}
+
+bool Action_Kill::doSave(XML_Helper* helper) const
+{
+  bool retval = true;
+  return retval;
+}
+
+bool Action_Kill::fillData()
+{
+  return true;
+}
+
+//-----------------------------------------------------------------------------
+// Action_DefendStack
+
+Action_DefendStack::Action_DefendStack()
+:Action(Action::STACK_DEFEND), d_stack_id(0)
+{
+}
+
+Action_DefendStack::Action_DefendStack(const Action_DefendStack &action)
+: Action(action), d_stack_id(action.d_stack_id)
+{
+}
+
+Action_DefendStack::Action_DefendStack(XML_Helper* helper)
+:Action(helper)
+{
+  helper->getData(d_stack_id, "stack_id");
+}
+
+Action_DefendStack::~Action_DefendStack()
+{
+}
+
+std::string Action_DefendStack::dump() const
+{
+  std::stringstream ss;
+
+  ss <<"Stack " <<d_stack_id <<" is going into defend mode. " << std::endl;
+
+  return ss.str();
+}
+
+bool Action_DefendStack::doSave(XML_Helper* helper) const
+{
+  bool retval = true;
+  retval &= helper->saveData("stack_id", d_stack_id);
+  return retval;
+}
+
+bool Action_DefendStack::fillData(Stack *s)
+{
+  d_stack_id = s->getId();
+  return true;
+}
+
+//-----------------------------------------------------------------------------
+// Action_UndefendStack
+
+Action_UndefendStack::Action_UndefendStack()
+:Action(Action::STACK_UNDEFEND), d_stack_id(0)
+{
+}
+
+Action_UndefendStack::Action_UndefendStack(const Action_UndefendStack &action)
+: Action(action), d_stack_id(action.d_stack_id)
+{
+}
+
+Action_UndefendStack::Action_UndefendStack(XML_Helper* helper)
+:Action(helper)
+{
+  helper->getData(d_stack_id, "stack_id");
+}
+
+Action_UndefendStack::~Action_UndefendStack()
+{
+}
+
+std::string Action_UndefendStack::dump() const
+{
+  std::stringstream ss;
+
+  ss <<"Stack " <<d_stack_id <<" is going out of defend mode. " << std::endl;
+
+  return ss.str();
+}
+
+bool Action_UndefendStack::doSave(XML_Helper* helper) const
+{
+  bool retval = true;
+  retval &= helper->saveData("stack_id", d_stack_id);
+  return retval;
+}
+
+bool Action_UndefendStack::fillData(Stack *s)
+{
+  d_stack_id = s->getId();
+  return true;
+}
+
+//-----------------------------------------------------------------------------
+// Action_ParkStack
+
+Action_ParkStack::Action_ParkStack()
+:Action(Action::STACK_PARK), d_stack_id(0)
+{
+}
+
+Action_ParkStack::Action_ParkStack(const Action_ParkStack &action)
+: Action(action), d_stack_id(action.d_stack_id)
+{
+}
+
+Action_ParkStack::Action_ParkStack(XML_Helper* helper)
+:Action(helper)
+{
+  helper->getData(d_stack_id, "stack_id");
+}
+
+Action_ParkStack::~Action_ParkStack()
+{
+}
+
+std::string Action_ParkStack::dump() const
+{
+  std::stringstream ss;
+
+  ss <<"Stack " <<d_stack_id <<" is going into parked mode. " << std::endl;
+
+  return ss.str();
+}
+
+bool Action_ParkStack::doSave(XML_Helper* helper) const
+{
+  bool retval = true;
+  retval &= helper->saveData("stack_id", d_stack_id);
+  return retval;
+}
+
+bool Action_ParkStack::fillData(Stack *s)
+{
+  d_stack_id = s->getId();
+  return true;
+}
+
+//-----------------------------------------------------------------------------
+// Action_UnparkStack
+
+Action_UnparkStack::Action_UnparkStack()
+:Action(Action::STACK_UNPARK), d_stack_id(0)
+{
+}
+
+Action_UnparkStack::Action_UnparkStack(const Action_UnparkStack &action)
+: Action(action), d_stack_id(action.d_stack_id)
+{
+}
+
+Action_UnparkStack::Action_UnparkStack(XML_Helper* helper)
+:Action(helper)
+{
+  helper->getData(d_stack_id, "stack_id");
+}
+
+Action_UnparkStack::~Action_UnparkStack()
+{
+}
+
+std::string Action_UnparkStack::dump() const
+{
+  std::stringstream ss;
+
+  ss <<"Stack " <<d_stack_id <<" is going out of parked mode. " << std::endl;
+
+  return ss.str();
+}
+
+bool Action_UnparkStack::doSave(XML_Helper* helper) const
+{
+  bool retval = true;
+  retval &= helper->saveData("stack_id", d_stack_id);
+  return retval;
+}
+
+bool Action_UnparkStack::fillData(Stack *s)
+{
+  d_stack_id = s->getId();
+  return true;
+}
+
+//-----------------------------------------------------------------------------
+// Action_SelectStack
+
+Action_SelectStack::Action_SelectStack()
+:Action(Action::STACK_SELECT), d_stack_id(0)
+{
+}
+
+Action_SelectStack::Action_SelectStack(const Action_SelectStack &action)
+: Action(action), d_stack_id(action.d_stack_id)
+{
+}
+
+Action_SelectStack::Action_SelectStack(XML_Helper* helper)
+:Action(helper)
+{
+  helper->getData(d_stack_id, "stack_id");
+}
+
+Action_SelectStack::~Action_SelectStack()
+{
+}
+
+std::string Action_SelectStack::dump() const
+{
+  std::stringstream ss;
+
+  ss <<"Stack " <<d_stack_id <<" is selected. " << std::endl;
+
+  return ss.str();
+}
+
+bool Action_SelectStack::doSave(XML_Helper* helper) const
+{
+  bool retval = true;
+  retval &= helper->saveData("stack_id", d_stack_id);
+  return retval;
+}
+
+bool Action_SelectStack::fillData(Stack *s)
+{
+  d_stack_id = s->getId();
+  return true;
+}
+
+//-----------------------------------------------------------------------------
+// Action_DeselectStack
+
+Action_DeselectStack::Action_DeselectStack()
+:Action(Action::STACK_DESELECT)
+{
+}
+
+Action_DeselectStack::Action_DeselectStack(const Action_DeselectStack &action)
+: Action(action)
+{
+}
+
+Action_DeselectStack::Action_DeselectStack(XML_Helper* helper)
+:Action(helper)
+{
+}
+
+Action_DeselectStack::~Action_DeselectStack()
+{
+}
+
+std::string Action_DeselectStack::dump() const
+{
+  std::stringstream ss;
+
+  ss <<"deselecting stack. " << std::endl;
+
+  return ss.str();
+}
+
+bool Action_DeselectStack::doSave(XML_Helper* helper) const
+{
+  return true;
+}
+
+bool Action_DeselectStack::fillData()
+{
+  return true;
+}
+
 std::string Action::actionTypeToString(Action::Type type)
 {
   switch (type)
@@ -2559,6 +3205,28 @@ std::string Action::actionTypeToString(Action::Type type)
       return "Action::CITY_LOOT";
     case Action::USE_ITEM:
       return "Action::USE_ITEM";
+    case Action::STACK_ORDER:
+      return "Action::STACK_ORDER";
+    case Action::STACKS_RESET:
+      return "Action::STACKS_RESET";
+    case Action::RUINS_RESET:
+      return "Action::RUINS_RESET";
+    case Action::COLLECT_TAXES_AND_PAY_UPKEEP:
+      return "Action::COLLECT_TAXES_AND_PAY_UPKEEP";
+    case Action::KILL_PLAYER:
+      return "Action::KILL_PLAYER";
+    case Action::STACK_DEFEND:
+      return "Action::STACK_DEFEND";
+    case Action::STACK_UNDEFEND:
+      return "Action::STACK_UNDEFEND";
+    case Action::STACK_PARK:
+      return "Action::STACK_PARK";
+    case Action::STACK_UNPARK:
+      return "Action::STACK_UNPARK";
+    case Action::STACK_SELECT:
+      return "Action::STACK_SELECT";
+    case Action::STACK_DESELECT:
+      return "Action::STACK_DESELECT";
     }
       
   return "Action::MOVE";
@@ -2642,6 +3310,28 @@ Action::Type Action::actionTypeFromString(std::string str)
     return Action::CITY_LOOT;
   else if (str == "Action::USE_ITEM")
     return Action::USE_ITEM;
+  else if (str == "Action::STACK_ORDER")
+    return Action::STACK_ORDER;
+  else if (str == "Action::STACKS_RESET")
+    return Action::STACKS_RESET;
+  else if (str == "Action::RUINS_RESET")
+    return Action::RUINS_RESET;
+  else if (str == "Action::COLLECT_TAXES_AND_PAY_UPKEEP")
+    return Action::COLLECT_TAXES_AND_PAY_UPKEEP;
+  else if (str == "Action::KILL_PLAYER")
+    return Action::KILL_PLAYER;
+  else if (str == "Action::STACK_DEFEND")
+    return Action::STACK_DEFEND;
+  else if (str == "Action::STACK_UNDEFEND")
+    return Action::STACK_UNDEFEND;
+  else if (str == "Action::STACK_PARK")
+    return Action::STACK_PARK;
+  else if (str == "Action::STACK_UNPARK")
+    return Action::STACK_UNPARK;
+  else if (str == "Action::STACK_SELECT")
+    return Action::STACK_SELECT;
+  else if (str == "Action::STACK_DESELECT")
+    return Action::STACK_DESELECT;
   return Action::STACK_MOVE;
 }
 
