@@ -326,6 +326,11 @@ void Army::decrementMoves(guint32 moves)
     d_moves -= moves;
 }
 
+void Army::incrementMoves(guint32 moves)
+{
+  d_moves += moves;
+}
+
 void Army::gainXp(double n)
 {
   d_xp += n;
@@ -413,9 +418,16 @@ void  Army::printAllDebugInfo() const
 
 void Army::setInShip (bool s)
 {
+  if (s == true && isFlyer() == true)
+    s = false;
   d_ship = s;
 }
 
+bool Army::isFlyer()
+{
+  return d_move_bonus == Tile::isFlying();
+}
+
 //! Sets this army as being fortified (+1 to stack)
 void Army::setFortified (bool f)
 {
@@ -481,3 +493,8 @@ void Army::morph(const ArmyProto *army)
   d_type_id = army->getTypeId();
   d_armyset = army->getArmyset();
 }
+
+guint32 Army::countBlessings() const
+{
+  return d_visitedTemples.size();
+}
