@@ -41,44 +41,30 @@ class ArmyProtoBase : public ArmyBase
 	//! Loading constructor.
         ArmyProtoBase(XML_Helper* helper);
         
-	//! Create an empty army prototype base.
+	//! Default constructor.  Create an empty army prototype base.
 	ArmyProtoBase();
 
 	//! Destructor.
         ~ArmyProtoBase();
 
-        // Set functions:
+        // Set Methods
         
         void setTypeId(guint32 type_id) {d_type_id = type_id;};
 
         //! Sets the descriptive text for this Army.
         void setDescription(std::string text) {d_description = text;};
         
-        //! Set the gold pieces needed to add this Army to a city's production.
+        //! Set the gold pieces needed to make an Army unit of this kind.
         void setProductionCost(guint32 production_cost)
 	  {d_production_cost = production_cost;}
 
+        //! Set the gold pieces needed to add this Army to a city's production.
+        void setNewProductionCost(guint32 new_production_cost)
+	  {d_new_production_cost = new_production_cost;}
+
 	//! Sets the armyset id for this army.
 	void setArmyset(guint32 id) {d_armyset = id;};
 
-        // Get functions
-        
-	//! Get the Id of the Armyset to which the Army's type belongs.
-        guint32 getTypeId() const {return d_type_id;}
-
-        //! Returns the descriptive text of this Army.
-        std::string getDescription() const {return _(d_description.c_str());}
-
-        //! Returns how much gold setting up the production costs
-	/**
-	 * @return The amount of gold pieces required to add this Army
-	 *         into the City's suite of 4 production slots.
-	 */
-        guint32 getProductionCost() const {return d_production_cost;}
-
-	//! Returns the armyset id for this army.
-	guint32 getArmyset() const {return d_armyset;};
-
         //! Set the army bonus of the army prototype.
         void setArmyBonus(guint32 bonus) {d_army_bonus = bonus;};
 
@@ -94,16 +80,39 @@ class ArmyProtoBase : public ArmyBase
         //! Set the name of the Army.
         void setName(std::string name){d_name = name;}
 
+        //! Set how many turns this unit type needs to be produced.
+        void setProduction(guint32 production){d_production = production;};
+
+
+        // Get Methods
+        
+	//! Get the Id of the Armyset to which the Army's type belongs.
+        guint32 getTypeId() const {return d_type_id;}
+
+        //! Returns the descriptive text of this Army.
+        std::string getDescription() const {return _(d_description.c_str());}
+
+	//! Returns how much gold making one of these army units costs.
+        guint32 getProductionCost() const {return d_production_cost;}
+
+        //! Returns how much gold setting up the production costs
+	/**
+	 * @return The amount of gold pieces required to add this Army
+	 *         into the City's suite of 4 production slots.
+	 */
+        guint32 getNewProductionCost() const {return d_new_production_cost;}
+
+	//! Returns the armyset id for this army.
+	guint32 getArmyset() const {return d_armyset;};
+
         //! Returns the name of the Army.
         std::string getName() const {return _(d_name.c_str());};
 
         //! Returns how many turns this Army needs to be produced.
         guint32 getProduction() const {return d_production;};
 
-        //! Set how many turns this unit type needs to be produced.
-        void setProduction(guint32 production){d_production = production;};
-
     protected:
+	//! Callback method for loading this object from an opened file.
 	bool saveData(XML_Helper* helper) const;
 
 	//! The name of the Army unit.  e.g. Scouts.
@@ -115,6 +124,13 @@ class ArmyProtoBase : public ArmyBase
 	//! The description of the Army unit.
         std::string d_description;
 
+	//! How many gold pieces needed to create an army of this kind.
+	/**
+	 * Every time an army unit is created of this kind, it costs the
+	 * player this many gold pieces.
+	 */
+        guint32 d_production_cost;
+
         //! How many gold pieces needed to add this Army to a city's production.
 	/**
 	 * If d_production_cost is over zero, then the Army can be purchased.
@@ -123,7 +139,7 @@ class ArmyProtoBase : public ArmyBase
 	 *
 	 * This value does not change during gameplay.
 	 */
-        guint32 d_production_cost;
+        guint32 d_new_production_cost;
 
 	//! How many turns the Army unit takes to be produced in a City.
 	/**
