@@ -1,4 +1,4 @@
-//  Copyright (C) 2007, 2008, 2009, 2010 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009, 2010, 2011 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -264,11 +264,11 @@ class Armyset: public std::list<ArmyProto *>, public sigc::trackable, public Set
         //! Delete the armyset's temporary directory.
         void clean_tmp_dir() const;
 
-	void instantiateImages();
+	void instantiateImages(bool &broken);
 	void uninstantiateImages();
-	void loadStandardPic(std::string image_filename);
-	void loadShipPic(std::string image_filename);
-	void loadBagPic(std::string image_filename);
+	void loadStandardPic(std::string image_filename, bool &broken);
+	void loadShipPic(std::string image_filename, bool &broken);
+	void loadBagPic(std::string image_filename, bool &broken);
 
 	std::string getConfigurationFile() const;
 	static std::list<std::string> scanUserCollection();
@@ -284,7 +284,7 @@ class Armyset: public std::list<ArmyProto *>, public sigc::trackable, public Set
         std::string getFileFromConfigurationFile(std::string file);
         bool replaceFileInConfigurationFile(std::string file, std::string new_file);
         //! Load the armyset again.
-        void reload();
+        void reload(bool &broken);
         guint32 calculate_preferred_tile_size() const;
 
     private:
