@@ -1,7 +1,7 @@
 // Copyright (C) 2001, 2002, 2003 Michael Bartl
 // Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2004, 2005 Andrea Paternesi
-// Copyright (C) 2007, 2008, 2009, 2010 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009, 2010, 2011 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -296,18 +296,21 @@ void Armysetlist::getSizes(std::list<guint32> &sizes)
     }
 }
 
-guint32 Armysetlist::getArmysetId(std::string armyset, guint32 tilesize) const
+int Armysetlist::getArmysetId(std::string armyset, guint32 tilesize) const
 {
   IdMap::const_iterator it = 
     d_ids.find(String::ucompose("%1 %2", armyset, tilesize));
   if (it == d_ids.end())
-    return NULL;
+    return -1;
   return (*it).second;
 }
 
 std::string Armysetlist::getArmysetDir(std::string name, guint32 tilesize) const
 {
-  return getArmyset(getArmysetId(name, tilesize))->getBaseName();
+  int id = getArmysetId(name, tilesize);
+  if (id == -1)
+    return "";
+  return getArmyset(id)->getBaseName();
 }
 
 int Armysetlist::getNextAvailableId(int after)
@@ -345,10 +348,14 @@ int Armysetlist::getNextAvailableId(int after)
   return -1;
 }
 
-void Armysetlist::instantiateImages()
+void Armysetlist::instantiateImages(bool &broken)
 {
+  broken = false;
   for (iterator it = begin(); it != end(); it++)
-    (*it)->instantiateImages();
+    {
+      if (!broken)
+        (*it)->instantiateImages(broken);
+    }
 }
 
 void Armysetlist::uninstantiateImages()
