@@ -1,6 +1,6 @@
 // Copyright (C) 2001, 2002, 2003 Michael Bartl
 // Copyright (C) 2003, 2004, 2005 Ulf Lorenz
-// Copyright (C) 2007, 2008, 2009, 2010 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009, 2010, 2011 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -126,7 +126,7 @@ class Armysetlist : public std::list<Armyset*>, public sigc::trackable
 	  *
           * @return the id of the armyset (0 on error)
           */
-	guint32 getArmysetId(std::string armyset, guint32 tilesize) const;
+	int getArmysetId(std::string armyset, guint32 tilesize) const;
 	Armyset *getArmyset(guint32 id) const;
 
 	//! Return the Armyset object by the name of the subdir.
@@ -154,7 +154,7 @@ class Armysetlist : public std::list<Armyset*>, public sigc::trackable
 
 	void add(Armyset *arymset, std::string file);
 
-	void instantiateImages();
+	void instantiateImages(bool &broken);
 	void uninstantiateImages();
 	
 
