@@ -86,13 +86,13 @@ bool Bridgelist::load(std::string tag, XML_Helper* helper)
     return true;
 }
 
-int Bridgelist::calculateType(Vector<int> t)
+int Bridgelist::calculateType(Vector<int> t) const
 {
     // examine neighbour tiles to discover whether there's a bridge on them
-    bool u = Bridgelist::getInstance()->getObjectAt(t + Vector<int>(0, -1));
-    bool b = Bridgelist::getInstance()->getObjectAt(t + Vector<int>(0, 1));
-    bool l = Bridgelist::getInstance()->getObjectAt(t + Vector<int>(-1, 0));
-    bool r = Bridgelist::getInstance()->getObjectAt(t + Vector<int>(1, 0));
+    bool u = getObjectAt(t + Vector<int>(0, -1));
+    bool b = getObjectAt(t + Vector<int>(0, 1));
+    bool l = getObjectAt(t + Vector<int>(-1, 0));
+    bool r = getObjectAt(t + Vector<int>(1, 0));
 
     if (u)
       return Bridge::CONNECTS_TO_NORTH;
