@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, Ole Laursen
+//  Copyright (C) 2007 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -19,7 +19,7 @@
 #define CALLBACK_ENUMS_H
 
 enum CityDefeatedAction {
-    CITY_DEFEATED_OCCUPY, CITY_DEFEATED_PILLAGE, CITY_DEFEATED_RAZE,
+    CITY_DEFEATED_OCCUPY = 1, CITY_DEFEATED_PILLAGE, CITY_DEFEATED_RAZE,
     CITY_DEFEATED_SACK
 };
 
