@@ -26,19 +26,22 @@
 #define DEFINITIONS_H
 
 #include <gtkmm.h>
+#include <glibmm.h>
 #include <string>
 #include <libintl.h>
 
-#define LORDSAWAR_SAVEGAME_VERSION "0.1.9"
-#define LORDSAWAR_TILESET_VERSION "0.1.9"
-#define LORDSAWAR_ARMYSET_VERSION "0.1.9"
-#define LORDSAWAR_CITYSET_VERSION "0.1.9"
-#define LORDSAWAR_SHIELDSET_VERSION "0.1.9"
-#define LORDSAWAR_CONFIG_VERSION "0.1.9"
-#define LORDSAWAR_RECENTLY_PLAYED_VERSION "0.1.9"
-#define LORDSAWAR_RECENTLY_EDITED_VERSION "0.1.9"
-#define _(string) gettext(string) // Macro for the gettext
-#define __(astring) std::string(gettext(astring.c_str()))
+#define LORDSAWAR_SAVEGAME_VERSION "0.2.0"
+#define LORDSAWAR_TILESET_VERSION "0.2.0"
+#define LORDSAWAR_ARMYSET_VERSION "0.2.0"
+#define LORDSAWAR_CITYSET_VERSION "0.2.0"
+#define LORDSAWAR_SHIELDSET_VERSION "0.2.0"
+#define LORDSAWAR_CONFIG_VERSION "0.2.0"
+#define LORDSAWAR_RECENTLY_PLAYED_VERSION "0.2.0"
+#define LORDSAWAR_RECENTLY_EDITED_VERSION "0.2.0"
+#define LORDSAWAR_PROFILES_VERSION "0.2.0"
+#define LORDSAWAR_RECENTLY_HOSTED_VERSION "0.2.0"
+#define _(string) Glib::locale_to_utf8(Glib::ustring(gettext(string))) // Macro for the gettext
+#define N_(string) string
 
 
 //-----------------------------------------------------------------------------
@@ -83,11 +86,17 @@ const unsigned int MOVE_BONUS_WIDTH = 32;
 const unsigned int MOVE_BONUS_HEIGHT = 20;
 const unsigned int MOVE_BONUS_TYPES = 6;
 const unsigned int MEDAL_TYPES = 3;
+const unsigned int NUM_WAYPOINTS = 2;
+const unsigned int NUM_GAME_BUTTON_IMAGES = 11;
+const unsigned int NUM_ARROW_IMAGES = 8;
+const unsigned int NUM_BACKGROUND_IMAGES = 2;
 
 const int MAX_GOLD_TO_CARRY_OVER_TO_NEXT_SCENARIO = 5000;
 const unsigned int MAX_ARMY_STRENGTH = 9;
 
 const unsigned short LORDSAWAR_PORT = 14998;
+const unsigned short LORDSAWAR_GAMELIST_PORT = 18998;
+const unsigned short LORDSAWAR_GAMEHOST_PORT = 22998;
 #define HUMAN_PLAYER_TYPE _("Human")
 #define EASY_PLAYER_TYPE _("Easy")
 #define HARD_PLAYER_TYPE _("Hard")
@@ -108,6 +117,9 @@ const std::string SAVE_EXT = ".sav";
 const std::string PBM_EXT = ".trn";
 const std::string RECENTLY_PLAYED_LIST = "recently-played.xml";
 const std::string RECENTLY_EDITED_LIST = "recently-edited.xml";
+const std::string PROFILE_LIST = "profiles.xml";
+const std::string RECENTLY_ADVERTISED_LIST = "recently-advertised.xml";
+const std::string RECENTLY_HOSTED_LIST = "recently-hosted.xml";
 
 const unsigned int MIN_PRODUCTION_TURNS_FOR_ARMY_UNITS = 1;
 const unsigned int MAX_PRODUCTION_TURNS_FOR_ARMY_UNITS = 5;
@@ -142,5 +154,6 @@ const Gdk::Color GRID_BOX_COLOUR(BLACK_COLOUR);
 const Gdk::Color FOG_COLOUR(BLACK_COLOUR);
 const Gdk::Color VECTORMAP_ACTIVE_BOX_COLOUR(WHITE_COLOUR);
 
+
 #endif // DEFINITIONS_H
 
