@@ -1,5 +1,5 @@
 //  Copyright (C) 2007 Ole Laursen
-//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009, 2010 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 #include "army.h"
 #include "stacklist.h"
 #include "stack.h"
+#include "stacktile.h"
 #include "citylist.h"
 #include "city.h"
 #include "ruinlist.h"
@@ -53,6 +54,8 @@
 #include "Backpack.h"
 #include "MapBackpack.h"
 #include "backpack-editor-dialog.h"
+#include "citysetlist.h"
+#include "cityset.h"
 
 
 EditorBigMap::EditorBigMap()
@@ -164,7 +167,7 @@ void EditorBigMap::mouse_motion_event(MouseMotionEvent e)
 	
 	// FIXME: show a drag cursor
 	
-	int ts = GameMap::getInstance()->getTileset()->getTileSize();
+	int ts = GameMap::getInstance()->getTileSize();
 	Vector<int> screen_dim(image.get_width(), image.get_height());
 	view_pos = clip(Vector<int>(0, 0),
 			view_pos + delta,
@@ -302,7 +305,6 @@ void EditorBigMap::change_map_under_cursor()
 
   Player* active = Playerlist::getInstance()->getActiveplayer();
   std::vector<Vector<int> > tiles = get_cursor_tiles();
-  Cityset* cs = GameMap::getInstance()->getCityset();
 
   Vector<int> tile = tiles.front();
   Rectangle changed_tiles(tile, Vector<int>(-1, -1));
@@ -341,7 +343,23 @@ void EditorBigMap::change_map_under_cursor()
           Vector<int> from = moving_objects_from;
           //here we go with the move!
           GameMap *gm = GameMap::getInstance();
-          if (gm->getBuilding(from) != Maptile::NONE)
+          if (gm->getStack(from) != NULL)
+            {
+              Stack *s = gm->getFriendlyStack(from);
+              if (!s)
+                s = gm->getStack(from);
+              if (gm->canPutStack(s->size(), s->getOwner(), tile) == true)
+                {
+                  gm->moveStack(s, tile);
+                  moving_objects_from = Vector<int>(-1,-1);
+                }
+            }
+          else if (gm->getBackpack(from)->empty() == false)
+            {
+              gm->moveBackpack(from, tile);
+              moving_objects_from = Vector<int>(-1,-1);
+            }
+          else if (gm->getBuilding(from) != Maptile::NONE)
             {
               guint32 s = gm->getBuildingSize(from);
               if (gm->canPutBuilding
@@ -360,73 +378,16 @@ void EditorBigMap::change_map_under_cursor()
                     }
                 }
             }
-          else if (gm->getStack(from) != NULL)
-            {
-              Stack *s = gm->getFriendlyStack(from);
-              if (!s)
-                s = gm->getStack(from);
-              if (gm->canPutStack(s->size(), s->getOwner(), tile) == true)
-                {
-                  gm->moveStack(s, tile);
-                  moving_objects_from = Vector<int>(-1,-1);
-                }
-            }
-          else if (gm->getBackpack(from)->empty() == false)
-            {
-              gm->moveBackpack(from, tile);
-              moving_objects_from = Vector<int>(-1,-1);
-            }
         }
       break;
     case ERASE:
       // check if there is a building or a stack there and remove it
 
-      // first stack, it's above everything else
-      while  (GameMap::getStack(tile) != NULL)
-        {
-          Stack *s = GameMap::getStack(tile);
-          GameMap::getInstance()->removeStack(s);
-        }
-
-      // ... or a temple ...
-      GameMap::getInstance()->removeTemple(tile);
-
-      // ... or a port ...
-      GameMap::getInstance()->removePort(tile);
-
-      // ... or a ruin ...
-      if (GameMap::getRuin(tile) != NULL)
-        {
-          Rewardlist *rl = Rewardlist::getInstance();
-          for (Rewardlist::iterator i = rl->begin(); i != rl->end(); i++)
-            {
-              if ((*i)->getType() == Reward::RUIN)
-                {
-                  Reward_Ruin *rr = static_cast<Reward_Ruin*>(*i);
-                  if (rr->getRuin()->getPos() == tile)
-                    rl->remove(*i);
-                }
-            }
-        }
-      GameMap::getInstance()->removeRuin(tile);
-
-      // ... or a road ...
-      GameMap::getInstance()->removeRoad(tile);
-
-      // ... or a bridge...
-      GameMap::getInstance()->removeBridge(tile);
-
-      // ... or a signpost ...
-      GameMap::getInstance()->removeSignpost(tile);
-
-      // ... or a city
-      GameMap::getInstance()->removeCity(tile);
-
-      // ... or a bag
-      GameMap::getInstance()->getTile(tile)->getBackpack()->removeAllFromBackpack();
+      GameMap::getInstance()->eraseTile(tile);
       break;
 
     case STACK:
+              
       if (GameMap::getInstance()->canPutStack(1, active, tile) == true)
         {
           // Create a new dummy stack. As we don't want to have empty
@@ -434,57 +395,36 @@ void EditorBigMap::change_map_under_cursor()
           // has at least one entry.
           Stack* s = new Stack(active, tile);
           const Armysetlist* al = Armysetlist::getInstance();
-          Army* a = new Army(*al->getArmy(active->getArmyset(), 0), 
-                             active);
-          s->push_back(a);
+          Army* a = new Army(*al->getArmy(active->getArmyset(), 0), active);
+          s->add(a);
           GameMap::getInstance()->putStack(s);
           //if we're on a city, change the allegiance of the stack
           //and it's armies to that of the city
           if (GameMap::getInstance()->getBuilding(s->getPos()) == Maptile::CITY)
             {
               City *c = GameMap::getCity(s->getPos());
-              Stacklist::changeOwnership(s, c->getOwner());
+              if (c->getOwner() != active)
+                {
+                  GameMap::getStacks(s->getPos())->leaving(s);
+                  s = Stacklist::changeOwnership(s, c->getOwner());
+                  GameMap::getStacks(s->getPos())->arriving(s);
+                }
             }
         }
 
       break;
 
     case CITY:
-        {
-          // check if we can place the city
-          bool city_placeable =
-            GameMap::getInstance()->canPutBuilding
-            (Maptile::CITY,cs->getCityTileWidth(), tile);
-
-          if (!city_placeable)
-            break;
-
-          City *c = new City(tile, cs->getCityTileWidth());
-          GameMap::getInstance()->putCity(c);
-          break;
-        }
+      GameMap::getInstance()->putNewCity(tile);
+      break;
 
     case RUIN:
-        {
-          bool ruin_placeable = GameMap::getInstance()->canPutBuilding
-            (Maptile::RUIN, cs->getRuinTileWidth(), tile);
-          if (!ruin_placeable)
-            break;
-          Ruin *r = new Ruin(tile, cs->getRuinTileWidth());
-          GameMap::getInstance()->putRuin(r);
-          break;
-        }
+      GameMap::getInstance()->putNewRuin(tile);
+      break;
 
     case TEMPLE:
-        {
-          bool temple_placeable = GameMap::getInstance()->canPutBuilding
-            (Maptile::TEMPLE, cs->getRuinTileWidth(), tile);
-          if (!temple_placeable)
-            break;
-          Temple *t = new Temple(tile, cs->getTempleTileWidth());
-          GameMap::getInstance()->putTemple(t);
-          break;
-        }
+      GameMap::getInstance()->putNewTemple(tile);
+      break;
 
     case SIGNPOST:
         {
@@ -541,7 +481,7 @@ void EditorBigMap::change_map_under_cursor()
           break;
         }
     case BAG:
-      if (maptile->getMaptileType() != Tile::WATER)
+      if (maptile->getType() != Tile::WATER)
         {
           //open the dialog
           MapBackpack *bag = 
@@ -568,7 +508,7 @@ void EditorBigMap::smooth_view()
 
 void EditorBigMap::after_draw()
 {
-    int tilesize = GameMap::getInstance()->getTileset()->getTileSize();
+    int tilesize = GameMap::getInstance()->getTileSize();
     std::vector<Vector<int> > tiles;
 
     if (show_tile_types_instead_of_tile_styles)
@@ -646,17 +586,17 @@ void EditorBigMap::after_draw()
 	    break;
 
 	  case CITY:
-	    pic = GraphicsCache::getInstance()->getCityPic(0, Playerlist::getInstance()->getActiveplayer(), GameMap::getInstance()->getCityset()->getId());
+	    pic = GraphicsCache::getInstance()->getCityPic(0, Playerlist::getInstance()->getActiveplayer(), GameMap::getInstance()->getCitysetId());
 	    pic->blit(buffer, pos);
 	    break;
 
 	  case RUIN:
-	    pic = GraphicsCache::getInstance()->getRuinPic(0, GameMap::getInstance()->getCityset()->getId());
+	    pic = GraphicsCache::getInstance()->getRuinPic(0, GameMap::getInstance()->getCitysetId());
 	    pic->blit(buffer, pos);
 	    break;
 
 	  case TEMPLE:
-	    pic = GraphicsCache::getInstance()->getTemplePic(0, GameMap::getInstance()->getCityset()->getId());
+	    pic = GraphicsCache::getInstance()->getTemplePic(0, GameMap::getInstance()->getCitysetId());
 	    pic->blit(buffer, pos);
 	    break;
 
