@@ -1,4 +1,4 @@
-//  Copyright (C) 2008, 2009 Ben Asselstine
+//  Copyright (C) 2008, 2009, 2011 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -122,6 +122,9 @@ ItemlistDialog::ItemlistDialog()
     xml->get_widget("sinks_ships_checkbutton", sinks_ships_checkbutton);
     sinks_ships_checkbutton->signal_toggled().connect(
 	sigc::mem_fun(this, &ItemlistDialog::on_sinks_ships_toggled));
+    xml->get_widget("banish_worms_checkbutton", banish_worms_checkbutton);
+    banish_worms_checkbutton->signal_toggled().connect(
+	sigc::mem_fun(this, &ItemlistDialog::on_banish_worms_toggled));
     xml->get_widget("uses_spinbutton", uses_spinbutton);
     uses_spinbutton->signal_changed().connect(
 	sigc::mem_fun(this, &ItemlistDialog::on_uses_changed));
@@ -224,6 +227,7 @@ void ItemlistDialog::fill_item_info(ItemProto *item)
     (item->getBonus(ItemProto::ADD5GOLDPERCITY));
   steals_gold_checkbutton->set_active (item->getBonus(ItemProto::STEAL_GOLD));
   sinks_ships_checkbutton->set_active (item->getBonus(ItemProto::SINK_SHIPS));
+  banish_worms_checkbutton->set_active (item->getBonus(ItemProto::BANISH_WORMS));
   uses_spinbutton->set_value(double(item->getNumberOfUsesLeft()));
   inhibit_bonus_checkbuttons = 0;
 }
@@ -241,17 +245,19 @@ void ItemlistDialog::on_name_changed()
       row[items_columns.name] = name_entry->get_text();
     }
 }
+
 void ItemlistDialog::on_add_item_clicked()
 {
   //add a new empty item to the itemlist
-  ItemProto *a = new ItemProto("Untitled", 0);
+  ItemProto *a = new ItemProto("Untitled");
+  d_itemlist->add(a);
   //add it to the treeview
   Gtk::TreeIter i = items_list->append();
   a->setName("Untitled");
   (*i)[items_columns.name] = a->getName();
   (*i)[items_columns.item] = a;
-
 }
+
 void ItemlistDialog::on_remove_item_clicked()
 {
   //erase the selected row from the treeview
@@ -267,6 +273,7 @@ void ItemlistDialog::on_remove_item_clicked()
       d_itemlist->remove(a);
     }
 }
+
 void ItemlistDialog::set_parent_window(Gtk::Window &parent)
 {
     dialog->set_transient_for(parent);
@@ -371,6 +378,11 @@ void ItemlistDialog::on_sinks_ships_toggled()
   on_checkbutton_toggled(sinks_ships_checkbutton, ItemProto::SINK_SHIPS);
 }
 	
+void ItemlistDialog::on_banish_worms_toggled()
+{
+  on_checkbutton_toggled(banish_worms_checkbutton, ItemProto::BANISH_WORMS);
+}
+	
 void ItemlistDialog::on_uses_changed()
 {
   if (inhibit_bonus_checkbuttons)
