@@ -1,5 +1,5 @@
 //  Copyright (C) 2007 Ole Laursen
-//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009, 2010 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -109,7 +109,7 @@ NewMapDialog::NewMapDialog()
     default_id = 0;
     shield_theme_combobox = manage(new Gtk::ComboBoxText);
     Shieldsetlist *sl = Shieldsetlist::getInstance();
-    std::list<std::string> shield_themes = sl->getNames();
+    std::list<std::string> shield_themes = sl->getValidNames();
     for (std::list<std::string>::iterator i = shield_themes.begin(),
 	 end = shield_themes.end(); i != end; ++i)
       {
@@ -285,7 +285,7 @@ void NewMapDialog::on_map_size_changed()
 
 void NewMapDialog::add_fill_style(Tile::Type tile_type)
 {
-  Tileset *tileset = GameMap::getInstance()->getTileset();
+  Tileset *tileset = GameMap::getTileset();
   Tile *tile = (*tileset)[tileset->getIndex(tile_type)];
   fill_style_combobox->append_text(tile->getName());
   fill_style.push_back(tile_type);
@@ -303,7 +303,7 @@ void NewMapDialog::on_tile_size_changed()
 
   tile_theme_combobox->clear_items();
   Tilesetlist *tl = Tilesetlist::getInstance();
-  std::list<std::string> tile_themes = tl->getNames(get_active_tile_size());
+  std::list<std::string> tile_themes = tl->getValidNames(get_active_tile_size());
   for (std::list<std::string>::iterator i = tile_themes.begin(),
        end = tile_themes.end(); i != end; ++i)
     {
@@ -319,7 +319,7 @@ void NewMapDialog::on_tile_size_changed()
 
   army_theme_combobox->clear_items();
   Armysetlist *al = Armysetlist::getInstance();
-  std::list<std::string> army_themes = al->getNames(get_active_tile_size());
+  std::list<std::string> army_themes = al->getValidNames(get_active_tile_size());
   counter = 0;
   default_id = 0;
   for (std::list<std::string>::iterator i = army_themes.begin(),
@@ -337,7 +337,7 @@ void NewMapDialog::on_tile_size_changed()
 
   city_theme_combobox->clear_items();
   Citysetlist *cl = Citysetlist::getInstance();
-  std::list<std::string> city_themes = cl->getNames(get_active_tile_size());
+  std::list<std::string> city_themes = cl->getValidNames(get_active_tile_size());
   counter = 0;
   default_id = 0;
   for (std::list<std::string>::iterator i = city_themes.begin(),
