@@ -1,8 +1,8 @@
-//  Copyright (C) 2008, Ben Asselstine
+//  Copyright (C) 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,10 +17,7 @@
 
 #include <config.h>
 
-#include <libglademm/xml.h>
-#include <gtkmm/image.h>
-#include <gtkmm/table.h>
-#include <gtkmm/alignment.h>
+#include <gtkmm.h>
 #include <sigc++/functors/mem_fun.h>
 #include <assert.h>
 
@@ -37,13 +34,11 @@ SelectRewardDialog::SelectRewardDialog()
 {
     selected_reward = 0;
     
-    Glib::RefPtr<Gnome::Glade::Xml> xml
-	= Gnome::Glade::Xml::create(get_glade_path()
-				    + "/select-reward-dialog.glade");
+    Glib::RefPtr<Gtk::Builder> xml
+	= Gtk::Builder::create_from_file(get_glade_path()
+				    + "/select-reward-dialog.ui");
 
-    Gtk::Dialog *d = 0;
-    xml->get_widget("dialog", d);
-    dialog.reset(d);
+    xml->get_widget("dialog", dialog);
     
     xml->get_widget("select_button", select_button);
 
@@ -58,7 +53,7 @@ SelectRewardDialog::SelectRewardDialog()
     for (;iter != rewardlist->end(); iter++)
       addReward(*iter);
       
-    Uint32 max = rewardlist->size();
+    guint32 max = rewardlist->size();
     if (max)
       {
 	Gtk::TreeModel::Row row;
@@ -70,6 +65,10 @@ SelectRewardDialog::SelectRewardDialog()
       select_button->set_sensitive(false);
 }
 
+SelectRewardDialog::~SelectRewardDialog()
+{
+  delete dialog;
+}
 void SelectRewardDialog::addReward(Reward *reward)
 {
   Gtk::TreeIter i = rewards_list->append();
@@ -88,7 +87,7 @@ void SelectRewardDialog::run()
     dialog->show_all();
     int response = dialog->run();
 
-    if (response != 1)
+    if (response != Gtk::RESPONSE_ACCEPT)
 	selected_reward = 0;
     else
       {
