@@ -1,4 +1,4 @@
-//  Copyright (C) 2007, 2008, 2009, 2010 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009, 2010, 2011 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -526,8 +526,9 @@ bool ShieldSetWindow::load_shieldset(std::string filename)
     delete d_shieldset;
   d_shieldset = shieldset;
 
+  bool broken = false;
   d_shieldset->setBaseName(File::get_basename(autosave));
-  d_shieldset->instantiateImages();
+  d_shieldset->instantiateImages(broken);
   for(Shieldset::iterator i = d_shieldset->begin(); 
       i != d_shieldset->end(); i++)
     loadShield(*i);
