@@ -1,4 +1,4 @@
-//  Copyright (C) 2008, 2009 Ben Asselstine
+//  Copyright (C) 2008, 2009, 2010 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -40,12 +40,16 @@ class TileSetWindow: public sigc::trackable
 
     Gtk::Window &get_window() { return *window; }
 
+    sigc::signal<void, guint32> tileset_saved;
+
  private:
     Gtk::Window* window;
     std::string current_save_filename;
+    std::string autosave; //filename
     Tileset *d_tileset; //current tileset
     Tile *d_tile; //current tile
     bool needs_saving;
+    bool inhibit_needs_saving;
     Gtk::Frame *tilestyleset_frame;
     Gtk::Frame *tilestyle_frame;
     Gtk::Entry *name_entry;
@@ -66,6 +70,7 @@ class TileSetWindow: public sigc::trackable
     Gtk::MenuItem *new_tileset_menuitem;
     Gtk::MenuItem *load_tileset_menuitem;
     Gtk::MenuItem *save_tileset_menuitem;
+    Gtk::MenuItem *save_as_menuitem;
     Gtk::MenuItem *edit_tileset_info_menuitem;
     Gtk::MenuItem *roads_picture_menuitem;
     Gtk::MenuItem *bridges_picture_menuitem;
@@ -74,14 +79,14 @@ class TileSetWindow: public sigc::trackable
     Gtk::MenuItem *army_unit_selector_menuitem;
     Gtk::MenuItem *explosion_picture_menuitem;
     Gtk::MenuItem *preview_tile_menuitem;
+    Gtk::MenuItem *organize_tilestyles_menuitem;
+    Gtk::MenuItem *smallmap_building_colors_menuitem;
     Gtk::MenuItem *quit_menuitem;
     Gtk::MenuItem *help_about_menuitem;
     Gtk::ComboBoxText *tilestyle_combobox;
     Gtk::Image *tilestyle_image;
-    Gtk::FileChooserButton *image_filechooser_button;
-    Gtk::Button *refresh_button;
+    Gtk::Button *image_button;
 
-    std::vector<PixMask* > tilestyle_standard_images;
     std::vector<PixMask* > tilestyle_images;
     Gtk::Image *tilestyle_standard_image;
 
@@ -100,10 +105,9 @@ class TileSetWindow: public sigc::trackable
     class TileStyleSetsColumns: public Gtk::TreeModelColumnRecord {
     public:
 	TileStyleSetsColumns() 
-        { add(name); add(subdir); add(tilestyleset);}
+        { add(name); add(tilestyleset);}
 	
 	Gtk::TreeModelColumn<Glib::ustring> name;
-	Gtk::TreeModelColumn<Glib::ustring> subdir;
 	Gtk::TreeModelColumn<TileStyleSet *> tilestyleset;
     };
     const TileStyleSetsColumns tilestylesets_columns;
@@ -126,8 +130,6 @@ class TileSetWindow: public sigc::trackable
     TileStyleSet * get_selected_tilestyleset ();
     TileStyle * get_selected_tilestyle ();
 
-    bool inhibit_image_change;
-
     bool on_delete_event(GdkEventAny *e);
 
     void update_tile_panel();
@@ -141,7 +143,7 @@ class TileSetWindow: public sigc::trackable
     void on_new_tileset_activated();
     void on_load_tileset_activated();
     void on_save_tileset_activated();
-    void on_save_tileset_as_activated();
+    void on_save_as_activated();
     void on_quit_activated();
     bool on_window_closed(GdkEventAny *);
     bool quit();
@@ -153,6 +155,8 @@ class TileSetWindow: public sigc::trackable
     void on_fog_picture_activated();
     void on_flags_picture_activated();
     void on_preview_tile_activated();
+    void on_organize_tilestyles_activated();
+    void on_smallmap_building_colors_activated();
     void on_help_about_activated();
     void on_tile_selected();
     void on_tilestyleset_selected();
@@ -179,9 +183,17 @@ class TileSetWindow: public sigc::trackable
     void on_remove_tile_clicked();
     void on_add_tilestyleset_clicked();
     void on_remove_tilestyleset_clicked();
-    void on_refresh_clicked();
 
-    void load_tileset(std::string filename);
+    bool load_tileset(std::string filename);
+    void update_window_title();
+
+    void choose_and_add_or_replace_tilestyleset(std::string replace_filename);
+
+    void on_tilestyle_id_selected(guint32 id);
+
+    void select_tile(Tile *tile);
+    void select_tilestyleset(TileStyleSet *set);
+    void select_tilestyle(TileStyle *style);
 
 };
 
