@@ -2,7 +2,7 @@
 // Copyright (C) 2002, 2003, 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2004, 2006 Andrea Paternesi
 // Copyright (C) 2004 Bryan Duff
-// Copyright (C) 2006, 2007, 2008 Ben Asselstine
+// Copyright (C) 2006, 2007, 2008, 2011 Ben Asselstine
 // Copyright (C) 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
@@ -99,17 +99,22 @@ Fight::Fight(Stack* attacker, Stack* defender, FightType type)
     City *city = GameMap::getCity(defender->getPos());
     //Vector<int> p = defender->getPos();
 
-    if (city && city->isBurnt() == false)
+    if (city && city->isBurnt() == false && 
+        city->getOwner() == defender->getOwner())
       {
-	std::vector<Stack*> stacks = city->getDefenders();
-	for (std::vector<Stack*>::iterator it = stacks.begin(); 
-	     it != stacks.end(); it++)
-	  {
-	    Stack *s = *it;
-	    if (s == d_defenders.front())
-	      continue;
-	    d_defenders.push_back(s);
-	  }
+        /* we check the owner here because:
+         * StackInfoDialog does a fight for kicks with a neutral scout, 
+         * on the tile of the selected stack, which could be in a city.
+         */
+        std::vector<Stack*> stacks = city->getDefenders();
+        for (std::vector<Stack*>::iterator it = stacks.begin(); 
+             it != stacks.end(); it++)
+          {
+            Stack *s = *it;
+            if (s == d_defenders.front())
+              continue;
+            d_defenders.push_back(s);
+          }
       }
 	
     std::list<Stack*>::iterator it;
@@ -247,12 +252,6 @@ Fight::Result Fight::battleFromHistory()
     if (!a)
       a = findArmyById(d_defenders, f.id);
 
-    if (!a)
-      {
-	printf ("uh oh.  army id %d can't be found in the battle.\n", f.id);
-	printf ("do we have an army id of that in the stacklist anywhere?\n");
-      assert (false);
-      }
     a->damage(f.damage);
   }
   //is there anybody alive in the attackers?
@@ -587,7 +586,7 @@ void Fight::fightArmies(Fighter* attacker, Fighter* defender)
 	  defender_roll > defender->terrain_strength)
 	{
 	  //hit defender
-	  if (d_type == FOR_KEEPS)
+	  if (d_type != FOR_KEEPS)
 	    {
 	      a->setNumberHasHit(a->getNumberHasHit() + (1/xp_factor));
 	      d->setNumberHasBeenHit(d->getNumberHasBeenHit() + (1/xp_factor));
@@ -601,7 +600,7 @@ void Fight::fightArmies(Fighter* attacker, Fighter* defender)
 	       attacker_roll > attacker->terrain_strength)
 	{
 	  //hit attacker
-	  if (d_type == FOR_KEEPS)
+	  if (d_type != FOR_KEEPS)
 	    {
 	      d->setNumberHasHit(d->getNumberHasHit() + (1/xp_factor));
 	      a->setNumberHasBeenHit(a->getNumberHasBeenHit() + (1/xp_factor));
@@ -618,7 +617,7 @@ void Fight::fightArmies(Fighter* attacker, Fighter* defender)
 	    {
 	      //defender automatically wins
 	      //hit attacker for however much it takes
-	      if (d_type == FOR_KEEPS)
+	      if (d_type != FOR_KEEPS)
 		{
 		  d->setNumberHasHit(d->getNumberHasHit() + (1/xp_factor));
 		  a->setNumberHasBeenHit(a->getNumberHasBeenHit() + 
@@ -632,6 +631,7 @@ void Fight::fightArmies(Fighter* attacker, Fighter* defender)
 	}
     }
   // continue documenting the engagement
+
   item.damage = damage;
   d_actions.push_back(item);
 
