@@ -79,6 +79,8 @@ int GameClientDecoder::decodeActions(std::list<NetworkAction*> actions,
       remote_player_named.emit(action->getOwner());
     else if (action->getAction()->getType() == Action::END_TURN)
       remote_player_moved.emit((*actions.back()).getOwner());
+    else if (action->getAction()->getType() == Action::INIT_TURN)
+      remote_player_starts_move.emit((*actions.back()).getOwner());
     count++;
   }
 
@@ -102,7 +104,6 @@ void GameClientDecoder::gotActions(const std::string &payload)
   decodeActions(loader.actions, Playerlist::getActiveplayer());
 }
 
-
 int GameClientDecoder::decodeHistories(std::list<NetworkHistory *> histories)
 {
   int count = 0;
