@@ -1,4 +1,5 @@
 // Copyright (C) 2008 Ole Laursen
+// Copyright (C) 2011 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -16,6 +17,7 @@
 //  02110-1301, USA.
 
 #include <iostream>
+#include <sstream>
 #include <fstream>
 
 #include "game-client.h"
@@ -28,6 +30,7 @@
 #include "playerlist.h"
 #include "network_player.h"
 #include "xmlhelper.h"
+#include "ucompose.hpp"
   
 #include "real_player.h" 
 #include "network_player.h" 
@@ -60,16 +63,15 @@ GameClient::GameClient()
 
 GameClient::~GameClient()
 {
-  if (network_connection.get() != NULL)
-    network_connection->send(MESSAGE_TYPE_PARTICIPANT_DISCONNECT, d_nickname);
 }
 
-void GameClient::start(std::string host, guint32 port, std::string nick)
+void GameClient::start(std::string host, guint32 port, std::string profile_id, std::string nick)
 {
   d_host = host;
   d_port = port;
   player_id = -1;
   setNickname(nick);
+  setProfileId(profile_id);
   network_connection.reset(new NetworkConnection());
   network_connection->connected.connect(
     sigc::mem_fun(this, &GameClient::onConnected));
@@ -77,6 +79,8 @@ void GameClient::start(std::string host, guint32 port, std::string nick)
     sigc::mem_fun(this, &GameClient::onConnectionLost));
   network_connection->got_message.connect(
     sigc::mem_fun(this, &GameClient::onGotMessage));
+  network_connection->connection_failed.connect
+    (sigc::mem_fun(this->client_could_not_connect, &sigc::signal<void>::emit));
   network_connection->connectToHost(host, port);
 }
 
@@ -94,7 +98,7 @@ void GameClient::onConnectionLost()
 {
   std::cerr << "connection lost" << std::endl;
   if (d_connected)
-    client_disconnected.emit();
+    client_forcibly_disconnected.emit();
   else
     client_could_not_connect.emit();
 }
@@ -108,6 +112,24 @@ void GameClient::sat_down(Player *player, std::string nickname)
   player_sits.emit(player, nickname);
 }
 
+void GameClient::name_changed (Player *player, Glib::ustring name)
+{
+  if (player)
+    player_changes_name.emit(player, name);
+}
+
+void GameClient::type_changed (Player *player, int type)
+{
+  if (!player)
+    return;
+  //we don't change the type of player here.
+  //the player is networked on the remote side, and not networked 
+  //(e.g. ai_smart) on the local side.
+  //we show the "ai smart" in the game lobby, but the player object is still
+  //networked.
+  player_changes_type.emit(player, type);
+}
+
 void GameClient::stood_up(Player *player, std::string nickname)
 {
   if (!player)
@@ -118,6 +140,7 @@ void GameClient::stood_up(Player *player, std::string nickname)
       NetworkPlayer *new_p = new NetworkPlayer(*player);
       Playerlist::getInstance()->swap(player, new_p);
       delete player;
+      player = new_p;
       new_p->setConnected(false);
     }
   else if (player->getType() == Player::NETWORKED)
@@ -125,16 +148,17 @@ void GameClient::stood_up(Player *player, std::string nickname)
   player_stands.emit(player, nickname);
 }
 
-void GameClient::onGotMessage(MessageType type, std::string payload)
+bool GameClient::onGotMessage(int type, std::string payload)
 {
   std::cerr << "got message of type " << type << std::endl;
-  switch (type) {
+  switch (MessageType(type)) {
   case MESSAGE_TYPE_PING:
     network_connection->send(MESSAGE_TYPE_PONG, "PONGOGOGO");
     break;
 
   case MESSAGE_TYPE_PONG:
-    network_connection->send(MESSAGE_TYPE_PARTICIPANT_CONNECT, d_nickname);
+    network_connection->send(MESSAGE_TYPE_PARTICIPANT_CONNECT, 
+                             getNickname() + " " + getProfileId());
     break;
 
   case MESSAGE_TYPE_SENDING_ACTIONS:
@@ -146,33 +170,23 @@ void GameClient::onGotMessage(MessageType type, std::string payload)
     break;
 
   case MESSAGE_TYPE_PARTICIPANT_CONNECTED:
+    std::cerr << "message: " << type <<" has data: " << payload << std::endl;
     remote_participant_joins.emit(payload);
     break;
+
   case MESSAGE_TYPE_PARTICIPANT_DISCONNECTED:
+    std::cerr << "message: " << type <<" has data: " << payload << std::endl;
     remote_participant_departs.emit(payload);
     break;
 
+  case MESSAGE_TYPE_ROUND_OVER:
+    round_ends.emit();
+    break;
+
   case MESSAGE_TYPE_REQUEST_SEAT_MANIFEST:
-  case MESSAGE_TYPE_P1_SIT:
-  case MESSAGE_TYPE_P2_SIT:
-  case MESSAGE_TYPE_P3_SIT:
-  case MESSAGE_TYPE_P4_SIT:
-  case MESSAGE_TYPE_P5_SIT:
-  case MESSAGE_TYPE_P6_SIT:
-  case MESSAGE_TYPE_P7_SIT:
-  case MESSAGE_TYPE_P8_SIT:
-  case MESSAGE_TYPE_P1_STAND:
-  case MESSAGE_TYPE_P2_STAND:
-  case MESSAGE_TYPE_P3_STAND:
-  case MESSAGE_TYPE_P4_STAND:
-  case MESSAGE_TYPE_P5_STAND:
-  case MESSAGE_TYPE_P6_STAND:
-  case MESSAGE_TYPE_P7_STAND:
-  case MESSAGE_TYPE_P8_STAND:
   case MESSAGE_TYPE_PARTICIPANT_CONNECT:
   case MESSAGE_TYPE_PARTICIPANT_DISCONNECT:
   case MESSAGE_TYPE_CHAT:
-  case MESSAGE_TYPE_ROUND_OVER:
     //FIXME: faulty server.
     break;
 
@@ -180,61 +194,13 @@ void GameClient::onGotMessage(MessageType type, std::string payload)
     gotChatMessage("", payload);
     break;
     //this is the client realizing that some other player joined the server
-  case MESSAGE_TYPE_P1_SAT_DOWN:
-    sat_down(Playerlist::getInstance()->getPlayer(0), payload);
-    break;
-  case MESSAGE_TYPE_P2_SAT_DOWN:
-    sat_down(Playerlist::getInstance()->getPlayer(1), payload);
-    break;
-  case MESSAGE_TYPE_P3_SAT_DOWN:
-    sat_down(Playerlist::getInstance()->getPlayer(2), payload);
-    break;
-  case MESSAGE_TYPE_P4_SAT_DOWN:
-    sat_down(Playerlist::getInstance()->getPlayer(3), payload);
-    break;
-  case MESSAGE_TYPE_P5_SAT_DOWN:
-    sat_down(Playerlist::getInstance()->getPlayer(4), payload);
-    break;
-  case MESSAGE_TYPE_P6_SAT_DOWN:
-    sat_down(Playerlist::getInstance()->getPlayer(5), payload);
-    break;
-  case MESSAGE_TYPE_P7_SAT_DOWN:
-    sat_down(Playerlist::getInstance()->getPlayer(6), payload);
-    break;
-  case MESSAGE_TYPE_P8_SAT_DOWN:
-    sat_down(Playerlist::getInstance()->getPlayer(7), payload);
-    break;
-  case MESSAGE_TYPE_P1_STOOD_UP:
-    stood_up(Playerlist::getInstance()->getPlayer(0), payload);
-    break;
-  case MESSAGE_TYPE_P2_STOOD_UP:
-    stood_up(Playerlist::getInstance()->getPlayer(1), payload);
-    break;
-  case MESSAGE_TYPE_P3_STOOD_UP:
-    stood_up(Playerlist::getInstance()->getPlayer(2), payload);
-    break;
-  case MESSAGE_TYPE_P4_STOOD_UP:
-    stood_up(Playerlist::getInstance()->getPlayer(3), payload);
-    break;
-  case MESSAGE_TYPE_P5_STOOD_UP:
-    stood_up(Playerlist::getInstance()->getPlayer(4), payload);
-    break;
-  case MESSAGE_TYPE_P6_STOOD_UP:
-    stood_up(Playerlist::getInstance()->getPlayer(5), payload);
-    break;
-  case MESSAGE_TYPE_P7_STOOD_UP:
-    stood_up(Playerlist::getInstance()->getPlayer(6), payload);
-    break;
-  case MESSAGE_TYPE_P8_STOOD_UP:
-    stood_up(Playerlist::getInstance()->getPlayer(7), payload);
-    break;
 
   case MESSAGE_TYPE_SENDING_HISTORY:
     gotHistories(payload);
     break;
   
   case MESSAGE_TYPE_SERVER_DISCONNECT:
-    client_disconnected.emit();
+    return false;
     break;
 
   case MESSAGE_TYPE_TURN_ORDER:
@@ -245,12 +211,77 @@ void GameClient::onGotMessage(MessageType type, std::string payload)
     gotKillPlayer(Playerlist::getInstance()->getPlayer(atoi(payload.c_str())));
     break;
 
+  case MESSAGE_TYPE_NEXT_PLAYER:
+    start_player_turn.emit
+      (Playerlist::getInstance()->getPlayer(atoi(payload.c_str())));
+    break;
+
   case MESSAGE_TYPE_ROUND_START:
     round_begins.emit();
     break;
+
+  case MESSAGE_TYPE_CHANGE_NICKNAME:
+    nickname_changed.emit(d_nickname, payload);
+    d_nickname = payload;
+    break;
+
+  case MESSAGE_TYPE_GAME_MAY_BEGIN:
+    game_may_begin.emit();
+    break;
+
+  case MESSAGE_TYPE_OFF_PLAYER:
+    gotOffPlayer(Playerlist::getInstance()->getPlayer(atoi(payload.c_str())));
+    break;
+
+  case MESSAGE_TYPE_LOBBY_ACTIVITY:
+      {
+        guint32 id;
+        gint32 action;
+        bool reported;
+        Glib::ustring data;
+        bool success = get_message_lobby_activity (payload, id, action, 
+                                                   reported, data);
+        if (success)
+          {
+            if (reported)
+              {
+                switch (action)
+                  {
+                  case LOBBY_MESSAGE_TYPE_SIT:
+                    sat_down(Playerlist::getInstance()->getPlayer(id), data);
+                    break;
+                  case LOBBY_MESSAGE_TYPE_STAND:
+                    stood_up(Playerlist::getInstance()->getPlayer(id), data);
+                    break;
+                  case LOBBY_MESSAGE_TYPE_CHANGE_NAME:
+                    name_changed(Playerlist::getInstance()->getPlayer(id), 
+                                 data);
+                    break;
+                  case LOBBY_MESSAGE_TYPE_CHANGE_TYPE:
+                    type_changed(Playerlist::getInstance()->getPlayer(id), 
+                                 atoi(data.c_str()));
+                    break;
+                  default:
+                    break;
+                  }
+              }
+          }
+      }
+    break;
   }
+  return true;
 }
 
+void GameClient::gotOffPlayer(Player *player)
+{
+  player_gets_turned_off.emit(player);
+  GameParameters::Player p;
+  p.id = player->getId();
+  p.type = GameParameters::Player::OFF;
+  p.name = player->getName();
+  Playerlist::getInstance()->syncPlayer(p);
+}  
+
 void GameClient::gotKillPlayer(Player *player)
 {
   player->kill();
@@ -300,7 +331,7 @@ void GameClient::sendActions()
 
   helper.closeTag();
 
-  std::cerr << "sending actions" << std::endl;
+  //std::cerr << "sending actions" << std::endl;
   network_connection->send(MESSAGE_TYPE_SENDING_ACTIONS, os.str());
 }
 
@@ -321,57 +352,62 @@ void GameClient::sendHistories()
   network_connection->send(MESSAGE_TYPE_SENDING_HISTORY, os.str());
 }
 
-void GameClient::sit_down (Player *player)
+void GameClient::sit_or_stand (Player *player, bool sit)
 {
   if (!player)
     return;
-  MessageType type;
-  switch (player->getId())
+  Glib::ustring payload = 
+    String::ucompose("%1 %2 %3 %4", player->getId(), 
+                     sit ? LOBBY_MESSAGE_TYPE_SIT : LOBBY_MESSAGE_TYPE_STAND, 
+                     0, 
+                     d_nickname);
+  network_connection->send(MESSAGE_TYPE_LOBBY_ACTIVITY, payload);
+  if (sit)
     {
-    case 0: type = MESSAGE_TYPE_P1_SIT; break;
-    case 1: type = MESSAGE_TYPE_P2_SIT; break;
-    case 2: type = MESSAGE_TYPE_P3_SIT; break;
-    case 3: type = MESSAGE_TYPE_P4_SIT; break;
-    case 4: type = MESSAGE_TYPE_P5_SIT; break;
-    case 5: type = MESSAGE_TYPE_P6_SIT; break;
-    case 6: type = MESSAGE_TYPE_P7_SIT; break;
-    case 7: type = MESSAGE_TYPE_P8_SIT; break;
-    default:
-	    return;
+      RealPlayer *new_p = new RealPlayer (*player);
+      Playerlist::getInstance()->swap(player, new_p);
+      stopListeningForLocalEvents(player);
+      listenForLocalEvents(new_p);
+      delete player;
+      payload = String::ucompose("%1 %2 %3 %4", new_p->getId(), 
+                     LOBBY_MESSAGE_TYPE_CHANGE_TYPE, 0, new_p->getType());
+      network_connection->send(MESSAGE_TYPE_LOBBY_ACTIVITY, payload);
     }
-  RealPlayer *new_p = new RealPlayer (*player);
-  Playerlist::getInstance()->swap(player, new_p);
-  stopListeningForLocalEvents(player);
-  listenForLocalEvents(new_p);
-  delete player;
-  network_connection->send(type, d_nickname);
+  else
+    {
+      NetworkPlayer *new_p = new NetworkPlayer(*player);
+      Playerlist::getInstance()->swap(player, new_p);
+      stopListeningForLocalEvents(player);
+      delete player;
+      new_p->setConnected(false);
+    }
+
+}
+
+void GameClient::change_name (Player *player, Glib::ustring name)
+{
+  Glib::ustring payload = 
+    String::ucompose("%1 %2 %3 %4", player->getId(), 
+                     LOBBY_MESSAGE_TYPE_CHANGE_NAME, 0, name);
+  network_connection->send(MESSAGE_TYPE_LOBBY_ACTIVITY, payload);
+}
+
+void GameClient::change_type (Player *player, int type)
+{
+  Glib::ustring payload = 
+    String::ucompose("%1 %2 %3 %4", player->getId(), 
+                     LOBBY_MESSAGE_TYPE_CHANGE_TYPE, 0, type);
+  network_connection->send(MESSAGE_TYPE_LOBBY_ACTIVITY, payload);
+}
+
+void GameClient::sit_down (Player *player)
+{
+  sit_or_stand (player, true);
 }
 
 void GameClient::stand_up (Player *player)
 {
-  if (!player)
-    return;
-  MessageType type;
-  switch (player->getId())
-    {
-    case 0: type = MESSAGE_TYPE_P1_STAND; break;
-    case 1: type = MESSAGE_TYPE_P2_STAND; break;
-    case 2: type = MESSAGE_TYPE_P3_STAND; break;
-    case 3: type = MESSAGE_TYPE_P4_STAND; break;
-    case 4: type = MESSAGE_TYPE_P5_STAND; break;
-    case 5: type = MESSAGE_TYPE_P6_STAND; break;
-    case 6: type = MESSAGE_TYPE_P7_STAND; break;
-    case 7: type = MESSAGE_TYPE_P8_STAND; break;
-    default:
-	    return;
-    }
-  //now turning a human player into a network player
-  NetworkPlayer *new_p = new NetworkPlayer(*player);
-  Playerlist::getInstance()->swap(player, new_p);
-  stopListeningForLocalEvents(new_p);
-  delete player;
-  new_p->setConnected(false);
-  network_connection->send(type, d_nickname);
+  sit_or_stand (player, false);
 }
 
 void GameClient::chat(std::string message)
@@ -396,13 +432,15 @@ void GameClient::gotTurnOrder (std::string payload)
       ival = -1;
       players >> ival;
       if (ival != -1)
-	player_ids.push_back(ival);
+        player_ids.push_back(ival);
     }
   Playerlist::getInstance()->reorder(player_ids);
   playerlist_reorder_received.emit();
 }
 
-void GameClient::sendRoundOver()
+void GameClient::disconnect()
 {
-  network_connection->send(MESSAGE_TYPE_ROUND_OVER, "");
+  d_connected = false;
+  if (network_connection.get() != NULL)
+    network_connection->send(MESSAGE_TYPE_PARTICIPANT_DISCONNECT, d_nickname);
 }
