@@ -1,5 +1,5 @@
 // Copyright (C) 2008 Ole Laursen
-// Copyright (C) 2008 Ben Asselstine
+// Copyright (C) 2008, 2011 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -34,23 +34,25 @@
 #include "network_player.h"
 #include "real_player.h"
 #include "GameScenarioOptions.h"
-
+#include "ucompose.hpp"
+#include "game-parameters.h"
 
 class NetworkAction;
 
 struct Participant
 {
   void *conn;
-  std::list<guint32> players;
+  std::list<GameParameters::Player> players;
+  std::map<guint32, bool> id_end_turn;
   std::list<NetworkAction *> actions;
   std::list<NetworkHistory *> histories;
   std::string nickname;
-  bool round_finished;
+  bool departed;
+  std::string profile_id;
 };
 
 GameServer * GameServer::s_instance = 0;
 
-
 GameServer* GameServer::getInstance()
 {
     if (s_instance == 0)
@@ -70,10 +72,52 @@ void GameServer::deleteInstance()
 
 GameServer::GameServer()
 {
+  d_game_has_begun = false;
+
+  remote_player_moved.connect
+    (sigc::mem_fun(*this, &GameServer::on_player_finished_turn));
+  local_player_moved.connect
+    (sigc::mem_fun(*this, &GameServer::on_player_finished_turn));
 }
 
-GameServer::~GameServer()
+void GameServer::notifyRoundOver()
 {
+  for (std::list<Participant *>::iterator i = participants.begin(),
+       end = participants.end(); i != end; ++i) 
+    network_server->send((*i)->conn, MESSAGE_TYPE_ROUND_OVER, "");
+}
+
+bool GameServer::check_end_of_round()
+{
+  if (Playerlist::getInstance()->getNeutral()->hasAlreadyEndedTurn())
+    {
+      Playerlist::getInstance()->getNeutral()->clearActionlist();
+      notifyRoundOver();
+      round_ends.emit();
+      return true;
+    }
+  return false;
+}
+
+void GameServer::on_player_finished_turn(Player *player)
+{
+  if (check_end_of_round() == false)
+    {
+      //if the end of turn is asynchronous, start a new turn from here
+      //otherwise, just fall through back to the nextTurn method, and it's 
+      //inner loop.
+      if (player->getType() == Player::HUMAN ||
+          player->getType() == Player::NETWORKED)
+        {
+          if (nextTurn())
+            on_player_finished_turn(Playerlist::getInstance()->getNeutral());
+        }
+    }
+}
+
+void GameServer::remove_all_participants()
+{
+  stopListeningForLocalEvents();
   //say goodbye to all participants
   for (std::list<Participant *>::iterator i = participants.begin(),
          end = participants.end(); i != end; ++i)
@@ -82,9 +126,20 @@ GameServer::~GameServer()
   for (std::list<Participant *>::iterator i = participants.begin(),
          end = participants.end(); i != end; ++i)
     delete *i;
+  participants.clear();
   players_seated_locally.clear();
 }
 
+GameServer::~GameServer()
+{
+  if (network_server.get() != NULL)
+    {
+      if (network_server->isListening())
+        network_server->stop();
+    }
+  remove_all_participants();
+}
+
 bool GameServer::isListening()
 {
   if (network_server.get() != NULL)
@@ -93,14 +148,17 @@ bool GameServer::isListening()
     return false;
 }
 
-void GameServer::start(GameScenario *game_scenario, int port, std::string nick)
+void GameServer::start(GameScenario *game_scenario, int port, std::string profile_id, std::string nick)
 {
   setGameScenario(game_scenario);
   setNickname(nick);
+  setProfileId(profile_id);
 
   if (network_server.get() != NULL && network_server->isListening())
     return;
   network_server.reset(new NetworkServer());
+  network_server->port_in_use.connect
+    (sigc::mem_fun(port_in_use, &sigc::signal<void, int>::emit));
   network_server->got_message.connect
     (sigc::mem_fun(this, &GameServer::onGotMessage));
   network_server->connection_lost.connect
@@ -111,48 +169,78 @@ void GameServer::start(GameScenario *game_scenario, int port, std::string nick)
   network_server->startListening(port);
 
   listenForLocalEvents(Playerlist::getInstance()->getNeutral());
+  Playerlist *pl = Playerlist::getInstance();
+  for (Playerlist::iterator it = pl->begin(); it != pl->end(); it++)
+    if ((*it)->getType() == Player::NETWORKED)
+      listenForLocalEvents(*it);
 }
 
-void GameServer::checkRoundOver()
+bool GameServer::sendNextPlayer()
 {
-  bool all_finished = true;
+  Glib::ustring s = 
+    String::ucompose("%1", Playerlist::getActiveplayer()->getId());
+  //now we can send the start round message, and begin the round ourselves.
   for (std::list<Participant *>::iterator i = participants.begin(),
        end = participants.end(); i != end; ++i)
-    {
-      if ((*i)->round_finished == false)
-	{
-	  all_finished = false;
-	  break;
-	}
-    }
-
-  if (all_finished)
-    {
-      printf ("hooray!  we're all done the round.\n");
-      for (std::list<Participant *>::iterator i = participants.begin(),
-	   end = participants.end(); i != end; ++i)
-	(*i)->round_finished = false;
-
-      //now we can send the start round message, and begin the round ourselves.
-      for (std::list<Participant *>::iterator i = participants.begin(),
-	   end = participants.end(); i != end; ++i)
-	network_server->send((*i)->conn, MESSAGE_TYPE_ROUND_START, "");
-
-      round_begins.emit();
-    }
+    network_server->send((*i)->conn, MESSAGE_TYPE_NEXT_PLAYER, s);
+  Participant *part = findParticipantByPlayerId
+    (Playerlist::getActiveplayer()->getId());
+  if (!part)
+    return false;
+  return true;
 }
 
-void GameServer::gotRoundOver(void *conn)
+bool GameServer::nextTurn()
 {
-  Participant *part = findParticipantByConn(conn);
-  if (part)
+  while (1)
     {
-      //mark the participant as finished for this round
-      part->round_finished = true;
-      //are all participants finished?
-      checkRoundOver();
+      Player *p = get_next_player.emit();
+      if (p)
+        {
+          if (p->getType() == Player::NETWORKED)
+            {
+              bool player_available = sendNextPlayer();
+              if (!player_available)
+                {
+                  ; //now what?
+                }
+              //we do this anyway, to update our local turn shield
+                  start_player_turn.emit(p);
+              break; //now it goes to on_player_finished_turn if player avail.
+            }
+          else
+            {
+              sendNextPlayer();
+              if (p->getType() == Player::HUMAN)
+                {
+                  start_player_turn.emit(p);
+                  break;
+                }
+              else if (p->getType() == Player::AI_DUMMY)
+                {
+                  start_player_turn.emit(p);
+                  return true;
+                }
+              else
+                start_player_turn.emit(p);
+            }
+        }
+      else
+        break;
     }
-  return;
+  return false;
+}
+
+bool GameServer::sendRoundStart()
+{
+  sendTurnOrder();
+  //now we can send the start round message, and begin the round ourselves.
+  for (std::list<Participant *>::iterator i = participants.begin(),
+       end = participants.end(); i != end; ++i)
+    network_server->send((*i)->conn, MESSAGE_TYPE_ROUND_START, "");
+  round_begins.emit();
+  Playerlist::getInstance()->setActiveplayer(NULL);
+  return nextTurn();
 }
 
 void GameServer::gotChat(void *conn, std::string message)
@@ -175,10 +263,12 @@ void GameServer::gotChat(void *conn, std::string message)
     }
   return;
 }
-void GameServer::onGotMessage(void *conn, MessageType type, std::string payload)
+
+    
+bool GameServer::onGotMessage(void *conn, int type, std::string payload)
 {
-  std::cerr << "got message of type " << type << std::endl;
-  switch (type) {
+  //std::cerr << "got message of type " << type << std::endl;
+  switch (MessageType(type)) {
   case MESSAGE_TYPE_PING:
     std::cerr << "sending pong" << std::endl;
     network_server->send(conn, MESSAGE_TYPE_PONG, "");
@@ -204,72 +294,10 @@ void GameServer::onGotMessage(void *conn, MessageType type, std::string payload)
     break;
 
   case MESSAGE_TYPE_REQUEST_SEAT_MANIFEST:
-    sendSeats(conn);
     sendChatRoster(conn);
-    break;
-
-  case MESSAGE_TYPE_P1_SIT:
-    sit(conn, Playerlist::getInstance()->getPlayer(0), payload);
-    break;
-
-  case MESSAGE_TYPE_P2_SIT:
-    sit(conn, Playerlist::getInstance()->getPlayer(1), payload);
-    break;
-
-  case MESSAGE_TYPE_P3_SIT:
-    sit(conn, Playerlist::getInstance()->getPlayer(2), payload);
-    break;
-
-  case MESSAGE_TYPE_P4_SIT:
-    sit(conn, Playerlist::getInstance()->getPlayer(3), payload);
-    break;
-
-  case MESSAGE_TYPE_P5_SIT:
-    sit(conn, Playerlist::getInstance()->getPlayer(4), payload);
-    break;
-
-  case MESSAGE_TYPE_P6_SIT:
-    sit(conn, Playerlist::getInstance()->getPlayer(5), payload);
-    break;
-
-  case MESSAGE_TYPE_P7_SIT:
-    sit(conn, Playerlist::getInstance()->getPlayer(6), payload);
-    break;
-
-  case MESSAGE_TYPE_P8_SIT:
-    sit(conn, Playerlist::getInstance()->getPlayer(7), payload);
-    break;
-
-  case MESSAGE_TYPE_P1_STAND:
-    stand(conn, Playerlist::getInstance()->getPlayer(0), payload);
-    break;
-
-  case MESSAGE_TYPE_P2_STAND:
-    stand(conn, Playerlist::getInstance()->getPlayer(1), payload);
-    break;
-
-  case MESSAGE_TYPE_P3_STAND:
-    stand(conn, Playerlist::getInstance()->getPlayer(2), payload);
-    break;
-
-  case MESSAGE_TYPE_P4_STAND:
-    stand(conn, Playerlist::getInstance()->getPlayer(3), payload);
-    break;
-
-  case MESSAGE_TYPE_P5_STAND:
-    stand(conn, Playerlist::getInstance()->getPlayer(4), payload);
-    break;
-
-  case MESSAGE_TYPE_P6_STAND:
-    stand(conn, Playerlist::getInstance()->getPlayer(5), payload);
-    break;
-
-  case MESSAGE_TYPE_P7_STAND:
-    stand(conn, Playerlist::getInstance()->getPlayer(6), payload);
-    break;
-
-  case MESSAGE_TYPE_P8_STAND:
-    stand(conn, Playerlist::getInstance()->getPlayer(7), payload);
+    sendSeats(conn);
+    if (gameHasBegun())
+      network_server->send(conn, MESSAGE_TYPE_GAME_MAY_BEGIN, "");
     break;
 
   case MESSAGE_TYPE_PARTICIPANT_DISCONNECT:
@@ -285,36 +313,61 @@ void GameServer::onGotMessage(void *conn, MessageType type, std::string payload)
 
   case MESSAGE_TYPE_ROUND_OVER:
     //what do we do now?
-    gotRoundOver(conn);
+    break;
+
+  case MESSAGE_TYPE_LOBBY_ACTIVITY:
+      {
+        guint32 id;
+        gint32 action;
+        bool reported;
+        Glib::ustring data;
+        bool success = 
+          get_message_lobby_activity (payload, id, action, reported, data);
+        if (success)
+          {
+            if (reported == false) //player is /reporting/
+              {
+                switch (action)
+                  {
+                  case LOBBY_MESSAGE_TYPE_SIT:
+                    sit(conn, Playerlist::getInstance()->getPlayer(id), data);
+                    break;
+                  case LOBBY_MESSAGE_TYPE_STAND:
+                    stand(conn, Playerlist::getInstance()->getPlayer(id), data);
+                    break;
+                  case LOBBY_MESSAGE_TYPE_CHANGE_NAME:
+                    change_name(conn, 
+                                Playerlist::getInstance()->getPlayer(id), data);
+                    break;
+                  case LOBBY_MESSAGE_TYPE_CHANGE_TYPE:
+                    change_type(conn, 
+                                Playerlist::getInstance()->getPlayer(id), 
+                                atoi(data.c_str()));
+                    break;
+                  default:
+                    break;
+                  }
+              }
+          }
+      }
     break;
 
   case MESSAGE_TYPE_PARTICIPANT_DISCONNECTED:
     break;
 
-  case MESSAGE_TYPE_P1_SAT_DOWN:
-  case MESSAGE_TYPE_P2_SAT_DOWN:
-  case MESSAGE_TYPE_P3_SAT_DOWN:
-  case MESSAGE_TYPE_P4_SAT_DOWN:
-  case MESSAGE_TYPE_P5_SAT_DOWN:
-  case MESSAGE_TYPE_P6_SAT_DOWN:
-  case MESSAGE_TYPE_P7_SAT_DOWN:
-  case MESSAGE_TYPE_P8_SAT_DOWN:
-  case MESSAGE_TYPE_P1_STOOD_UP:
-  case MESSAGE_TYPE_P2_STOOD_UP:
-  case MESSAGE_TYPE_P3_STOOD_UP:
-  case MESSAGE_TYPE_P4_STOOD_UP:
-  case MESSAGE_TYPE_P5_STOOD_UP:
-  case MESSAGE_TYPE_P6_STOOD_UP:
-  case MESSAGE_TYPE_P7_STOOD_UP:
-  case MESSAGE_TYPE_P8_STOOD_UP:
   case MESSAGE_TYPE_SERVER_DISCONNECT:
   case MESSAGE_TYPE_CHATTED:
   case MESSAGE_TYPE_TURN_ORDER:
   case MESSAGE_TYPE_KILL_PLAYER:
   case MESSAGE_TYPE_ROUND_START:
+  case MESSAGE_TYPE_CHANGE_NICKNAME:
+  case MESSAGE_TYPE_GAME_MAY_BEGIN:
+  case MESSAGE_TYPE_OFF_PLAYER:
+  case MESSAGE_TYPE_NEXT_PLAYER:
     //faulty client
     break;
   }
+  return true;
 }
 
 void GameServer::onConnectionMade(void *conn)
@@ -329,16 +382,17 @@ void GameServer::onConnectionLost(void *conn)
   Participant *part = findParticipantByConn(conn);
   if (part)
     {
-      std::list<guint32> players_to_stand = part->players;
+      std::list<GameParameters::Player> players_to_stand = part->players;
 
       depart(conn);
       participants.remove(part);
-      for (std::list<guint32>::iterator it = players_to_stand.begin();
-	   it != players_to_stand.end(); it++)
-	notifyStand(Playerlist::getInstance()->getPlayer(*it), d_nickname);
+      //tell everybode else that we've just stood up.
+      for (std::list<GameParameters::Player>::iterator i = 
+           players_to_stand.begin(); i != players_to_stand.end(); i++)
+	notifyStand(Playerlist::getInstance()->getPlayer((*i).id), d_nickname);
       remote_participant_disconnected.emit();
+      delete part;
     }
-  delete part;
 }
 
 Participant *GameServer::findParticipantByConn(void *conn)
@@ -351,30 +405,46 @@ Participant *GameServer::findParticipantByConn(void *conn)
   return 0;
 }
 
-void GameServer::onActionDone(NetworkAction *action)
+void GameServer::onLocalNonNetworkedActionDone(NetworkAction *action)
 {
   std::string desc = action->toString();
-  std::cerr << "Game Server got " << desc <<"\n";
+  std::cerr << "Game Server got " << Action::actionTypeToString(action->getAction()->getType()) << " "<< desc <<"\n";
 
   if (action->getAction()->getType() == Action::END_TURN)
-    local_player_moved(action->getOwner());
+    local_player_moved.emit(action->getOwner());
   if (action->getAction()->getType() == Action::INIT_TURN)
-    local_player_starts_move(action->getOwner());
+    local_player_starts_move.emit(action->getOwner());
 
   for (std::list<Participant *>::iterator i = participants.begin(),
        end = participants.end(); i != end; ++i) 
     {
-      (*i)->actions.push_back(action);
+      (*i)->actions.push_back(new NetworkAction (action->getAction(),
+                                                 action->getOwnerId()));
       sendActions(*i);
       clearNetworkActionlist((*i)->actions);
     }
 
+  //do it here.
+  delete action;
 }
 
-void GameServer::onHistoryDone(NetworkHistory *history)
+void GameServer::onActionDone(NetworkAction *action)
+{
+  if (d_stop)
+    return;
+  Player *p = Playerlist::getInstance()->getPlayer(action->getOwnerId());
+  if (p->getType() != Player::NETWORKED)
+    onLocalNonNetworkedActionDone(action);
+  else
+    ;//we don't want anything to do with actions generated by the local
+  //networked player.
+
+}
+
+void GameServer::onLocalNonNetworkedHistoryDone(NetworkHistory *history)
 {
   std::string desc = history->toString();
-  std::cerr << "Game Server got " << desc <<"\n";
+  std::cerr << "Game Server got " << History::historyTypeToString(history->getHistory()->getType())<< " " << desc <<"\n";
 
   if (history->getHistory()->getType() == History::PLAYER_VANQUISHED)
     local_player_died(history->getOwner());
@@ -382,10 +452,47 @@ void GameServer::onHistoryDone(NetworkHistory *history)
   for (std::list<Participant *>::iterator i = participants.begin(),
        end = participants.end(); i != end; ++i) 
     {
-      (*i)->histories.push_back(history);
+      (*i)->histories.push_back (new NetworkHistory (history->getHistory(), 
+                                                     history->getOwnerId()));
       sendHistories(*i);
       clearNetworkHistorylist((*i)->histories);
     }
+  delete history;
+}
+
+void GameServer::onLocalNetworkedHistoryDone(NetworkHistory *history)
+{
+  //okay we only care about two locally generated history events.
+  std::string desc = history->toString();
+
+  for (std::list<Participant *>::iterator i = participants.begin(),
+       end = participants.end(); i != end; ++i) 
+    {
+      (*i)->histories.push_back (new NetworkHistory (history->getHistory(), 
+                                                     history->getOwnerId()));
+      if (history->getHistory()->getType() == History::GOLD_TOTAL ||
+          history->getHistory()->getType() == History::SCORE)
+        {
+          std::cerr << "Game Server got locally generated networked history event: " << desc <<"\n";
+          sendHistories(*i);
+        }
+      else
+        {
+          std::cerr << "Game Server got locally generated networked history event but not sending: " << desc <<"\n";
+        }
+
+      clearNetworkHistorylist((*i)->histories);
+    }
+  delete history;
+}
+
+void GameServer::onHistoryDone(NetworkHistory *history)
+{
+  Player *p = Playerlist::getInstance()->getPlayer(history->getOwnerId());
+  if (p->getType() != Player::NETWORKED)
+    onLocalNonNetworkedHistoryDone(history);
+  else
+    onLocalNetworkedHistoryDone(history);
 }
 
 void GameServer::notifyJoin(std::string nickname)
@@ -422,26 +529,15 @@ void GameServer::notifySit(Player *player, std::string nickname)
 {
   if (!player)
     return;
+  Glib::ustring payload = 
+    String::ucompose("%1 %2 %3 %4", player->getId(), LOBBY_MESSAGE_TYPE_SIT, 
+                     1, nickname);
   player_sits.emit(player, nickname);
-  MessageType type;
-  switch (player->getId())
-    {
-    case 0: type = MESSAGE_TYPE_P1_SAT_DOWN; break;
-    case 1: type = MESSAGE_TYPE_P2_SAT_DOWN; break;
-    case 2: type = MESSAGE_TYPE_P3_SAT_DOWN; break;
-    case 3: type = MESSAGE_TYPE_P4_SAT_DOWN; break;
-    case 4: type = MESSAGE_TYPE_P5_SAT_DOWN; break;
-    case 5: type = MESSAGE_TYPE_P6_SAT_DOWN; break;
-    case 6: type = MESSAGE_TYPE_P7_SAT_DOWN; break;
-    case 7: type = MESSAGE_TYPE_P8_SAT_DOWN; break;
-    default:
-	    return;
-    }
 
   for (std::list<Participant *>::iterator i = participants.begin(),
        end = participants.end(); i != end; ++i) 
     {
-      network_server->send((*i)->conn, type, nickname);
+      network_server->send((*i)->conn, MESSAGE_TYPE_LOBBY_ACTIVITY, payload);
       network_server->send((*i)->conn, MESSAGE_TYPE_CHATTED, 
 			   nickname + " assumes control of " + 
 			   player->getName() +".");
@@ -450,34 +546,141 @@ void GameServer::notifySit(Player *player, std::string nickname)
 		 player->getName() +".");
 }
 
-void GameServer::join(void *conn, std::string nickname)
+void GameServer::notifyTypeChange(Player *player, int type)
+{
+  if (!player)
+    return;
+  Glib::ustring payload = 
+    String::ucompose("%1 %2 %3 %4", player->getId(), 
+                     LOBBY_MESSAGE_TYPE_CHANGE_TYPE, 1, type);
+  player_changes_type.emit(player, type);
+
+  for (std::list<Participant *>::iterator i = participants.begin(),
+       end = participants.end(); i != end; ++i) 
+    {
+      network_server->send((*i)->conn, MESSAGE_TYPE_LOBBY_ACTIVITY, payload);
+    }
+}
+
+void GameServer::notifyNameChange(Player *player, Glib::ustring name)
+{
+  if (!player)
+    return;
+  Glib::ustring payload = 
+    String::ucompose("%1 %2 %3 %4", player->getId(), 
+                     LOBBY_MESSAGE_TYPE_CHANGE_NAME, 1, name);
+  player_changes_name.emit(player, name);
+
+  for (std::list<Participant *>::iterator i = participants.begin(),
+       end = participants.end(); i != end; ++i) 
+    {
+      network_server->send((*i)->conn, MESSAGE_TYPE_LOBBY_ACTIVITY, payload);
+    }
+}
+
+Participant *GameServer::findParticipantByPlayerId(guint32 id)
+{
+  for (std::list<Participant *>::iterator i = participants.begin(),
+       end = participants.end(); i != end; ++i)
+    {
+      for (std::list<GameParameters::Player>::iterator j = 
+           (*i)->players.begin(); j != (*i)->players.end(); j++)
+        {
+          if ((*j).id == id)
+            return *i;
+        }
+    }
+
+  return 0;
+}
+
+Participant *GameServer::findParticipantByNick(Glib::ustring nickname)
+{
+  for (std::list<Participant *>::iterator i = participants.begin(),
+       end = participants.end(); i != end; ++i)
+    if ((*i)->nickname == nickname)
+      return *i;
+
+  return 0;
+}
+
+Glib::ustring GameServer::make_nickname_unique(Glib::ustring nickname)
+{
+  Glib::ustring new_nickname;
+  int count = 0;
+  //okay, does this nickname appear twice?
+  for (std::list<Participant *>::iterator i = participants.begin(),
+       end = participants.end(); i != end; ++i)
+    {
+      if ((*i)->nickname == nickname)
+        count++;
+    }
+  if (nickname == d_nickname)
+    count++;
+  if (count <= 1)
+    return nickname;
+  count = 2;
+  while (1)
+    {
+      new_nickname = String::ucompose("%1-%2", nickname, count);
+      Participant *part = findParticipantByNick(new_nickname);
+      if (!part)
+        break;
+      count++;
+      if (count == 1000)
+        break;
+    }
+  if (count == 1000)
+    return "";
+  return new_nickname;
+}
+
+void GameServer::join(void *conn, std::string nickname_and_profile_id)
 {
   bool new_participant = false;
   std::cout << "JOIN: " << conn << std::endl;
 
+  size_t pos;
+  pos = nickname_and_profile_id.rfind(' ');
+  if (pos == std::string::npos)
+    return;
+  std::string nickname = nickname_and_profile_id.substr(0, pos);
+  std::string profile_id = nickname_and_profile_id.substr(pos + 1);
   Participant *part = findParticipantByConn(conn);
   if (!part) {
     part = new Participant;
     part->conn = conn;
     part->nickname = nickname;
+    part->profile_id = profile_id;
     participants.push_back(part);
+    part->departed = false;
     new_participant = true;
   }
   if (new_participant)
-    {
-      sendMap(part);
-    }
+    sendMap(part);
 
-  notifyJoin(nickname);
+  Glib::ustring new_nickname = make_nickname_unique(nickname);
+  if (new_nickname != "")
+    {
+      if (new_nickname != nickname)
+        {
+          part->nickname = new_nickname;
+          network_server->send(conn, MESSAGE_TYPE_CHANGE_NICKNAME, 
+                               new_nickname);
+        }
+      notifyJoin(new_nickname);
+    }
 }
 
 void GameServer::depart(void *conn)
 {
-  std::cout << "DEPART: " << conn << std::endl;
-
   Participant *part = findParticipantByConn(conn);
-
-  notifyDepart(conn, part->nickname);
+  if (part && part->departed == false)
+    {
+      std::cout << "DEPART: " << conn << std::endl;
+      notifyDepart(conn, part->nickname);
+      part->departed = true;
+    }
   //we don't delete the participant, it gets deleted when it disconnects.
   //see onConnectionLost
 }
@@ -488,10 +691,10 @@ bool GameServer::player_already_sitting(Player *p)
   for (std::list<Participant *>::iterator i = participants.begin(),
        end = participants.end(); i != end; ++i) 
     {
-      for (std::list<guint32>::iterator j = (*i)->players.begin(); 
-	   j != (*i)->players.end(); j++)
+      for (std::list<GameParameters::Player>::iterator j = 
+           (*i)->players.begin(); j != (*i)->players.end(); j++)
 	{
-	  if (p->getId() == *j)
+	  if (p->getId() == (*j).id)
 	    return true;
 	}
     }
@@ -508,11 +711,15 @@ void GameServer::sit(void *conn, Player *player, std::string nickname)
   if (!part) 
     return;
 
-  //fixme: is another player already sitting here?
   if (player_already_sitting(player) == true)
     return;
 
-  add_to_player_list(part->players, player->getId());
+  //is this player already locally instantiated as an ai or human player?
+  if (player->getType() != Player::NETWORKED)
+    return;
+
+  add_to_player_list(part->players, player->getId(), player->getName(),
+                     GameParameters::player_type_to_player_param(player->getType()));
 
   if (player)
     dynamic_cast<NetworkPlayer*>(player)->setConnected(true);
@@ -520,30 +727,47 @@ void GameServer::sit(void *conn, Player *player, std::string nickname)
   notifySit(player, nickname);
 }
 
+void GameServer::change_name(void *conn, Player *player, Glib::ustring name)
+{
+  std::cout << "CHANGE NAME: " << conn << " " << player << " " << name << std::endl;
+
+  if (!player || !conn)
+    return;
+  Participant *part = findParticipantByConn(conn);
+  if (!part) 
+    return;
+
+  update_player_name (part->players, player->getId(), name);
+  name_change(player, name);
+}
+
+void GameServer::change_type(void *conn, Player *player, int type)
+{
+  std::cout << "CHANGE TYPE: " << conn << " " << player << " " << type << std::endl;
+
+  if (!player || !conn)
+    return;
+  Participant *part = findParticipantByConn(conn);
+  if (!part) 
+    return;
+
+  update_player_type (part->players, player->getId(), (guint32) type);
+  notifyTypeChange(player, type);
+}
+
 void GameServer::notifyStand(Player *player, std::string nickname)
 {
   if (!player)
     return;
+  Glib::ustring payload = 
+    String::ucompose("%1 %2 %3 %4", player->getId(), 
+                     LOBBY_MESSAGE_TYPE_STAND, 1, nickname);
   player_stands.emit(player, nickname);
-  MessageType type;
-  switch (player->getId())
-    {
-    case 0: type = MESSAGE_TYPE_P1_STOOD_UP; break;
-    case 1: type = MESSAGE_TYPE_P2_STOOD_UP; break;
-    case 2: type = MESSAGE_TYPE_P3_STOOD_UP; break;
-    case 3: type = MESSAGE_TYPE_P4_STOOD_UP; break;
-    case 4: type = MESSAGE_TYPE_P5_STOOD_UP; break;
-    case 5: type = MESSAGE_TYPE_P6_STOOD_UP; break;
-    case 6: type = MESSAGE_TYPE_P7_STOOD_UP; break;
-    case 7: type = MESSAGE_TYPE_P8_STOOD_UP; break;
-    default:
-	    return;
-    }
 
   for (std::list<Participant *>::iterator i = participants.begin(),
        end = participants.end(); i != end; ++i) 
     {
-      network_server->send((*i)->conn, type, nickname);
+      network_server->send((*i)->conn, MESSAGE_TYPE_LOBBY_ACTIVITY, payload);
       network_server->send((*i)->conn, MESSAGE_TYPE_CHATTED, 
 			   nickname + " relinquishes control of " + 
 			   player->getName() +".");
@@ -553,30 +777,70 @@ void GameServer::notifyStand(Player *player, std::string nickname)
 }
 
 bool
-GameServer::add_to_player_list(std::list<guint32> &list, guint32 id)
+GameServer::update_player_type (std::list<GameParameters::Player> &list, guint32 id, guint32 type)
 {
   bool found = false;
-  for (std::list<guint32>::iterator i = list.begin(); i != list.end(); i++)
+  for (std::list<GameParameters::Player>::iterator i = list.begin(); i != list.end(); i++)
     {
-      if (*i == id)
+      if ((*i).id == id)
 	{
 	  found = true;
+          (*i).type = GameParameters::Player::Type(type);
 	  break;
 	}
     }
-  if (found == false)
-    list.push_back(id);
   return found;
 }
 
 bool
-GameServer::remove_from_player_list(std::list<guint32> &list, guint32 id)
+GameServer::update_player_name (std::list<GameParameters::Player> &list, guint32 id, Glib::ustring name)
+{
+  bool found = false;
+  for (std::list<GameParameters::Player>::iterator i = list.begin(); i != list.end(); i++)
+    {
+      if ((*i).id == id)
+	{
+	  found = true;
+          (*i).name = name;
+	  break;
+	}
+    }
+  return found;
+}
+
+bool
+GameServer::add_to_player_list(std::list<GameParameters::Player> &list, guint32 id, Glib::ustring name, guint32 type)
+{
+  bool found = false;
+  for (std::list<GameParameters::Player>::iterator i = list.begin(); i != list.end(); i++)
+    {
+      if ((*i).id == id)
+	{
+	  found = true;
+          (*i).type = GameParameters::Player::Type(type);
+          (*i).name = name;
+	  break;
+	}
+    }
+  if (found == false)
+    {
+      GameParameters::Player p;
+      p.id = id;
+      p.type = GameParameters::Player::Type(type);
+      p.name = name;
+      list.push_back(p);
+    }
+  return found;
+}
+
+bool
+GameServer::remove_from_player_list(std::list<GameParameters::Player> &list, guint32 id)
 {
   //remove player id from part.
-  for (std::list<guint32>::iterator i = list.begin(); 
+  for (std::list<GameParameters::Player>::iterator i = list.begin(); 
        i != list.end(); i++)
     {
-      if (*i == id)
+      if ((*i).id == id)
 	{
 	  list.erase (i);
 	  return true;
@@ -650,10 +914,10 @@ void GameServer::sendMap(Participant *part)
   File::erase(tmpfile);
   tmpfile += SAVE_EXT;
 
-  d_game_scenario->saveGame(tmpfile, "sav");
+  d_game_scenario->saveGame(tmpfile);
 
   std::cerr << "sending map" << std::endl;
-  network_server->send(part->conn, MESSAGE_TYPE_SENDING_MAP, tmpfile);
+  network_server->sendFile(part->conn, MESSAGE_TYPE_SENDING_MAP, tmpfile);
   File::erase (tmpfile);
 
   // unhack the players
@@ -675,11 +939,13 @@ void GameServer::sendActions(Participant *part)
 
   for (std::list<NetworkAction *>::iterator i = part->actions.begin(),
        end = part->actions.end(); i != end; ++i)
+    {
+  std::cerr << "sending " << Action::actionTypeToString((*i)->getAction()->getType()) << " from " << d_nickname << " (" << Playerlist::getInstance()->getPlayer((*i)->getOwnerId())->getName() << ")" << " to " << part->nickname << std::endl;
     (**i).save(&helper);
+    }
 
   helper.closeTag();
 
-  std::cerr << "sending actions" << std::endl;
   network_server->send(part->conn, MESSAGE_TYPE_SENDING_ACTIONS, os.str());
 }
 
@@ -693,11 +959,13 @@ void GameServer::sendHistories(Participant *part)
 
   for (std::list<NetworkHistory *>::iterator i = part->histories.begin(),
        end = part->histories.end(); i != end; ++i)
+    {
+  std::cerr << "sending " << History::historyTypeToString((*i)->getHistory()->getType()) << " from " << d_nickname << " (" << Playerlist::getInstance()->getPlayer((*i)->getOwnerId())->getName() << ")" << " to " << part->nickname << std::endl;
     (**i).save(&helper);
+    }
 
   helper.closeTag();
 
-  std::cerr << "sending histories" << std::endl;
   network_server->send(part->conn, MESSAGE_TYPE_SENDING_HISTORY, os.str());
 }
 
@@ -708,10 +976,10 @@ bool GameServer::dumpActionsAndHistories(XML_Helper *helper, Player *player)
        end = participants.end(); i != end; ++i)
     {
       bool found = false;
-      for (std::list<guint32>::iterator it = (*i)->players.begin();
-	   it != (*i)->players.end(); it++)
+      for (std::list<GameParameters::Player>::iterator it = 
+           (*i)->players.begin(); it != (*i)->players.end(); it++)
 	{
-	  if (*it == player->getId())
+	  if ((*it).id == player->getId())
 	    {
 	      found = true;
 	      break;
@@ -755,20 +1023,28 @@ void GameServer::sit_down (Player *player)
       stopListeningForLocalEvents(player);
       listenForLocalEvents(new_p);
       delete player;
-      add_to_player_list (players_seated_locally, new_p->getId());
+      player = new_p;
+      add_to_player_list (players_seated_locally, new_p->getId(),
+                          new_p->getName(), 
+                          GameParameters::player_type_to_player_param(new_p->getType()));
       notifySit(new_p, d_nickname);
     }
   else if (player->getType() == Player::HUMAN)
     {
+      //alright, we want to sit down as this player
+      //wait, we're already human.
       // do nothing
     }
   else // an ai player
     {
       stopListeningForLocalEvents(player);
       listenForLocalEvents(player);
-      add_to_player_list (players_seated_locally, player->getId());
+      add_to_player_list (players_seated_locally, player->getId(),
+                          player->getName(),
+                          GameParameters::player_type_to_player_param(player->getType()));
       notifySit(player, d_nickname);
     }
+  notifyTypeChange(player, player->getType());
 }
 
 void GameServer::stand_up (Player *player)
@@ -784,13 +1060,17 @@ void GameServer::stand_up (Player *player)
       Playerlist::getInstance()->swap(player, new_p);
       stopListeningForLocalEvents(player);
       delete player;
+      listenForLocalEvents(new_p);
+      player = new_p;
       new_p->setConnected(false);
       notifyStand(new_p, d_nickname);
       remove_from_player_list (players_seated_locally, new_p->getId());
     }
   else if (player->getType() == Player::NETWORKED)
     {
-      // do nothing
+      //this is the forcibly booted, made to stand-up case. .
+      Participant *part = findParticipantByPlayerId(player->getId());
+      stand(part->conn, player, part->nickname);
     }
   else // an ai player
     {
@@ -798,6 +1078,25 @@ void GameServer::stand_up (Player *player)
       remove_from_player_list (players_seated_locally, player->getId());
       notifyStand(player, d_nickname);
     }
+  notifyTypeChange(player, GameParameters::Player::NETWORKED);
+}
+
+void GameServer::name_change (Player *player, Glib::ustring name)
+{
+  if (!player)
+    return;
+  player->rename(name);
+  update_player_name (players_seated_locally, player->getId(), name);
+  notifyNameChange(player, name);
+}
+
+void GameServer::type_change (Player *player, int type)
+{
+  if (!player)
+    return;
+  update_player_type (players_seated_locally, player->getId(), (guint32) type);
+  notifyTypeChange(player, type);
+  player_changes_type.emit(player, type);
 }
 
 void GameServer::chat (std::string message)
@@ -813,6 +1112,23 @@ void GameServer::notifyChat(std::string message)
     network_server->send((*i)->conn, MESSAGE_TYPE_CHATTED, message);
 }
 
+void GameServer::sendSeat(void *conn, GameParameters::Player player, Glib::ustring nickname)
+{
+  Glib::ustring payload = String::ucompose ("%1 %2 %3 %4", player.id, 
+                                            LOBBY_MESSAGE_TYPE_SIT, 1, 
+                                            nickname);
+  network_server->send(conn, MESSAGE_TYPE_LOBBY_ACTIVITY, payload);
+
+  payload = String::ucompose ("%1 %2 %3 %4", player.id, 
+                              LOBBY_MESSAGE_TYPE_CHANGE_TYPE, 1, player.type);
+  network_server->send(conn, MESSAGE_TYPE_LOBBY_ACTIVITY, payload);
+
+  payload = String::ucompose ("%1 %2 %3 %4", player.id, 
+                              LOBBY_MESSAGE_TYPE_CHANGE_NAME, 1, 
+                              player.name);
+  network_server->send(conn, MESSAGE_TYPE_LOBBY_ACTIVITY, payload);
+}
+
 void GameServer::sendSeats(void *conn)
 {
   Participant *part = findParticipantByConn(conn);
@@ -826,48 +1142,14 @@ void GameServer::sendSeats(void *conn)
       if ((*i)->conn == part->conn)
 	continue;
 
-      for (std::list<guint32>::iterator j = (*i)->players.begin(); 
-	   j != (*i)->players.end(); j++)
-	{
-	  Player *player = Playerlist::getInstance()->getPlayer(*j);
-	  MessageType type;
-	  switch (player->getId())
-	    {
-	    case 0: type = MESSAGE_TYPE_P1_SAT_DOWN; break;
-	    case 1: type = MESSAGE_TYPE_P2_SAT_DOWN; break;
-	    case 2: type = MESSAGE_TYPE_P3_SAT_DOWN; break;
-	    case 3: type = MESSAGE_TYPE_P4_SAT_DOWN; break;
-	    case 4: type = MESSAGE_TYPE_P5_SAT_DOWN; break;
-	    case 5: type = MESSAGE_TYPE_P6_SAT_DOWN; break;
-	    case 6: type = MESSAGE_TYPE_P7_SAT_DOWN; break;
-	    case 7: type = MESSAGE_TYPE_P8_SAT_DOWN; break;
-	    default:
-		    return;
-	    }
-	  network_server->send(part->conn, type, (*i)->nickname);
-	}
+      for (std::list<GameParameters::Player>::iterator j = 
+           (*i)->players.begin(); j != (*i)->players.end(); j++)
+        sendSeat(conn, (*j), (*i)->nickname);
     }
   //send out seatedness info for local server
-  for (std::list<guint32>::iterator j = players_seated_locally.begin(); 
-       j != players_seated_locally.end(); j++)
-    {
-      Player *player = Playerlist::getInstance()->getPlayer(*j);
-      MessageType type;
-      switch (player->getId())
-	{
-	case 0: type = MESSAGE_TYPE_P1_SAT_DOWN; break;
-	case 1: type = MESSAGE_TYPE_P2_SAT_DOWN; break;
-	case 2: type = MESSAGE_TYPE_P3_SAT_DOWN; break;
-	case 3: type = MESSAGE_TYPE_P4_SAT_DOWN; break;
-	case 4: type = MESSAGE_TYPE_P5_SAT_DOWN; break;
-	case 5: type = MESSAGE_TYPE_P6_SAT_DOWN; break;
-	case 6: type = MESSAGE_TYPE_P7_SAT_DOWN; break;
-	case 7: type = MESSAGE_TYPE_P8_SAT_DOWN; break;
-	default:
-		return;
-	}
-      network_server->send(part->conn, type, d_nickname);
-    }
+  for (std::list<GameParameters::Player>::iterator j = 
+       players_seated_locally.begin(); j != players_seated_locally.end(); j++)
+    sendSeat(conn, (*j), d_nickname);
 }
 
 void GameServer::sendChatRoster(void *conn)
@@ -887,6 +1169,17 @@ void GameServer::sendChatRoster(void *conn)
 		       d_nickname);
 }
 
+void GameServer::sendOffPlayer(Player *p)
+{
+  std::stringstream player;
+  player << p->getId();
+  for (std::list<Participant *>::iterator i = participants.begin(),
+       end = participants.end(); i != end; ++i) 
+    network_server->send((*i)->conn, MESSAGE_TYPE_OFF_PLAYER, player.str());
+
+  remote_player_died.emit(p);
+}
+
 void GameServer::sendKillPlayer(Player *p)
 {
   std::stringstream player;
@@ -900,14 +1193,65 @@ void GameServer::sendKillPlayer(Player *p)
 
 void GameServer::sendTurnOrder()
 {
+  std::list<guint32> ids;
   std::stringstream players;
   Playerlist *pl = Playerlist::getInstance();
   for (Playerlist::iterator it = pl->begin(); it != pl->end(); it++)
-    players << (*it)->getId() << " ";
+    {
+      players << (*it)->getId() << " ";
+      ids.push_back((*it)->getId());
+    }
   for (std::list<Participant *>::iterator i = participants.begin(),
        end = participants.end(); i != end; ++i) 
     network_server->send((*i)->conn, MESSAGE_TYPE_TURN_ORDER, players.str());
   playerlist_reorder_received.emit();
 }
 
+bool GameServer::gameHasBegun()
+{
+  return d_game_has_begun;
+}
+
+void GameServer::notifyClientsGameMayBeginNow()
+{
+  d_game_has_begun = true;
+  syncLocalPlayers();
+  //notify everyone that the game can finally start.
+  for (std::list<Participant *>::iterator i = participants.begin(),
+       end = participants.end(); i != end; ++i) 
+    network_server->send((*i)->conn, MESSAGE_TYPE_GAME_MAY_BEGIN, "");
+}
+
+void GameServer::syncLocalPlayers()
+{
+  std::list<guint32> ids;
+  for (std::list<GameParameters::Player>::iterator j = 
+       players_seated_locally.begin(); j != players_seated_locally.end(); j++)
+    {
+      Player *p = Playerlist::getInstance()->getPlayer((*j).id);
+      if ((*j).type == GameParameters::Player::OFF)
+        {
+          stopListeningForLocalEvents(p);
+          player_gets_turned_off.emit(p);
+          sendOffPlayer(p);
+          ids.push_back(p->getId());
+          Playerlist::getInstance()->syncPlayer(*j);
+        }
+      else
+        {
+          stopListeningForLocalEvents(p);
+          Playerlist::getInstance()->syncPlayer(*j);
+          listenForLocalEvents(Playerlist::getInstance()->getPlayer((*j).id));
+        }
+    }
+  for (std::list<guint32>::iterator i = ids.begin(); i != ids.end(); i++)
+    remove_from_player_list (players_seated_locally, *i);
+}
+  
+void GameServer::on_turn_aborted()
+{
+  d_stop = true;
+  remove_all_participants();
+}
+
 // End of file
