@@ -1,4 +1,4 @@
-// Copyright (C) 2008 Ben Asselstine
+// Copyright (C) 2008, 2011 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -20,10 +20,12 @@
 #include <list>
 
 #include "game-station.h"
+#include "network-common.h"
 
 #include "network-action.h"
 #include "network-history.h"
 
+#include "playerlist.h"  /// REMOVE ME
 
 GameStation::GameStation()
 {
@@ -64,6 +66,18 @@ void GameStation::listenForLocalEvents(Player *p)
   history_listeners[p->getId()] = connection;
 }
 
+void GameStation::stopListeningForLocalEvents()
+{
+  std::map<guint32, sigc::connection>::iterator i = action_listeners.begin();
+  for (; i != action_listeners.end(); i++)
+    (*i).second.disconnect();
+  action_listeners.clear();
+  std::map<guint32, sigc::connection>::iterator j = history_listeners.begin();
+  for (; j != history_listeners.end(); j++)
+    (*j).second.disconnect();
+  history_listeners.clear();
+}
+
 void GameStation::stopListeningForLocalEvents(Player *p)
 {
   sigc::connection connection;
@@ -83,4 +97,37 @@ void GameStation::stopListeningForLocalEvents(Player *p)
       history_listeners.erase(it);
     }
 }
+
+bool GameStation::get_message_lobby_activity (std::string payload, 
+                                             guint32 &player_id, 
+                                             gint32 &action, bool &reported,
+                                             Glib::ustring &remainder)
+{
+  std::stringstream spayload;
+  spayload.str(payload);
+  spayload >> player_id;
+  if (player_id >= MAX_PLAYERS + 1)
+    return false;
+  spayload >> action;
+  switch (action)
+    {
+    case LOBBY_MESSAGE_TYPE_SIT:
+    case LOBBY_MESSAGE_TYPE_CHANGE_NAME:
+    case LOBBY_MESSAGE_TYPE_STAND:
+    case LOBBY_MESSAGE_TYPE_CHANGE_TYPE:
+      break;
+    default:
+      return false;
+    }
+  spayload >> reported;
+  if (reported != 0 && reported != 1)
+    return false;
+  //okay, the rest of the stringstream is a nickname.
+  char buffer[1024];
+  memset (buffer, 0, sizeof (buffer));
+  spayload.get();
+  spayload.rdbuf()->sgetn(buffer, sizeof (buffer));
+  remainder = std::string (buffer);
+  return true;
+}
 // End of file
