@@ -1,4 +1,4 @@
-// Copyright (C) 2008 Ben Asselstine
+// Copyright (C) 2008, 2011 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -41,9 +41,17 @@ public:
   sigc::signal<void, Player*> local_player_moved;
   sigc::signal<void, Player*> local_player_died;
   sigc::signal<void, Player*> local_player_starts_move;
+  sigc::signal<void, Player*, int> player_changes_type;
+  sigc::signal<void, Player*, Glib::ustring> player_changes_name;
+  sigc::signal<void, Glib::ustring, Glib::ustring> nickname_changed;
+  sigc::signal<void, Player*> player_gets_turned_off;
   sigc::signal<void> round_begins;
+  sigc::signal<void> round_ends;
+  sigc::signal<void> game_may_begin;
+  sigc::signal<void, Player *> start_player_turn;
 
   void listenForLocalEvents(Player *p);
+  std::string getProfileId() const {return d_profile_id;};
 protected:
   GameStation();
   virtual ~GameStation();
@@ -55,10 +63,19 @@ protected:
   void clearNetworkHistorylist(std::list<NetworkHistory*> &histories);
 
   void stopListeningForLocalEvents(Player *p);
+  void stopListeningForLocalEvents();
+
+  static bool get_message_lobby_activity (std::string payload, 
+                                          guint32 &player_id, 
+                                          gint32 &action, bool &reported,
+                                          Glib::ustring &nickname);
+
+  void setProfileId(std::string id) {d_profile_id = id;};
 
 private:
   std::map<guint32, sigc::connection> action_listeners;
   std::map<guint32, sigc::connection> history_listeners;
+  std::string d_profile_id;
 };
 
 #endif
