@@ -112,6 +112,12 @@ void Game::addPlayer(Player *p)
       connections[p->getId()].push_back
 	(p->advice_asked.connect
 	 (sigc::mem_fun(advice_asked, &sigc::signal<void, float>::emit)));
+      connections[p->getId()].push_back
+	(p->smovingStack.connect
+	 (sigc::mem_fun(this, &Game::on_stack_starts_moving)));
+      connections[p->getId()].push_back
+	(p->sstoppingStack.connect
+	 (sigc::mem_fun(this, &Game::on_stack_stopped)));
       connections[p->getId()].push_back
 	(p->shaltedStack.connect
 	 (sigc::mem_fun(this, &Game::on_stack_halted)));
@@ -132,6 +138,11 @@ void Game::addPlayer(Player *p)
       connections[p->getId()].push_back
 	(p->mp_added_to_hero_stack.connect
 	 (sigc::mem_fun(mp_added_to_hero_stack, &sigc::signal<void, Hero*, guint32>::emit)));
+      connections[p->getId()].push_back
+	(p->worms_killed.connect
+	 (sigc::mem_fun(worms_killed, &sigc::signal<void, Hero*, guint32>::emit)));
+
+
     }
       
       
@@ -199,8 +210,22 @@ void Game::addPlayer(Player *p)
     unlock_inputs();
 }
 
+void Game::on_stack_starts_moving(Stack *stack)
+{
+  if (Playerlist::getActiveplayer()->getType() == Player::HUMAN)
+    lock_inputs();
+}
+
+void Game::on_stack_stopped()
+{
+  if (Playerlist::getActiveplayer()->getType() == Player::HUMAN)
+    unlock_inputs();
+}
+
 void Game::on_stack_halted(Stack *stack)
 {
+  if (Playerlist::getActiveplayer()->getType() == Player::HUMAN)
+    unlock_inputs();
   if (stack == NULL)
     return;
   bigmap->reset_path_calculator(stack);
@@ -268,6 +293,7 @@ Game::Game(GameScenario* gameScenario, NextTurn *nextTurn)
 	sigc::mem_fun(bigmap.get(), &GameBigMap::set_view));
 
     // get the maps up and running
+    Playerlist::getInstance()->setViewingplayer(Playerlist::getActiveplayer());
     bigmap->screen_size_changed(Gtk::Allocation(0,0,320,200));
 
     // connect player callbacks
@@ -277,7 +303,8 @@ Game::Game(GameScenario* gameScenario, NextTurn *nextTurn)
 	Player *p = *i;
 	addPlayer(p);
     }
-    if (gameScenario->getPlayMode() == GameScenario::HOTSEAT)
+    if (gameScenario->getPlayMode() == GameScenario::HOTSEAT ||
+        gameScenario->getPlayMode() == GameScenario::NETWORKED)
       pl->splayerDead.connect(sigc::mem_fun(this, &Game::on_player_died));
     pl->ssurrender.connect(sigc::mem_fun(this, &Game::on_surrender_offered));
 
@@ -325,13 +352,7 @@ void Game::end_turn()
     update_control_panel();
     lock_inputs();
 
-    bool trigger_next_remote_player = false;
-    if (d_gameScenario->getPlayMode() == GameScenario::NETWORKED &&
-	Playerlist::getActiveplayer()->getType() == Player::NETWORKED)
-      trigger_next_remote_player = true;
     d_nextTurn->endTurn();
-    if (trigger_next_remote_player)
-      remote_next_player_turn.emit();
 }
 
 void Game::update_stack_info()
@@ -363,7 +384,7 @@ void Game::update_sidebar_stats()
     s.cities = Citylist::getInstance()->countCities(player);
 
     s.units = 0;
-    s.upkeep = player->getUpkeep() + player->getCostOfUnitsProducedThisTurn();
+    s.upkeep = player->getStacklist()->calculateUpkeep();
     Stacklist *sl = player->getStacklist();
     for (Stacklist::iterator i = sl->begin(), iend = sl->end(); i != iend; ++i)
       s.units += (*i)->size();
@@ -537,7 +558,7 @@ void Game::defend_selected_stack()
   Stack *stack = player->getActivestack();
   assert(stack);
 
-  stack->setDefending(true);
+  player->stackDefend(stack);
 
   stack = player->getStacklist()->getNextMovable();
   player->setActivestack(stack);
@@ -553,7 +574,7 @@ void Game::park_selected_stack()
   Player *player = Playerlist::getActiveplayer();
   Stack *stack = player->getActivestack();
   assert(stack);
-  stack->setParked(true);
+  player->stackPark(stack);
 
   stack = player->getStacklist()->getNextMovable();
   player->setActivestack(stack);
@@ -604,7 +625,9 @@ void Game::search_stack(Stack *stack, bool &gotquest, bool &stackdied)
 	  
       if (reward)
 	{
-	  player->giveReward(stack, reward);
+          StackReflist *stacks = new StackReflist();
+	  player->giveReward(stack, reward, stacks);
+          delete stacks;
 	  //FIXME: delete this reward, but don't delete the item, or map
 	  redraw();
 	  update_stack_info();
@@ -707,7 +730,8 @@ void Game::stackUpdate(Stack* s)
   if (s)
     smallmap->center_view_on_tile(s->getPos(), true);
 
-  //redraw();
+  if (!s)
+    redraw();
 
   update_stack_info();
   update_control_panel();
@@ -938,6 +962,8 @@ void Game::update_control_panel()
       can_defend_selected_stack.emit(false);
       can_park_selected_stack.emit(false);
       can_deselect_selected_stack.emit(false);
+      can_inspect.emit(false);
+      can_see_hero_levels.emit(false);
       can_search_selected_stack.emit(false);
       can_use_item.emit(false);
       can_plant_standard_selected_stack.emit(false);
@@ -985,6 +1011,8 @@ void Game::update_control_panel()
   can_park_selected_stack.emit(stack != 0);
   can_deselect_selected_stack.emit(stack != 0);
   can_center_selected_stack.emit(stack != 0);
+  can_inspect.emit(Playerlist::getActiveplayer()->getHeroes().size() > 0);
+  can_see_hero_levels.emit(Playerlist::getActiveplayer()->getHeroes().size() > 0);
 
   if (stack)
     {
@@ -1014,8 +1042,9 @@ void Game::update_control_panel()
       can_disband_stack.emit(false);
       can_group_ungroup_selected_stack.emit(false);
       can_plant_standard_selected_stack.emit(false);
+      can_search_selected_stack.emit(false);
     }
-
+      
   if (d_gameScenario->getRound() > 1)
     can_see_history.emit(true);
   else
@@ -1023,7 +1052,10 @@ void Game::update_control_panel()
     
   can_see_diplomacy.emit(GameScenarioOptions::s_diplomacy);
 
-  can_end_turn.emit(true);
+  if (Playerlist::getInstance()->countPlayersAlive() <= 1)
+    can_end_turn.emit(false);
+  else
+    can_end_turn.emit(true);
 }
 
 GameBigMap &Game::get_bigmap()
@@ -1048,7 +1080,9 @@ void Game::startGame()
   update_stack_info();
   lock_inputs();
 
-  d_nextTurn->start();
+  if (d_gameScenario->getPlayMode() != GameScenario::NETWORKED)
+    d_nextTurn->start();
+      
   if (Playerlist::getInstance()->countPlayersAlive())
     update_control_panel();
 }
@@ -1142,6 +1176,11 @@ void Game::init_turn_for_player(Player* p)
 
   next_player_turn.emit(p, d_gameScenario->getRound());
 
+  if (p->getType() == Player::NETWORKED)
+    {
+      remote_next_player_turn.emit();
+      return;
+    }
   blank(false);
 
   if (p->isObservable() == true)
@@ -1284,6 +1323,7 @@ void Game::center_view_on_city()
 	}
     }
 }
+
 void Game::select_active_stack()
 {
   //if (Playerlist::getActiveplayer()->getType() != Player::HUMAN &&
@@ -1293,6 +1333,7 @@ void Game::select_active_stack()
   smallmap->center_view_on_tile (p->getActivestack()->getPos(), true);
   bigmap->select_active_stack();
 }
+
 void Game::unselect_active_stack()
 {
   bigmap->unselect_active_stack();
@@ -1318,12 +1359,9 @@ bool Game::maybeTreachery(Stack *stack, Player *them, Vector<int> pos)
   if (treachery == false)
     return false;
   me->proposeDiplomacy (Player::NO_PROPOSAL, them);
-  me->declareDiplomacy (Player::AT_WAR, them);
+  me->declareDiplomacy (Player::AT_WAR, them, true);
   them->proposeDiplomacy (Player::NO_PROPOSAL, me);
-  them->declareDiplomacy (Player::AT_WAR, me);
-  History_DiplomacyTreachery *item = new History_DiplomacyTreachery();
-  item->fillData(them);
-  me->addHistory(item);
+  them->declareDiplomacy (Player::AT_WAR, me, false);
 
   me->deteriorateDiplomaticRelationship (5);
   them->improveDiplomaticRelationship (2, me);
@@ -1333,9 +1371,12 @@ bool Game::maybeTreachery(Stack *stack, Player *them, Vector<int> pos)
 
 void Game::nextRound()
 {
-  Playerlist::getInstance()->nextRound
-    (GameScenarioOptions::s_diplomacy, 
-     &GameScenarioOptions::s_surrender_already_offered);
+  if (GameServer::getInstance()->isListening())
+    {
+      Playerlist::getInstance()->nextRound
+        (GameScenarioOptions::s_diplomacy, 
+         &GameScenarioOptions::s_surrender_already_offered);
+    }
 }
     
 void Game::on_surrender_offered(Player *recipient)
@@ -1431,8 +1472,7 @@ void Game::endOfGameRoaming(Player *winner)
 {
   Playerlist* pl = Playerlist::getInstance();
   pl->setWinningPlayer(winner);
-
-  winner->immobilize();
+  Playerlist::getActiveplayer()->immobilize();
   d_gameScenario->s_see_opponents_stacks = true;
   d_gameScenario->s_see_opponents_production = true;
   bigmap->d_see_opponents_stacks = true;
