@@ -116,6 +116,8 @@ class Game
 	can_park_selected_stack,
 	can_deselect_selected_stack,
 	can_search_selected_stack,
+	can_inspect,
+	can_see_hero_levels,
 	can_use_item,
 	can_plant_standard_selected_stack,
 	can_move_selected_stack_along_path,
@@ -172,6 +174,7 @@ class Game
     sigc::signal<void, Player*, guint32> sunk_ships;
     sigc::signal<void, Hero*, guint32> bags_picked_up;
     sigc::signal<void, Hero *, guint32> mp_added_to_hero_stack;
+    sigc::signal<void, Hero *, guint32> worms_killed;
     
     void addPlayer(Player *p);
 
@@ -250,6 +253,8 @@ class Game
     void stack_arrives_on_tile(Stack *stack, Vector<int> tile);
     void stack_leaves_tile(Stack *stack, Vector<int> tile);
     void on_stack_halted(Stack *stack);
+    void on_stack_stopped();
+    void on_stack_starts_moving(Stack *stack);
 
 
     GameScenario* d_gameScenario;
