@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -22,12 +22,8 @@
 #include <memory>
 #include <sigc++/trackable.h>
 #include <sigc++/signal.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/liststore.h>
-#include <gtkmm/treemodelcolumn.h>
-#include <gtkmm/treeview.h>
+#include <gtkmm.h>
 #include <list>
-#include <SDL.h>
 class Player;
 
 #include "decorated.h"
@@ -36,6 +32,7 @@ class ArmyBonusDialog: public Decorated
 {
  public:
     ArmyBonusDialog(Player *p);
+    ~ArmyBonusDialog();
 
     void set_parent_window(Gtk::Window &parent);
 
@@ -43,7 +40,7 @@ class ArmyBonusDialog: public Decorated
     void hide();
 
  private:
-    std::auto_ptr<Gtk::Dialog> dialog;
+    Gtk::Dialog* dialog;
 
     Gtk::TreeView *armies_treeview;
 
@@ -55,15 +52,15 @@ class ArmyBonusDialog: public Decorated
 	
 	Gtk::TreeModelColumn<Glib::RefPtr<Gdk::Pixbuf> > image;
 	Gtk::TreeModelColumn<Glib::ustring> name;
-	Gtk::TreeModelColumn<Uint32> str;
-	Gtk::TreeModelColumn<Uint32> move;
+	Gtk::TreeModelColumn<guint32> str;
+	Gtk::TreeModelColumn<guint32> move;
 	Gtk::TreeModelColumn<Glib::RefPtr<Gdk::Pixbuf> > move_image;
 	Gtk::TreeModelColumn<Glib::ustring> bonus;
     };
     const ArmiesColumns armies_columns;
     Glib::RefPtr<Gtk::ListStore> armies_list;
  private:
-    void addArmyType(Uint32 army_type);
+    void addArmyType(guint32 army_type);
     Player *d_player; //show armies in this player's colour
 };
 
