@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -22,10 +22,7 @@
 #include <memory>
 #include <vector>
 #include <sigc++/trackable.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/label.h>
-#include <gtkmm/togglebutton.h>
-#include <gtkmm/button.h>
+#include <gtkmm.h>
 
 #include "army-info-tip.h"
 
@@ -38,6 +35,7 @@ class BuyProductionDialog: public Decorated
 {
  public:
     BuyProductionDialog(City *city);
+    ~BuyProductionDialog();
 
     void set_parent_window(Gtk::Window &parent);
 
@@ -48,8 +46,8 @@ class BuyProductionDialog: public Decorated
     int get_selected_army() { return selected_army == NO_ARMY_SELECTED ? NO_ARMY_SELECTED : purchasables[selected_army]->getTypeId(); }
     
  private:
-    std::auto_ptr<Gtk::Dialog> dialog;
-    std::auto_ptr<ArmyInfoTip> army_info_tip;
+    Gtk::Dialog* dialog;
+    ArmyInfoTip* army_info_tip;
     Gtk::Label *production_info_label1;
     Gtk::Label *production_info_label2;
     Gtk::Button *buy_button;
