@@ -1,8 +1,8 @@
-//  Copyright (C) 2008 Ben Asselstine
+//  Copyright (C) 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,11 +17,8 @@
 
 #include <config.h>
 
-#include <libglademm/xml.h>
+#include <gtkmm.h>
 #include <sigc++/functors/mem_fun.h>
-#include <gtkmm/label.h>
-#include <gtkmm/radiobutton.h>
-#include <gtkmm/image.h>
 
 #include "diplomacy-dialog.h"
 #include "diplomacy-report-dialog.h"
@@ -41,14 +38,12 @@ DiplomacyDialog::DiplomacyDialog(Player *player)
   GraphicsCache *gc = GraphicsCache::getInstance();
   Playerlist *pl = Playerlist::getInstance();
   d_player = player;
-  Glib::RefPtr<Gnome::Glade::Xml> xml
-    = Gnome::Glade::Xml::create(get_glade_path() + "/diplomacy-dialog.glade");
+  Glib::RefPtr<Gtk::Builder> xml
+    = Gtk::Builder::create_from_file(get_glade_path() + "/diplomacy-dialog.ui");
 
-  Gtk::Dialog *d = 0;
-  xml->get_widget("dialog", d);
-  dialog.reset(d);
-  decorate(dialog.get());
-  window_closed.connect(sigc::mem_fun(dialog.get(), &Gtk::Dialog::hide));
+  xml->get_widget("dialog", dialog);
+  decorate(dialog);
+  window_closed.connect(sigc::mem_fun(dialog, &Gtk::Dialog::hide));
 
   xml->get_widget("proposals_table", d_proposals_table);
   xml->get_widget("offers_table", d_offers_table);
@@ -56,13 +51,12 @@ DiplomacyDialog::DiplomacyDialog(Player *player)
   xml->get_widget("player_shield_image", d_player_shield_image);
   xml->get_widget("report_button", d_report_button);
     
-  xml->connect_clicked("report_button",
-		       sigc::mem_fun(*this, 
-				     &DiplomacyDialog::on_report_clicked));
+  d_report_button->signal_clicked().connect
+    (sigc::mem_fun(*this, &DiplomacyDialog::on_report_clicked));
 
   // put the shields across the top of the proposals table, minus our own
-  Uint32 i = 0;
-  Uint32 j = 0;
+  guint32 i = 0;
+  guint32 j = 0;
   for (unsigned int k = 0; k < MAX_PLAYERS; k++)
     {
       Player *p = pl->getPlayer(k);
@@ -72,17 +66,17 @@ DiplomacyDialog::DiplomacyDialog(Player *player)
 	continue;
       if (p == d_player)
 	continue;
-      Glib::RefPtr<Gdk::Pixbuf> pixbuf = to_pixbuf(gc->getShieldPic(2, p));
-      Gtk::Image *im = manage(new Gtk::Image(pixbuf));
+      Glib::RefPtr<Gdk::Pixbuf> pixbuf= gc->getShieldPic(2, p)->to_pixbuf();
+      Gtk::Image *im = new Gtk::Image();
+      im->property_pixbuf() = pixbuf;
       //im->set_padding(11, 0);
-      d_proposals_table->attach(*im, i + 0, i + 1, 0, 1, 
+      d_proposals_table->attach(*manage(im), i + 0, i + 1, 0, 1, 
 				Gtk::SHRINK, Gtk::SHRINK);
       i++;
     }
   d_proposals_table->set_col_spacings (16);
     
-  d_player_shield_image->property_pixbuf() = 
-    to_pixbuf(gc->getShieldPic(2, d_player));
+  d_player_shield_image->property_pixbuf() = gc->getShieldPic(2, d_player)->to_pixbuf();
 
   d_player_label->set_text(d_player->getName());
 
@@ -105,10 +99,10 @@ DiplomacyDialog::DiplomacyDialog(Player *player)
 	}
       j = 0;
       Player::DiplomaticState state = d_player->getDiplomaticState (p);
-      Glib::RefPtr<Gdk::Pixbuf> pixbuf = to_pixbuf(gc->getDiplomacyPic(1, 
-								       state));
-      Gtk::Image *im = manage(new Gtk::Image(pixbuf));
-      d_proposals_table->attach(*im, i + 0, i + 1, j + 1, j + 2, 
+      Glib::RefPtr<Gdk::Pixbuf> pixbuf= gc->getDiplomacyPic(1, state)->to_pixbuf();
+      Gtk::Image *im = new Gtk::Image();
+      im->property_pixbuf() = pixbuf;
+      d_proposals_table->attach(*manage(im), i + 0, i + 1, j + 1, j + 2, 
 				Gtk::SHRINK, Gtk::SHRINK);
       Player::DiplomaticProposal proposal = p->getDiplomaticProposal (d_player);
       if (proposal != Player::NO_PROPOSAL)
@@ -118,21 +112,21 @@ DiplomacyDialog::DiplomacyDialog(Player *player)
 	  switch (proposal)
 	    {
 	    case Player::PROPOSE_PEACE:
-	      pixbuf2 = to_pixbuf(gc->getDiplomacyPic(1, Player::AT_PEACE));
+	      pixbuf2 = gc->getDiplomacyPic(1, Player::AT_PEACE)->to_pixbuf();
 	      break;
 	    case Player::PROPOSE_WAR_IN_FIELD:
-	      pixbuf2 = 
-		to_pixbuf(gc->getDiplomacyPic(1, Player::AT_WAR_IN_FIELD));
+	      pixbuf2 = gc->getDiplomacyPic(1, Player::AT_WAR_IN_FIELD)->to_pixbuf();
 	      break;
 	    case Player::PROPOSE_WAR:
-	      pixbuf2 = to_pixbuf(gc->getDiplomacyPic(1, Player::AT_WAR));
+	      pixbuf2 = gc->getDiplomacyPic(1, Player::AT_WAR)->to_pixbuf();
 	      break;
 	    default:
 	      continue;
 	    }
 
-	  Gtk::Image *im2 = manage(new Gtk::Image(pixbuf2));
-	  d_proposals_table->attach(*im2, i + 0, i + 1, j + 1, j + 2, 
+	  Gtk::Image *im2 = manage(new Gtk::Image());
+	  im2->property_pixbuf() = pixbuf2;
+	  d_proposals_table->attach(*manage(im2), i + 0, i + 1, j + 1, j + 2, 
 				    Gtk::SHRINK, Gtk::SHRINK);
 	}
       i++;
@@ -155,9 +149,10 @@ DiplomacyDialog::DiplomacyDialog(Player *player)
       //show the peace radio buttons
       j = 0;
       Gtk::RadioButton *radio1= manage(new Gtk::RadioButton);
-      Glib::RefPtr<Gdk::Pixbuf> pixbuf = 
-	to_pixbuf(gc->getDiplomacyPic(1, Player::AT_PEACE));
-      radio1->add(*manage(new Gtk::Image(pixbuf)));
+      Gtk::Image *im3 = new Gtk::Image();
+      im3->property_pixbuf() = 
+	gc->getDiplomacyPic(1, Player::AT_PEACE)->to_pixbuf();
+      radio1->add(*manage(im3));
       radio1->set_mode(false);
       Gtk::RadioButtonGroup group = radio1->get_group();
       if (p->isDead())
@@ -174,9 +169,10 @@ DiplomacyDialog::DiplomacyDialog(Player *player)
 
       j = 1;
       Gtk::RadioButton *radio2= manage(new Gtk::RadioButton);
-      Glib::RefPtr<Gdk::Pixbuf> pixbuf2 = 
-	to_pixbuf(gc->getDiplomacyPic(1, Player::AT_WAR_IN_FIELD));
-      radio2->add(*manage(new Gtk::Image(pixbuf2)));
+      Gtk::Image *im4 = new Gtk::Image();
+      im4->property_pixbuf() = 
+	gc->getDiplomacyPic(1, Player::AT_WAR_IN_FIELD)->to_pixbuf();
+      radio2->add(*manage(im4));
       radio2->set_mode(false);
       radio2->set_group(group);
       if (p->isDead())
@@ -193,9 +189,10 @@ DiplomacyDialog::DiplomacyDialog(Player *player)
 
       j = 2;
       Gtk::RadioButton *radio3= manage(new Gtk::RadioButton);
-      Glib::RefPtr<Gdk::Pixbuf> pixbuf3 = 
-	to_pixbuf(gc->getDiplomacyPic(1, Player::AT_WAR));
-      radio3->add(*manage(new Gtk::Image(pixbuf3)));
+      Gtk::Image *im5 = new Gtk::Image();
+      im5->property_pixbuf() = 
+	gc->getDiplomacyPic(1, Player::AT_WAR)->to_pixbuf();
+      radio3->add(*manage(im5));
       radio3->set_mode(false);
       radio3->set_group(group);
       if (p->isDead())
@@ -213,6 +210,10 @@ DiplomacyDialog::DiplomacyDialog(Player *player)
     }
 }
 
+DiplomacyDialog::~DiplomacyDialog()
+{
+  delete dialog;
+}
 void DiplomacyDialog::on_proposal_toggled (Gtk::ToggleButton *toggle, 
 					   Player *player, 
 					   Player::DiplomaticProposal proposal)
@@ -231,7 +232,7 @@ void DiplomacyDialog::set_parent_window(Gtk::Window &parent)
 void DiplomacyDialog::on_report_clicked()
 {
   DiplomacyReportDialog d(d_player);
-  d.set_parent_window(*dialog.get());
+  d.set_parent_window(*dialog);
   d.run();
   d.hide();
 }
