@@ -1,8 +1,8 @@
-//  Copyright (C) 2008 Ben Asselstine
+//  Copyright (C) 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,10 +17,8 @@
 
 #include <config.h>
 
-#include <libglademm/xml.h>
+#include <gtkmm.h>
 #include <sigc++/functors/mem_fun.h>
-#include <gtkmm/label.h>
-#include <gtkmm/image.h>
 
 #include "diplomacy-report-dialog.h"
 
@@ -39,22 +37,20 @@ DiplomacyReportDialog::DiplomacyReportDialog(Player *player)
   GraphicsCache *gc = GraphicsCache::getInstance();
   Playerlist *pl = Playerlist::getInstance();
   d_player = player;
-  Glib::RefPtr<Gnome::Glade::Xml> xml
-    = Gnome::Glade::Xml::create(get_glade_path() + 
-				"/diplomacy-report-dialog.glade");
+  Glib::RefPtr<Gtk::Builder> xml
+    = Gtk::Builder::create_from_file(get_glade_path() + 
+				"/diplomacy-report-dialog.ui");
 
-  Gtk::Dialog *d = 0;
-  xml->get_widget("dialog", d);
-  dialog.reset(d);
-  decorate(dialog.get());
-  window_closed.connect(sigc::mem_fun(dialog.get(), &Gtk::Dialog::hide));
+  xml->get_widget("dialog", dialog);
+  decorate(dialog);
+  window_closed.connect(sigc::mem_fun(dialog, &Gtk::Dialog::hide));
 
   xml->get_widget("diplomacy_table", d_table);
 
   int order[MAX_PLAYERS];
 
   /* find the diplomatic order of the players */
-  for (Uint32 i = 0; i < MAX_PLAYERS; i++)
+  for (guint32 i = 0; i < MAX_PLAYERS; i++)
     {
       order[i] = -1;
       for (Playerlist::iterator it = pl->begin(); it != pl->end(); ++it)
@@ -70,35 +66,41 @@ DiplomacyReportDialog::DiplomacyReportDialog(Player *player)
     }
 
   /* show the players in order of their diplomatic ranking. */
-  for (Uint32 i = 0; i < MAX_PLAYERS; i++)
+  for (guint32 i = 0; i < MAX_PLAYERS; i++)
     {
       if (order[i] == -1)
 	continue;
       Player *p = pl->getPlayer(order[i]);
 
-      Glib::RefPtr<Gdk::Pixbuf> pixbuf = to_pixbuf(gc->getShieldPic(2, p));
-      Gtk::Image *im = manage(new Gtk::Image(pixbuf));
+      Glib::RefPtr<Gdk::Pixbuf> pix = gc->getShieldPic(2, p)->to_pixbuf();
+      Gtk::Image *im = manage(new Gtk::Image());
+      im->property_pixbuf() = pix;
       d_table->attach(*im, 1, 2, i + 1, i + 2, Gtk::SHRINK, Gtk::SHRINK);
-      Gtk::Image *im2 = manage(new Gtk::Image(pixbuf));
+      Gtk::Image *im2 = manage(new Gtk::Image());
+      im2->property_pixbuf() = pix;
       d_table->attach(*im2, i + 2, i + 3, 0, 0 + 1, Gtk::SHRINK, Gtk::SHRINK);
       Gtk::Label *label = manage(new Gtk::Label(p->getDiplomaticTitle()));
       d_table->attach(*label, 0, 1, i + 1, i + 2, Gtk::SHRINK, Gtk::SHRINK);
   
-      for (Uint32 j = 0; j < MAX_PLAYERS; j++)
+      for (guint32 j = 0; j < MAX_PLAYERS; j++)
 	{
 	  if (order[j] == -1)
 	    continue;
 	  Player::DiplomaticState state;
 	  state = p->getDiplomaticState(pl->getPlayer(order[j]));
-	  Glib::RefPtr<Gdk::Pixbuf> pixbuf2 = 
-	    to_pixbuf(gc->getDiplomacyPic(0, state));
-	  Gtk::Image *im3 = manage(new Gtk::Image(pixbuf2));
+	  Glib::RefPtr<Gdk::Pixbuf> pix2 = gc->getDiplomacyPic(0, state)->to_pixbuf();
+	  Gtk::Image *im3 = manage(new Gtk::Image());
+	  im3->property_pixbuf() = pix2;
 	  d_table->attach(*im3, i + 2, i + 3, j + 1, j + 2, 
 			  Gtk::SHRINK, Gtk::SHRINK);
 	}
     }
 }
 
+DiplomacyReportDialog::~DiplomacyReportDialog()
+{
+  delete dialog;
+}
 void DiplomacyReportDialog::set_parent_window(Gtk::Window &parent)
 {
   dialog->set_transient_for(parent);
