@@ -57,6 +57,7 @@
 #include "NextTurnNetworked.h"
 #include "pbm/pbm.h"
 #include "recently-played-game-list.h"
+#include "recently-played-game.h"
 #include "Backpack.h"
 #include "Item.h"
 #include "city.h"
@@ -66,6 +67,11 @@
 #include "stacklist.h"
 #include "smallmap.h"
 #include "new-random-map-dialog.h"
+#include "network_player.h"
+#include "profile.h"
+#include "profilelist.h"
+#include "gamelist-client.h"
+#include "gamehost-client.h"
 
 Driver::Driver(std::string load_filename)
 {
@@ -102,11 +108,173 @@ Driver::Driver(std::string load_filename)
 	run();
 	return;
       }
+    if (Main::instance().start_headless_server)
+      {
+        GameScenario *game_scenario = NULL;
+        std::string path = load_filename;
+        if (load_filename.empty() == true)
+          {
+            GameParameters g;
+            get_default(MAX_PLAYERS, g);
+            game_scenario = create_new_scenario(g, GameScenario::NETWORKED);
+            if (!game_scenario)
+              {
+                cerr << "Error: could not load randomly generated map." << 
+                  std::endl;
+                exit(1);
+              }
+          }
+        else
+          {
+            bool broken = false;
+            GameParameters g = GameScenario::loadGameParameters(load_filename, 
+                                                                broken);
+            if (!broken)
+              game_scenario = load_game(load_filename);
+            if (!game_scenario || broken)
+              {
+                cerr << "Error: could not load file " << 
+                  load_filename << std::endl;
+                exit(1);
+              }
+            game_scenario->setPlayMode(GameScenario::NETWORKED);
+            game_scenario->initialize(g);
+          }
+        if (game_scenario)
+          serve (game_scenario);
+        return;
+      }
     splash_window->show();
     //here are the ones that do
     run();
 }
 
+void Driver::serve (GameScenario *game_scenario)
+{
+  if (!game_scenario)
+    return;
+  Playerlist::getInstance()->syncNeutral();
+  //okay we're going to host a game, using this file as a scenario.
+  GameServer *game_server = GameServer::getInstance();
+  guint32 port = LORDSAWAR_PORT;
+  if (Main::instance().port)
+    port = Main::instance().port;
+  game_server->port_in_use.connect(sigc::mem_fun(*this, &Driver::on_could_not_bind_to_port_for_headless_server));
+  std::string id = "";
+  if (Profilelist::getInstance()->empty() == false)
+    id = Profilelist::getInstance()->front()->getId();
+  game_server->start(game_scenario, port, id, "admin");
+  game_server = GameServer::getInstance();
+  if (game_server->isListening() == false)
+    {
+      GameServer::deleteInstance();
+      return;
+    }
+  printf("Game Server is now listening on port %d\n", port);
+  NextTurnNetworked *next_turn = new NextTurnNetworked(game_scenario->getTurnmode(), game_scenario->s_random_turns);
+  game_server->round_ends.connect(sigc::mem_fun(next_turn, &NextTurnNetworked::finishRound));
+  game_server->start_player_turn.connect(sigc::mem_fun(next_turn, &NextTurnNetworked::start_player));
+  next_turn->srequestAbort.connect(sigc::mem_fun(game_server, &GameServer::on_turn_aborted));
+  game_server->get_next_player.connect(sigc::mem_fun(next_turn, &NextTurnNetworked::next));
+  game_server->round_ends.connect
+    (sigc::mem_fun(*this, &Driver::on_keep_network_play_going));
+  Playerlist::getInstance()->splayerDead.connect
+    (sigc::mem_fun(GameServer::getInstance(), &GameServer::sendKillPlayer));
+
+  game_server->notifyClientsGameMayBeginNow();
+  Game *game = new Game(game_scenario, next_turn);
+  if (game)
+    game_server->player_sits.connect(sigc::mem_fun(this, &Driver::on_client_sits_down_in_headless_server_game));
+}
+
+void Driver::on_client_sits_down_in_headless_server_game(Player *p, std::string nick)
+{
+  static unsigned int count;
+  count++;
+  if (count == Playerlist::getInstance()->countPlayersAlive())
+    GameServer::getInstance()->sendRoundStart();
+}
+
+void Driver::get_default(int num_players, GameParameters &g)
+{
+  GameParameters::Player p;
+  if (num_players <= 1 || num_players > (int)MAX_PLAYERS)
+    num_players = (int)MAX_PLAYERS;
+  for (unsigned int i = 0; i < (unsigned int) num_players; i++)
+    {
+      p.type = GameParameters::Player::HUMAN;
+      p.id = i;
+      switch (p.id)
+        {
+        case 0: 
+          p.name = 
+            CreateScenarioRandomize::getPlayerName(Shield::WHITE); 
+          break;
+        case 1: 
+          p.name = 
+            CreateScenarioRandomize::getPlayerName(Shield::GREEN); 
+          break;
+        case 2: 
+          p.name = 
+            CreateScenarioRandomize::getPlayerName(Shield::YELLOW); 
+          break;
+        case 3: 
+          p.name = 
+            CreateScenarioRandomize::getPlayerName(Shield::DARK_BLUE); 
+          break;
+        case 4: 
+          p.name = 
+            CreateScenarioRandomize::getPlayerName(Shield::ORANGE); 
+          break;
+        case 5: 
+          p.name = 
+            CreateScenarioRandomize::getPlayerName(Shield::LIGHT_BLUE); 
+          break;
+        case 6: 
+          p.name = 
+            CreateScenarioRandomize::getPlayerName(Shield::RED); 
+          break;
+        case 7: 
+          p.name = 
+            CreateScenarioRandomize::getPlayerName(Shield::BLACK); 
+          break;
+        }
+      g.players.push_back(p);
+    }
+  g.map.width = MAP_SIZE_NORMAL_WIDTH;
+  g.map.height = MAP_SIZE_NORMAL_HEIGHT;
+  g.map.grass = 78;
+  g.map.water = 7;
+  g.map.swamp = 2;
+  g.map.forest = 3;
+  g.map.hills = 5;
+  g.map.mountains = 5;
+  g.map.cities = 80;
+  g.map.ruins = 15;
+  g.map.temples = 3;
+  g.map.signposts = 20;
+  g.map_path = "";
+  g.play_with_quests = GameParameters::ONE_QUEST_PER_PLAYER;
+  g.hidden_map = false;
+  g.neutral_cities = GameParameters::STRONG;
+  g.razing_cities = GameParameters::ALWAYS;
+  g.diplomacy = false;
+  g.random_turns = false;
+  g.quick_start = GameParameters::NO_QUICK_START;
+  g.intense_combat = false;
+  g.military_advisor = false;
+  g.army_theme = "default";
+  g.tile_theme = "default";
+  g.shield_theme = "default";
+  g.city_theme = "default";
+  g.process_armies = GameParameters::PROCESS_ARMIES_AT_PLAYERS_TURN;
+  g.difficulty = GameScenario::calculate_difficulty_rating(g);
+  g.cities_can_produce_allies = false;
+  g.cusp_of_war = false;
+  g.see_opponents_stacks = false;
+  g.see_opponents_production = false;
+}
+
 void Driver::run()
 {
   if (Main::instance().start_test_scenario) 
@@ -260,6 +428,24 @@ void Driver::on_hosted_player_stood_up(Player *player)
   player_replaced.emit(Playerlist::getInstance()->getPlayer(id));
 }
 
+void Driver::on_hosted_player_changed_name(Player *player, Glib::ustring name)
+{
+  GameServer *game_server = GameServer::getInstance();
+  game_server->name_change(player, name);
+}
+
+void Driver::on_hosted_player_changed_type(Player *player, int type)
+{
+  GameServer *game_server = GameServer::getInstance();
+  game_server->type_change(player, type);
+}
+
+void Driver::on_hosted_player_says_game_may_begin()
+{
+  GameServer *game_server = GameServer::getInstance();
+  game_server->notifyClientsGameMayBeginNow();
+}
+
 void Driver::on_hosted_player_chat(std::string message)
 {
   GameServer *game_server = GameServer::getInstance();
@@ -278,6 +464,18 @@ void Driver::on_client_player_stood_up(Player *player)
   game_client->stand_up(player);
 }
 
+void Driver::on_client_player_changed_name(Player *player, Glib::ustring name)
+{
+  GameClient *game_client = GameClient::getInstance();
+  game_client->change_name(player, name);
+}
+
+void Driver::on_client_player_changed_type(Player *player, int type)
+{
+  GameClient *game_client = GameClient::getInstance();
+  game_client->change_type(player, type);
+}
+
 void Driver::on_client_player_chat(std::string message)
 {
   GameClient *game_client = GameClient::getInstance();
@@ -300,6 +498,8 @@ GameScenario *Driver::create_new_scenario(GameParameters &g, GameScenario::PlayM
   bool broken = false;
 						 
   GameScenario* game_scenario = new GameScenario(g.map_path, broken);
+  if (broken)
+    return NULL;
 
   GameScenarioOptions::s_see_opponents_stacks = g.see_opponents_stacks;
   GameScenarioOptions::s_see_opponents_production = g.see_opponents_production;
@@ -313,9 +513,6 @@ GameScenario *Driver::create_new_scenario(GameParameters &g, GameScenario::PlayM
   GameScenarioOptions::s_military_advisor = g.military_advisor;
   GameScenarioOptions::s_random_turns = g.random_turns;
 
-  if (broken)
-    return NULL;
-
   game_scenario->setName(g.name);
   game_scenario->setPlayMode(m);
 
@@ -323,16 +520,135 @@ GameScenario *Driver::create_new_scenario(GameParameters &g, GameScenario::PlayM
     {
       if (update_uuid)
 	game_scenario->setNewRandomId();
-
       Playerlist::getInstance()->syncPlayers(g.players);
-
       game_scenario->initialize(g);
     }
   return game_scenario;
 }
 
+void Driver::advertise_game(GameScenario *game_scenario, Profile *p)
+{
+  GamelistClient::deleteInstance();
+  GamelistClient *gsc = GamelistClient ::getInstance();
+  gsc->client_connected.connect
+    (sigc::bind(sigc::mem_fun(*this, &Driver::on_connected_to_gamelist_server_for_advertising), game_scenario, p));
+  gsc->start(Configuration::s_gamelist_server_hostname,
+             Configuration::s_gamelist_server_port, p);
+}
+
+void Driver::on_connected_to_gamelist_server_for_advertising(GameScenario *game_scenario, Profile *p)
+{
+  GamelistClient *gsc = GamelistClient::getInstance();
+  //okay, fashion the recently played game to go over the wire.
+  RecentlyPlayedNetworkedGame *g = 
+    new RecentlyPlayedNetworkedGame(game_scenario, p);
+  g->setNumberOfPlayers(Playerlist::getInstance()->countPlayersAlive());
+  gsc->received_advertising_response.connect
+    (sigc::mem_fun(*this, &Driver::on_advertising_response_received));
+  gsc->request_advertising(g);
+}
+
+void Driver::on_advertising_response_received(std::string scenario_id, 
+                                              std::string err)
+{
+  d_advertised_scenario_id = scenario_id;
+  return;
+}
+
+void Driver::remotely_serve (GameScenario *game_scenario, Profile *p)
+{
+  if ((Configuration::s_gamehost_server_hostname == "" &&
+      Configuration::s_gamehost_server_port == 0) || !p || !game_scenario)
+    return;
+  GamehostClient::deleteInstance();
+  GamehostClient *ghc = GamehostClient::getInstance();
+  ghc->client_connected.connect(sigc::bind(sigc::mem_fun(*this, &Driver::on_connected_to_gamehost_server_for_hosting_request), game_scenario));
+  ghc->client_could_not_connect.connect(sigc::mem_fun(*this, &Driver::on_could_not_connect_to_gamehost_server));
+  ghc->start(Configuration::s_gamehost_server_hostname,
+             Configuration::s_gamehost_server_port, p);
+}
+
+void Driver::on_could_not_connect_to_gamehost_server()
+{
+  GamehostClient *ghc = GamehostClient::getInstance();
+  if (splash_window)
+    {
+      splash_window->show();
+      TimedMessageDialog dialog
+        (*splash_window->get_window(),
+         String::ucompose(_("Could not connect to gamehost server:\n%1:%2"),
+                          ghc->getHost(), ghc->getPort()), 0);
+      dialog.run();
+      dialog.hide();
+    }
+}
+
+void Driver::on_connected_to_gamehost_server_for_hosting_request (GameScenario *game_scenario)
+{
+  GamehostClient *ghc = GamehostClient::getInstance();
+  ghc->received_host_response.connect(sigc::bind(sigc::mem_fun(*this, &Driver::on_got_game_host_response), game_scenario));
+  ghc->request_game_host (game_scenario->getId());
+}
+
+void Driver::on_got_game_host_response(std::string scenario_id, std::string err, GameScenario *game_scenario)
+{
+  if (err != "")
+    {
+      if (splash_window)
+        {
+          splash_window->show();
+          Glib::ustring s = 
+            String::ucompose(_("Gamehost Server Error: %1"), err);
+          TimedMessageDialog dialog(*splash_window->get_window(), s, 0);
+          dialog.set_title(_("Server Failure"));
+          dialog.run();
+          dialog.hide();
+        }
+      return;
+    }
+  GamehostClient *ghc = GamehostClient::getInstance();
+  ghc->received_map_response.connect(sigc::mem_fun(*this, &Driver::on_remote_game_hosted));
+  if (download_window)
+    delete download_window;
+  download_window = new NewNetworkGameDownloadWindow(_("Uploading."));
+  download_window->pulse();
+  upload_heartbeat_conn = Glib::signal_timeout().connect
+    (bind_return(sigc::mem_fun(*this, &Driver::upload_heartbeat), true), 1 * 1000);
+  ghc->send_map(game_scenario);
+}
+
+void Driver::on_remote_game_hosted(std::string scenario_id, guint32 port, std::string err)
+{
+  upload_heartbeat_conn.disconnect();
+  if (download_window)
+    download_window->hide();
+  Profile *profile = 
+    Profilelist::getInstance()->findProfileById
+    (GamehostClient::getInstance()->getProfileId());
+  if (err != "")
+    {
+      if (splash_window)
+        {
+          splash_window->show();
+          Glib::ustring s = 
+            String::ucompose(_("Gamehost Server Error: %1"), err);
+          TimedMessageDialog dialog(*splash_window->get_window(), s, 0);
+          dialog.set_title(_("Server Failure"));
+          dialog.run();
+          dialog.hide();
+        }
+    return;
+    }
+  //yay, we did it.  the new game is waiting for us on the gamehost server 
+  //on the port they just sent us.
+  //so now we start up a client.
+  on_new_remote_network_game_requested
+    (Configuration::s_gamehost_server_hostname, port, profile);
+}
+
 void Driver::on_new_hosted_network_game_requested(GameParameters g, int port,
-						  std::string nick)
+						  Profile *p, bool advertised,
+                                                  bool remotely_hosted)
 {
     if (splash_window)
 	splash_window->hide();
@@ -348,19 +664,38 @@ void Driver::on_new_hosted_network_game_requested(GameParameters g, int port,
 	dialog.hide();
 	return;
       }
+    if (remotely_hosted)
+      {
+        remotely_serve (game_scenario, p);
+        return;
+      }
 
   GameServer *game_server = GameServer::getInstance();
-  game_server->start(game_scenario, port, nick);
+  game_server->port_in_use.connect(sigc::mem_fun(*this, &Driver::on_could_not_bind_to_port));
+  game_server->start(game_scenario, port, p->getId(), p->getNickname());
+  game_server = GameServer::getInstance();
+  if (game_server->isListening() == false)
+    {
+      GameServer::deleteInstance();
+      return;
+    }
+  if (advertised)
+    advertise_game(game_scenario, p);
   NextTurnNetworked *next_turn = new NextTurnNetworked(game_scenario->getTurnmode(), game_scenario->s_random_turns);
-  if (game_scenario->s_random_turns == true)
-    next_turn->snextRound.connect (sigc::mem_fun(GameServer::getInstance(), 
-						 &GameServer::sendTurnOrder));
-  next_turn->snextPlayerUnavailable.connect(sigc::mem_fun(this, &Driver::on_player_unavailable));
+  game_server->round_ends.connect(sigc::mem_fun(next_turn, &NextTurnNetworked::finishRound));
+  if (advertised)
+    game_server->round_ends.connect
+      (sigc::bind(sigc::mem_fun(*this, &Driver::on_advertised_game_round_ends),
+                  game_scenario, p));
+  game_server->start_player_turn.connect(sigc::mem_fun(next_turn, &NextTurnNetworked::start_player));
+  next_turn->srequestAbort.connect(sigc::mem_fun(game_server, &GameServer::on_turn_aborted));
   if (game_lobby_dialog)
     delete game_lobby_dialog;
   game_lobby_dialog = new GameLobbyDialog(game_scenario, next_turn, 
 					      game_server, true);
-  game_server->round_begins.connect(sigc::mem_fun(next_turn, &NextTurnNetworked::start));
+  game_server->get_next_player.connect(sigc::mem_fun(next_turn, &NextTurnNetworked::next));
+  game_server->round_ends.connect
+    (sigc::mem_fun(*this, &Driver::on_keep_network_play_going));
   Playerlist::getInstance()->splayerDead.connect
     (sigc::mem_fun(GameServer::getInstance(), &GameServer::sendKillPlayer));
   game_lobby_dialog->set_parent_window(*splash_window->get_window());
@@ -368,8 +703,14 @@ void Driver::on_new_hosted_network_game_requested(GameParameters g, int port,
     (sigc::mem_fun(this, &Driver::on_hosted_player_sat_down));
   game_lobby_dialog->player_stood_up.connect
     (sigc::mem_fun(this, &Driver::on_hosted_player_stood_up));
+  game_lobby_dialog->player_changed_name.connect
+    (sigc::mem_fun(this, &Driver::on_hosted_player_changed_name));
+  game_lobby_dialog->player_changed_type.connect
+    (sigc::mem_fun(this, &Driver::on_hosted_player_changed_type));
   game_lobby_dialog->message_sent.connect
     (sigc::mem_fun(this, &Driver::on_hosted_player_chat));
+  game_lobby_dialog->game_may_begin.connect
+    (sigc::mem_fun(this, &Driver::on_hosted_player_says_game_may_begin));
   game_lobby_dialog->start_network_game.connect
     (sigc::mem_fun(this, &Driver::start_network_game_requested));
   game_lobby_dialog->show();
@@ -378,16 +719,20 @@ void Driver::on_new_hosted_network_game_requested(GameParameters g, int port,
     
   if (response == false)
     {
+      if (d_advertised_scenario_id != "")
+        unadvertise_game (d_advertised_scenario_id, p);
       GameServer::deleteInstance();
+
       delete game_scenario;
       if (splash_window)
-	splash_window->show();
+        splash_window->show();
     }
 }
 
   
 void Driver::on_server_went_away()
 {
+  upload_heartbeat_conn.disconnect();
   heartbeat_conn.disconnect();
   if (game_lobby_dialog)
     game_lobby_dialog->hide();
@@ -395,11 +740,12 @@ void Driver::on_server_went_away()
     download_window->hide();
   if (splash_window)
     splash_window->show();
-  GameClient::deleteInstance();
   TimedMessageDialog dialog(*splash_window->get_window(), 
 			    _("Server went away."), 0);
+  dialog.set_title(_("Disconnected"));
   dialog.run();
   dialog.hide();
+  GameClient::deleteInstance();
 }
 
 void Driver::on_client_could_not_connect()
@@ -411,14 +757,17 @@ void Driver::on_client_could_not_connect()
     download_window->hide();
   if (splash_window)
     splash_window->show();
-  GameClient::deleteInstance();
-  TimedMessageDialog dialog(*splash_window->get_window(), 
-			    _("Could not connect."), 0);
+  GameClient *gc = GameClient::getInstance();
+  TimedMessageDialog dialog
+    (*splash_window->get_window(), 
+     String::ucompose(_("Could not connect to server:\n%1 %2"),
+                        gc->getHost(), gc->getPort()), 0);
   dialog.run();
   dialog.hide();
+  GameClient::deleteInstance();
 }
 
-void Driver::on_new_remote_network_game_requested(std::string host, unsigned short port, std::string nick)
+void Driver::on_new_remote_network_game_requested(std::string host, unsigned short port, Profile *p)
 {
   if (splash_window)
     splash_window->hide();
@@ -427,20 +776,28 @@ void Driver::on_new_remote_network_game_requested(std::string host, unsigned sho
     (sigc::mem_fun(this, &Driver::on_game_scenario_downloaded));
   game_client->client_disconnected.connect
     (sigc::mem_fun(this, &Driver::on_server_went_away));
+  game_client->client_forcibly_disconnected.connect
+    (sigc::mem_fun(this, &Driver::on_server_went_away));
   game_client->client_could_not_connect.connect
     (sigc::mem_fun(this, &Driver::on_client_could_not_connect));
   game_scenario_received.connect
-    (sigc::mem_fun(this, &Driver::on_game_scenario_received));
+    (sigc::bind(sigc::mem_fun(this, &Driver::on_game_scenario_received), p));
   if (download_window)
     delete download_window;
   download_window = new NewNetworkGameDownloadWindow();
   download_window->pulse();
-  game_client->start(host, port, nick);
+  game_client->start(host, port, p->getId(), p->getNickname());
   heartbeat_conn = Glib::signal_timeout().connect
     (bind_return(sigc::mem_fun(*this, &Driver::heartbeat), true), 1 * 1000);
 
 }
 
+void Driver::upload_heartbeat()
+{
+  if (download_window)
+    download_window->pulse();
+}
+
 void Driver::heartbeat()
 {
   static bool already_done = false;
@@ -457,7 +814,7 @@ void Driver::heartbeat()
   already_done = true;
 }
 
-void Driver::on_game_scenario_received(std::string path)
+void Driver::on_game_scenario_received(std::string path, Profile *p)
 {
   heartbeat_conn.disconnect();
   if (download_window)
@@ -466,12 +823,13 @@ void Driver::on_game_scenario_received(std::string path)
   GameClient *game_client = GameClient::getInstance();
   std::string host = game_client->getHost();
   guint32 port = game_client->getPort();
-  RecentlyPlayedGameList::getInstance()->addNetworkedEntry(game_scenario, host, port);
-  RecentlyPlayedGameList::getInstance()->saveToFile(File::getSavePath() + "/recently-played.xml");
+  RecentlyPlayedGameList::getInstance()->addNetworkedEntry(game_scenario, p, host, port);
+  RecentlyPlayedGameList::getInstance()->save();
 
   NextTurnNetworked *next_turn = new NextTurnNetworked(game_scenario->getTurnmode(), game_scenario->s_random_turns);
-  next_turn->snextPlayerUnavailable.connect(sigc::mem_fun(this, &Driver::on_player_unavailable));
-  game_client->round_begins.connect(sigc::mem_fun(next_turn, &NextTurnNetworked::start));
+  game_client->start_player_turn.connect(sigc::mem_fun(next_turn, &NextTurnNetworked::start_player));
+  //game_client->round_begins.connect(sigc::mem_fun(next_turn, &NextTurnNetworked::start));
+  game_client->round_ends.connect(sigc::mem_fun(next_turn, &NextTurnNetworked::finishRound));
   if (game_lobby_dialog)
     delete game_lobby_dialog;
   game_lobby_dialog = new GameLobbyDialog(game_scenario, next_turn, 
@@ -481,6 +839,10 @@ void Driver::on_game_scenario_received(std::string path)
     (sigc::mem_fun(this, &Driver::on_client_player_sat_down));
   game_lobby_dialog->player_stood_up.connect
     (sigc::mem_fun(this, &Driver::on_client_player_stood_up));
+  game_lobby_dialog->player_changed_name.connect
+    (sigc::mem_fun(this, &Driver::on_client_player_changed_name));
+  game_lobby_dialog->player_changed_type.connect
+    (sigc::mem_fun(this, &Driver::on_client_player_changed_type));
   game_lobby_dialog->message_sent.connect
     (sigc::mem_fun(this, &Driver::on_client_player_chat));
   game_lobby_dialog->start_network_game.connect
@@ -491,6 +853,9 @@ void Driver::on_game_scenario_received(std::string path)
 
   if (response == false)
     {
+      GameClient::getInstance()->disconnect();
+      on_game_ended();
+
       if (splash_window)
 	splash_window->show();
     
@@ -577,16 +942,23 @@ void Driver::on_load_requested(std::string filename)
 					  game_scenario->s_random_turns));
       }
     else if (game_scenario->getPlayMode() == GameScenario::NETWORKED)
-      game_window->load_game
-	(game_scenario, new NextTurnNetworked(game_scenario->getTurnmode(),
-					      game_scenario->s_random_turns));
+      {
+	TimedMessageDialog dialog(*splash_window->get_window(),
+				  _("Can't load networked game from file."), 0);
+	dialog.run();
+	dialog.hide();
+        //well isn't this interesting.  we lack a game station.
+      //game_window->load_game
+	//(game_scenario, new NextTurnNetworked(game_scenario->getTurnmode(),
+					      //game_scenario->s_random_turns));
+      }
 }
 
 void Driver::on_quit_requested()
 {
     if (splash_window)
 	splash_window->hide();
-    
+
     if (game_window)
 	game_window->hide();
 
@@ -595,16 +967,32 @@ void Driver::on_quit_requested()
 
 void Driver::on_game_ended()
 {
+    if (game_lobby_dialog)
+      game_lobby_dialog->clean_up_players();
   if (game_window)
     {
       game_window->hide();
     }
+
+  if (GameServer::getInstance()->isListening() &&
+      d_advertised_scenario_id != "")
+    {
+      GameServer *gs = GameServer::getInstance();
+      Profile *profile = 
+        Profilelist::getInstance()->findProfileById(gs->getProfileId());
+      unadvertise_game (d_advertised_scenario_id, profile);
+    }
+
   GameClient::deleteInstance();
   PbmGameClient::deleteInstance();
   GameServer::deleteInstance();
   PbmGameServer::deleteInstance();
 
   GraphicsCache::deleteInstance();
+  GamehostClient::getInstance()->disconnect();
+  GamehostClient::deleteInstance();
+  GamelistClient::getInstance()->disconnect();
+  GamelistClient::deleteInstance();
 
   splash_window->show();
 }
@@ -764,7 +1152,6 @@ void Driver::stressTestNextRound()
 
 void Driver::stress_test()
 {
-
   // quick load a test scenario
   GameParameters g;
   GameParameters::Player p;
@@ -852,7 +1239,7 @@ void Driver::stress_test()
   printf("winner type: %s\n", Player::playerTypeToString(Player::Type(Playerlist::getInstance()->getFirstLiving()->getType())).c_str());
   Glib::ustring s = String::ucompose("/tmp/run-seed-%1", 
                                      Main::instance().random_number_seed);
-  game_scenario->saveGame(s + ".sav");
+  game_scenario->saveGame(s + SAVE_EXT);
 
 }
 	
@@ -863,12 +1250,17 @@ void Driver::lordsawaromatic(std::string host, unsigned short port, Player::Type
     (sigc::mem_fun(this, &Driver::on_game_scenario_downloaded));
   game_client->client_disconnected.connect
     (sigc::mem_fun(this, &Driver::on_server_went_away));
+  game_client->client_forcibly_disconnected.connect
+    (sigc::mem_fun(this, &Driver::on_server_went_away));
   game_client->client_could_not_connect.connect
     (sigc::mem_fun(this, &Driver::on_client_could_not_connect));
   game_scenario_received.connect
     (sigc::mem_fun(this, &Driver::on_game_scenario_received_for_robots));
-  game_client->setNickname("lordsawaromatic");
-  game_client->start(host, port, "lordsawaromatic");
+  game_client->setNickname("robot");
+  std::string id = "";
+  if (Profilelist::getInstance()->empty() == false)
+    id = Profilelist::getInstance()->front()->getId();
+  game_client->start(host, port, id, "robot");
   heartbeat_conn = Glib::signal_timeout().connect
     (bind_return(sigc::mem_fun(*this, &Driver::heartbeat), true), 1 * 1000);
   robot_player_type = type;
@@ -877,35 +1269,63 @@ void Driver::lordsawaromatic(std::string host, unsigned short port, Player::Type
 
 void Driver::on_game_scenario_received_for_robots(std::string path)
 {
+
   heartbeat_conn.disconnect();
   GameScenario *game_scenario = load_game(path);
+  if (!game_scenario)
+    return;
+  GameClient *game_client = GameClient::getInstance();
   NextTurnNetworked *next_turn = new NextTurnNetworked(game_scenario->getTurnmode(), game_scenario->s_random_turns);
-  GameClient::getInstance()->round_begins.connect(sigc::mem_fun(next_turn, &NextTurnNetworked::start));
+  game_client->start_player_turn.connect(sigc::mem_fun(next_turn, &NextTurnNetworked::start_player));
+  game_client->round_ends.connect(sigc::mem_fun(next_turn, &NextTurnNetworked::finishRound));
+
   Playerlist *pl = Playerlist::getInstance();
 
   unsigned int count = 0;
   for (Playerlist::iterator it = pl->begin(); it != pl->end(); it++)
     {
+      if ((*it) == Playerlist::getInstance()->getNeutral())
+        continue;
       if (count >= number_of_robots && number_of_robots > 0)
 	break;
       if ((*it)->getType() == Player::NETWORKED)
-	{
-	  on_client_player_sat_down(*it);
-	  count++;
-	}
+        {
+          on_client_player_sat_down(*it);
+          count++;
+        }
+    }
+  /*
+   * this is buggy because we're sitting down as players who may have
+   * already sat down.
+   *
+   * we can't use isConnected() because it's not saved in the save game.
+   *
+   * the game server doesn't seat the ai players who may already be 
+   * remotely sitting.
+   * the game lobby server does that.
+   *
+   * so we say sit, and then the game server disallows that, and we think we
+   * sat down.
+   *
+   */
+  if (count == 0)
+    {
+      printf("nowhere to sit!\n");
+      GameClient::deleteInstance();
+      delete next_turn;
+      delete game_scenario;
+      return;
     }
 
   pl->turnHumansInto(robot_player_type, number_of_robots);
 
   for (Playerlist::iterator it = pl->begin(); it != pl->end(); it++)
     if (Player::Type((*it)->getType()) == robot_player_type)
-      {
-	GameClient::getInstance()->listenForLocalEvents(*it);
-      }
+      GameClient::getInstance()->listenForLocalEvents(*it);
 
-  //end turn signals are listened to by next_turn, that are fired by the game client decoder
-
-  next_turn->start();
+  Game *game = new Game(game_scenario, next_turn);
+  game->get_smallmap().set_slide_speed(0);
+  game_client->request_seat_manifest();
 }
 
 void Driver::on_show_lobby_requested()
@@ -918,7 +1338,6 @@ void Driver::start_network_game_requested(GameScenario *game_scenario, NextTurnN
 {
   if (game_window)
     {
-  
       Player *active = Playerlist::getActiveplayer();
       if (active->getType() == Player::NETWORKED)
 	game_window->show();
@@ -938,11 +1357,69 @@ void Driver::start_network_game_requested(GameScenario *game_scenario, NextTurnN
       game_window->show();
 
       game_window->new_network_game (game_scenario, next_turn);
+      if (GameServer::getInstance()->isListening())
+        on_keep_network_play_going();
+
     }
 }
-  
-void Driver::on_player_unavailable(Player *p)
+
+void Driver::on_keep_network_play_going()
 {
-  game_lobby_dialog->player_is_unavailable(p);
-  on_show_lobby_requested();
+  while (GameServer::getInstance()->isListening())
+    {
+      bool round_finished = GameServer::getInstance()->sendRoundStart();
+      if (!round_finished)
+        {
+          //we are waiting for a player to finish their turn
+          //or they are unavailable.
+          break;
+          ;
+        }
+    }
+}
+    
+void Driver::on_could_not_bind_to_port_for_headless_server(int port)
+{
+  cerr << "Could not bind to port " << port << std::endl;
+  exit(1);
+}
+
+void Driver::on_could_not_bind_to_port (int port)
+{
+  if (splash_window)
+    splash_window->show();
+  Glib::ustring s = String::ucompose(_("Could not bind to port %1"), port);
+  TimedMessageDialog dialog(*splash_window->get_window(), s, 0);
+  dialog.set_title(_("Server Failure"));
+  dialog.run();
+  dialog.hide();
+}
+
+void Driver::unadvertise_game(std::string scenario_id, Profile *p)
+{
+  GamelistClient *gsc = GamelistClient ::getInstance();
+  gsc->client_connected.connect
+    (sigc::bind(sigc::mem_fun(*this, &Driver::on_connected_to_gamelist_server_for_advertising_removal), scenario_id));
+  gsc->start(Configuration::s_gamelist_server_hostname,
+             Configuration::s_gamelist_server_port, p);
+}
+
+void Driver::on_connected_to_gamelist_server_for_advertising_removal(std::string scenario_id)
+{
+  GamelistClient *gsc = GamelistClient::getInstance();
+  gsc->received_advertising_removal_response.connect
+    (sigc::mem_fun(*this, &Driver::on_advertising_removal_response_received));
+  gsc->request_advertising_removal(scenario_id);
+}
+
+void Driver::on_advertising_removal_response_received(std::string scenario_id, 
+                                                      std::string err)
+{
+  d_advertised_scenario_id = "";
+  return;
+}
+
+void Driver::on_advertised_game_round_ends(GameScenario *game_scenario, Profile *p)
+{
+  advertise_game(game_scenario, p);
 }
