@@ -1,5 +1,5 @@
 //  Copyright (C) 2007 Ole Laursen
-//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009, 2011 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 #include "new-network-game-download-window.h"
 #include "game-parameters.h"
 
+class Profile;
 // takes care of setting up the splash window and the game window, the
 // interaction between them and the model classes
 // it also takes care of the game lobby window.
@@ -47,18 +48,20 @@ class Driver: public sigc::trackable
     NewNetworkGameDownloadWindow* download_window;
     std::string d_load_filename;
     sigc::connection heartbeat_conn;
+    sigc::connection upload_heartbeat_conn;
     Player::Type robot_player_type;
+    std::string d_advertised_scenario_id;
     unsigned int number_of_robots;
     std::string game_scenario_downloaded;
     sigc::signal<void, std::string> game_scenario_received;
     sigc::signal<void, Player*> player_replaced;
 
     void on_new_game_requested(GameParameters g);
-    void on_new_remote_network_game_requested(std::string host, unsigned short port, std::string nick);
-    void on_new_hosted_network_game_requested(GameParameters g, int port, std::string nick);
+    void on_new_remote_network_game_requested(std::string host, unsigned short port, Profile *p);
+    void on_new_hosted_network_game_requested(GameParameters g, int port, Profile *p, bool advertised, bool remotely_hosted);
     void on_new_pbm_game_requested(GameParameters g);
     void on_game_scenario_downloaded(std::string filename);
-    void on_game_scenario_received(std::string path);
+    void on_game_scenario_received(std::string path, Profile *p);
     void on_load_requested(std::string filename);
     void on_quit_requested();
 
@@ -70,8 +73,12 @@ class Driver: public sigc::trackable
 
     void on_hosted_player_sat_down(Player *player);
     void on_hosted_player_stood_up(Player *player);
+    void on_hosted_player_changed_name(Player *player, Glib::ustring name);
+    void on_hosted_player_changed_type(Player *player, int type);
     void on_client_player_sat_down(Player *player);
     void on_client_player_stood_up(Player *player);
+    void on_client_player_changed_name(Player *player, Glib::ustring name);
+    void on_client_player_changed_type(Player *player, int type);
     void on_server_went_away();
     void on_client_could_not_connect();
 
@@ -85,18 +92,43 @@ class Driver: public sigc::trackable
   
 
     void heartbeat();
+    void upload_heartbeat();
 
     void on_client_player_chat(std::string message);
     void on_hosted_player_chat(std::string message);
+    void on_hosted_player_says_game_may_begin();
 
     void on_show_lobby_requested();
 
     void start_network_game_requested(GameScenario *game_scenario,
 				      NextTurnNetworked *next_turn);
 
-    void on_player_unavailable(Player *p);
+    void on_keep_network_play_going(); //starts a new round
 
     GameScenario *create_new_scenario(GameParameters &g, GameScenario::PlayMode m);
+
+    void get_default(int num_players, GameParameters &g);
+    void serve (GameScenario *game_scenario);
+    void remotely_serve (GameScenario *game_scenario, Profile *p);
+    void on_client_sits_down_in_headless_server_game(Player *p, std::string nick);
+  
+    void on_could_not_bind_to_port_for_headless_server(int port);
+    void on_could_not_bind_to_port (int port);
+
+    void advertise_game(GameScenario *game_scenario, Profile *p);
+    void on_connected_to_gamelist_server_for_advertising(GameScenario *game_scenario, Profile *p);
+
+    void on_advertising_response_received(std::string scenario_id, std::string err);
+    void unadvertise_game(std::string scenario_id, Profile *p);
+    void on_connected_to_gamelist_server_for_advertising_removal(std::string scenario_id);
+    void on_advertising_removal_response_received(std::string scenario_id, std::string err);
+
+    void on_advertised_game_round_ends(GameScenario *game_scenario, Profile *p);
+
+    void on_connected_to_gamehost_server_for_hosting_request (GameScenario *game_scenario);
+    void on_got_game_host_response(std::string scenario_id, std::string err, GameScenario *game_scenario);
+    void on_remote_game_hosted(std::string scenario_id, guint32 port, std::string err);
+    void on_could_not_connect_to_gamehost_server();
 };
 
 
