@@ -1,8 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,7 +18,7 @@
 
 #include <config.h>
 
-#include <gtkmm/messagedialog.h>
+#include <gtkmm.h>
 
 #include "defs.h"
 
