@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -21,12 +21,8 @@
 #include <memory>
 #include <sigc++/trackable.h>
 #include <sigc++/signal.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/liststore.h>
-#include <gtkmm/treemodelcolumn.h>
-#include <gtkmm/treeview.h>
+#include <gtkmm.h>
 #include <list>
-#include <SDL.h>
 
 class Stack;
 class Player;
@@ -39,6 +35,7 @@ class FightOrderDialog: public Decorated
 {
  public:
     FightOrderDialog(Player *player);
+    ~FightOrderDialog();
 
     void set_parent_window(Gtk::Window &parent);
 
@@ -47,10 +44,11 @@ class FightOrderDialog: public Decorated
     void run();
 
  private:
-    std::auto_ptr<Gtk::Dialog> dialog;
+    Gtk::Dialog* dialog;
 
     Player *player;
     Gtk::TreeView *armies_treeview;
+    Gtk::Button *reverse_button;
 
     class ArmiesColumns: public Gtk::TreeModelColumnRecord {
     public:
@@ -59,12 +57,13 @@ class FightOrderDialog: public Decorated
 	
 	Gtk::TreeModelColumn<Glib::RefPtr<Gdk::Pixbuf> > image;
 	Gtk::TreeModelColumn<Glib::ustring> name;
-	Gtk::TreeModelColumn<Uint32> army_type;
+	Gtk::TreeModelColumn<guint32> army_type;
     };
     const ArmiesColumns armies_columns;
     Glib::RefPtr<Gtk::ListStore> armies_list;
  private:
-    void addArmyType(Uint32 army_type);
+    void addArmyType(guint32 army_type);
+    void on_reverse_button_clicked();
 };
 
 #endif
