@@ -1,4 +1,4 @@
-//  Copyright (C) 2008, 2009 Ben Asselstine
+//  Copyright (C) 2008, 2009, 2011 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 #include <config.h>
 
 #include <gtkmm.h>
+#include <map>
 #include <sigc++/functors/mem_fun.h>
 
 #include "game-lobby-dialog.h"
@@ -38,19 +39,18 @@
 #include "shieldsetlist.h"
 #include "NextTurnNetworked.h"
 #include "recently-played-game-list.h"
+#include "game-parameters.h"
 
 namespace
 {
     Glib::ustring player_type_to_string(guint32 type)
     {
-	switch (type)
-	{
-	case Player::HUMAN: return HUMAN_PLAYER_TYPE;
-	case Player::AI_FAST: return EASY_PLAYER_TYPE;
-	case Player::AI_SMART: return HARD_PLAYER_TYPE;
-	case Player::NETWORKED: return NETWORKED_PLAYER_TYPE;
-	default: return NO_PLAYER_TYPE;
-	}
+      Glib::ustring s = 
+        GameParameters::player_param_to_string(GameParameters::player_type_to_player_param(type));
+      if (s == NETWORKED_PLAYER_TYPE)
+        return "";
+      else
+        return s;
     }
 }
 
@@ -80,10 +80,12 @@ void GameLobbyDialog::initDialog(GameScenario *gamescenario,
 				 NextTurnNetworked *next_turn,
 				 GameStation *game_station)
 {
-  Shieldsetlist::getInstance()->instantiateImages();
+  bool broken = false;
+  Shieldsetlist::getInstance()->instantiateImages(broken);
   d_game_scenario = gamescenario;
   d_game_station = game_station;
   d_next_turn = next_turn;
+  d_play_message_received = false;
   citymap = NULL;
     Glib::RefPtr<Gtk::Builder> xml
 	= Gtk::Builder::create_from_file(get_glade_path()
@@ -96,7 +98,6 @@ void GameLobbyDialog::initDialog(GameScenario *gamescenario,
     xml->get_widget("player_treeview", player_treeview);
     player_treeview->get_selection()->signal_changed().connect
           (sigc::mem_fun(*this, &GameLobbyDialog::on_player_selected));
-    //player_treeview->get_selection()->set_mode(Gtk::SELECTION_NONE);
     xml->get_widget("people_treeview", people_treeview);
     people_treeview->property_headers_visible() = true;
     xml->get_widget("play_button", play_button);
@@ -127,6 +128,8 @@ void GameLobbyDialog::initDialog(GameScenario *gamescenario,
 
     game_station->remote_player_moved.connect
       (sigc::mem_fun(*this, &GameLobbyDialog::on_remote_player_ends_turn));
+    game_station->remote_player_starts_move.connect
+      (sigc::mem_fun(*this, &GameLobbyDialog::on_remote_player_starts_turn));
     game_station->local_player_moved.connect
       (sigc::mem_fun(*this, &GameLobbyDialog::on_local_player_ends_turn));
     game_station->local_player_starts_move.connect
@@ -139,16 +142,28 @@ void GameLobbyDialog::initDialog(GameScenario *gamescenario,
       (sigc::mem_fun(*this, &GameLobbyDialog::on_player_sits));
     game_station->player_stands.connect
       (sigc::mem_fun(*this, &GameLobbyDialog::on_player_stands));
+    game_station->player_changes_name.connect
+      (sigc::mem_fun(*this, &GameLobbyDialog::on_player_changes_name));
+    game_station->player_changes_type.connect
+      (sigc::mem_fun(*this, &GameLobbyDialog::on_player_changes_type));
     game_station->remote_player_named.connect
       (sigc::mem_fun(*this, &GameLobbyDialog::on_remote_player_changes_name));
     game_station->chat_message_received.connect
       (sigc::mem_fun(*this, &GameLobbyDialog::on_chatted));
     game_station->playerlist_reorder_received.connect
       (sigc::mem_fun(*this, &GameLobbyDialog::on_reorder_playerlist));
+    game_station->round_begins.connect
+      (sigc::mem_fun(*this, &GameLobbyDialog::on_reorder_playerlist));
     game_station->remote_player_died.connect
       (sigc::mem_fun(*this, &GameLobbyDialog::on_player_died));
     game_station->local_player_died.connect
       (sigc::mem_fun(*this, &GameLobbyDialog::on_player_died));
+    game_station->nickname_changed.connect
+      (sigc::mem_fun(*this, &GameLobbyDialog::on_nickname_changed));
+    game_station->game_may_begin.connect
+      (sigc::mem_fun(*this, &GameLobbyDialog::on_play_message_received));
+    game_station->player_gets_turned_off.connect
+      (sigc::mem_fun(*this, &GameLobbyDialog::on_player_turned_off));
 
     update_player_details();
     update_buttons();
@@ -161,20 +176,45 @@ void GameLobbyDialog::initDialog(GameScenario *gamescenario,
 
 void GameLobbyDialog::update_buttons()
 {
+  if (d_play_button_clicked == true)
+    return;
   //if any types aren't networked, we can play.
   //if all types are networked then we can't.
-  Gtk::TreeModel::Children kids = player_list->children();
-  for (Gtk::TreeModel::Children::iterator i = kids.begin(); 
-       i != kids.end(); i++)
+  if (d_has_ops)
     {
-      Gtk::TreeModel::Row row = *i;
-      if (row[player_columns.type] != NETWORKED_PLAYER_TYPE)
-	{
-	  play_button->set_sensitive(true);
-	  return;
-	}
+      Gtk::TreeModel::Children kids = player_list->children();
+      for (Gtk::TreeModel::Children::iterator i = kids.begin(); 
+           i != kids.end(); i++)
+        {
+          Gtk::TreeModel::Row row = *i;
+          if (row[player_columns.type] != "")
+            {
+              play_button->set_sensitive(true);
+              return;
+            }
+        }
+      play_button->set_sensitive(false);
+    }
+  else
+    {
+      bool found = false;
+      //do we have a horse in the race?
+      Gtk::TreeModel::Children kids = player_list->children();
+      for (Gtk::TreeModel::Children::iterator i = kids.begin(); 
+           i != kids.end(); i++)
+        {
+          Gtk::TreeModel::Row row = *i;
+          if (row[player_columns.person] == d_game_station->getNickname())
+            {
+              found = true;
+              break;
+            }
+        }
+      if (found)
+        play_button->set_sensitive(d_play_message_received);
+      else
+        play_button->set_sensitive(false);
     }
-  play_button->set_sensitive(false);
 }
 
 void
@@ -186,6 +226,8 @@ GameLobbyDialog::update_player_details()
       player_list.reset();
     }
   player_list = Gtk::ListStore::create(player_columns);
+  player_list->set_sort_column (player_columns.order, Gtk::SORT_ASCENDING);
+
   // setup the player settings
   player_treeview->set_model(player_list);
 
@@ -215,6 +257,7 @@ GameLobbyDialog::update_player_details()
     ( name_renderer, sigc::mem_fun(*this, &GameLobbyDialog::cell_data_name));
   player_treeview->append_column(name_column);
 
+
   // the type column
   player_type_list = Gtk::ListStore::create(player_type_columns);
   Gtk::TreeModel::iterator i;
@@ -243,6 +286,7 @@ GameLobbyDialog::update_player_details()
 
   Playerlist *pl = Playerlist::getInstance();
 
+  guint32 count = 0;
   for (Playerlist::iterator i = pl->begin(), end = pl->end(); i != end; ++i)
     {
       Player *player = *i;
@@ -250,9 +294,11 @@ GameLobbyDialog::update_player_details()
 	continue;
       if (player->isDead())
 	continue;
-      add_player(player_type_to_string(player->getType()), player->getName(), 
+      add_player(count, player_type_to_string(player->getType()), player->getName(), 
 		 player);
+      count++;
     }
+  update_turn_indicator();
 }
 
 void GameLobbyDialog::on_sitting_changed(Gtk::CellEditable *editable,
@@ -263,10 +309,13 @@ void GameLobbyDialog::on_sitting_changed(Gtk::CellEditable *editable,
   Player *player;
   //maybe we can't make other ppl stand up
   if ((*iter)[player_columns.sitting] &&
-      (*iter)[player_columns.type] == NETWORKED_PLAYER_TYPE && d_has_ops == false)
+      (*iter)[player_columns.person] != d_game_station->getNickname() && 
+      d_has_ops == false)
     return;
 
+  sitting_renderer.set_sensitive(false);
   player = pl->getPlayer((*iter)[player_columns.player_id]);
+  d_player_id_of_sit_or_stand_request = player->getId();
 
   if (!(*iter)[player_columns.sitting])
     player_sat_down.emit(player);
@@ -280,11 +329,22 @@ GameLobbyDialog::GameLobbyDialog(GameScenario *game_scenario,
 				 bool has_ops)
 :name_column(_("Name"), name_renderer),
     type_column(_("Type"), type_renderer),
-    sitting_column(_("Seated"), sitting_renderer)
+    sitting_column(_("Controlled"), sitting_renderer)
 {
   d_has_ops = has_ops;
+  d_play_button_clicked = false;
+  d_play_message_received = false;
   initDialog(game_scenario, next_turn, game_station);
   update_scenario_details();
+  d_player_id_of_sit_or_stand_request = MAX_PLAYERS + 1;
+  d_player_id_of_name_change_request = MAX_PLAYERS + 1;
+  d_player_id_of_type_change_request = MAX_PLAYERS + 1;
+  name_column.set_resizable();
+  name_column.set_expand();
+  name_column.set_min_width(115);
+  name_renderer.property_ellipsize() = Pango::ELLIPSIZE_END;
+  player_treeview->get_column(2)->set_min_width(75);
+  player_treeview->get_column(2)->set_resizable();
 }
 
 GameLobbyDialog::~GameLobbyDialog()
@@ -345,9 +405,19 @@ void GameLobbyDialog::cell_data_type(Gtk::CellRenderer *renderer,
 void GameLobbyDialog::on_type_edited(const Glib::ustring &path,
 				     const Glib::ustring &new_text)
 {
-  (*player_list->get_iter(Gtk::TreePath(path)))[player_columns.type]
-    = new_text;
-  //fixme, make a player->changeType method, and send it as an action
+  Gtk::TreeModel::iterator iter = player_treeview->get_model()->get_iter(path);
+      
+  if ((*iter)[player_columns.sitting] == false)
+    return;
+  if ((*iter)[player_columns.person] != d_game_station->getNickname())
+    return;
+  type_renderer.set_sensitive(false);
+  Playerlist *pl = Playerlist::getInstance();
+  Player *player = pl->getPlayer((*iter)[player_columns.player_id]);
+  d_player_id_of_type_change_request = player->getId();
+
+  int type = GameParameters::player_param_string_to_player_param(new_text);
+  player_changed_type.emit (player, type);
 }
 
 void GameLobbyDialog::cell_data_name(Gtk::CellRenderer *renderer,
@@ -367,13 +437,23 @@ void GameLobbyDialog::on_name_edited(const Glib::ustring &path,
   Playerlist *pl = Playerlist::getInstance();
   Player *player;
   Gtk::TreeModel::iterator iter = player_treeview->get_model()->get_iter(path);
-  if ((*iter)[player_columns.sitting] == false)
+  if (d_has_ops == false)
+    {
+      if ((*iter)[player_columns.sitting] == false)
+        return;
+      if ((*iter)[player_columns.person] != d_game_station->getNickname())
+        return;
+    }
+  Glib::ustring new_name = String::utrim(new_text);
+  if (new_name.empty() == true)
     return;
-  player = pl->getPlayer((*iter)[player_columns.player_id]);
 
-  player->rename(new_text);
-  (*player_list->get_iter(Gtk::TreePath(path)))[player_columns.name]
-    = new_text;
+  name_renderer.set_sensitive(false);
+  player = pl->getPlayer((*iter)[player_columns.player_id]);
+  d_player_id_of_name_change_request = player->getId();
+
+  //here's where we send the message saying that the name has changed.
+  player_changed_name.emit(player, new_name);
 }
 
 void GameLobbyDialog::cell_data_sitting(Gtk::CellRenderer *renderer,
@@ -382,13 +462,12 @@ void GameLobbyDialog::cell_data_sitting(Gtk::CellRenderer *renderer,
   dynamic_cast<Gtk::CellRendererToggle*>(renderer)->set_active((*i)[player_columns.sitting]);
 }
 
-void GameLobbyDialog::add_player(const Glib::ustring &type,
+void GameLobbyDialog::add_player(guint32 order, const Glib::ustring &type,
 				 const Glib::ustring &name, Player *player)
 {
   GraphicsCache *gc = GraphicsCache::getInstance();
   Gtk::TreeIter i = player_list->append();
-  if (player == Playerlist::getInstance()->getActiveplayer())
-    (*i)[player_columns.turn] = gc->getCursorPic(GraphicsCache::SWORD)->to_pixbuf();
+  (*i)[player_columns.order] = order;
   (*i)[player_columns.shield] = gc->getShieldPic(1, player)->to_pixbuf();
   (*i)[player_columns.type] = type;
   (*i)[player_columns.name] = name;
@@ -439,10 +518,66 @@ void GameLobbyDialog::on_remote_participant_departs(std::string nickname)
     }
 }
 
+void GameLobbyDialog::on_player_changes_name(Player *p, Glib::ustring name)
+{
+  if (!p)
+    return;
+  if (p->getId() == d_player_id_of_name_change_request)
+    {
+      name_renderer.set_sensitive(true);
+      d_player_id_of_name_change_request = MAX_PLAYERS + 1;
+    }
+  //look for the row that has the right player id, and change the name
+  Gtk::TreeModel::Children kids = player_list->children();
+  for (Gtk::TreeModel::Children::iterator i = kids.begin(); 
+       i != kids.end(); i++)
+    {
+      Gtk::TreeModel::Row row = *i;
+      if (row[player_columns.player_id] == p->getId())
+        {
+          p->setName(name);
+          row[player_columns.name] = name;
+        }
+    }
+}
+
+void GameLobbyDialog::on_player_changes_type(Player *p, int type)
+{
+  if (!p)
+    return;
+  if (p->getId() == d_player_id_of_type_change_request)
+    {
+      type_renderer.set_sensitive(true);
+      d_player_id_of_type_change_request = MAX_PLAYERS + 1;
+    }
+  Gtk::TreeModel::Children kids = player_list->children();
+  //look for the row that has the right player id.
+  for (Gtk::TreeModel::Children::iterator i = kids.begin(); 
+       i != kids.end(); i++)
+    {
+      Gtk::TreeModel::Row row = *i;
+      if (row[player_columns.player_id] == p->getId())
+	{
+          Glib::ustring s = GameParameters::player_param_to_string(type);
+          if (s == NETWORKED_PLAYER_TYPE)
+            row[player_columns.type] = "";
+          else
+            row[player_columns.type] = s;
+	  update_buttons();
+	  return;
+	}
+    }
+}
+
 void GameLobbyDialog::on_player_sits(Player *p, std::string nickname)
 {
   if (!p)
     return;
+  if (p->getId() == d_player_id_of_sit_or_stand_request)
+    {
+      sitting_renderer.set_sensitive(true);
+      d_player_id_of_sit_or_stand_request = MAX_PLAYERS + 1;
+    }
   Gtk::TreeModel::Children kids = player_list->children();
   //look for the row that has the right player id.
   for (Gtk::TreeModel::Children::iterator i = kids.begin(); 
@@ -482,22 +617,11 @@ void GameLobbyDialog::on_player_stands(Player *p, std::string nickname)
 
 void GameLobbyDialog::on_local_player_ends_turn(Player *p)
 {
-  Gtk::TreeModel::Children kids = player_list->children();
-  for (Gtk::TreeModel::Children::iterator i = kids.begin(); 
-       i != kids.end(); i++)
-    {
-      Gtk::TreeModel::Row row = *i;
-      if (row[player_columns.player_id] == p->getId())
-	{
-	  Glib::RefPtr<Gdk::Pixbuf> empty_pic
-	    = Gdk::Pixbuf::create(Gdk::COLORSPACE_RGB, true, 8, 1, 1);
-	  empty_pic->fill(0x00000000);
-	  row[player_columns.turn] = empty_pic;
-	}
-    }
+  update_turn_indicator();
   update_scenario_details();
 }
-void GameLobbyDialog::on_local_player_starts_turn(Player *p)
+
+void GameLobbyDialog::update_turn_indicator()
 {
   GraphicsCache *gc = GraphicsCache::getInstance();
   Gtk::TreeModel::Children kids = player_list->children();
@@ -506,9 +630,30 @@ void GameLobbyDialog::on_local_player_starts_turn(Player *p)
     {
       Gtk::TreeModel::Row row = *i;
       Player *active = Playerlist::getActiveplayer();
-      if (row[player_columns.player_id] == active->getId())
-	(*i)[player_columns.turn] = gc->getCursorPic(GraphicsCache::SWORD)->to_pixbuf();
+      if (active)
+        {
+          if (row[player_columns.player_id] == active->getId())
+            (*i)[player_columns.turn] = gc->getCursorPic(GraphicsCache::SWORD)->to_pixbuf();
+          else
+            {
+              Glib::RefPtr<Gdk::Pixbuf> empty_pic
+                = Gdk::Pixbuf::create(Gdk::COLORSPACE_RGB, true, 8, 4, 4);
+              empty_pic->fill(0x00000000);
+              (*i)[player_columns.turn] = empty_pic;
+            }
+        }
     }
+}
+
+void GameLobbyDialog::on_remote_player_starts_turn(Player *p)
+{
+  update_turn_indicator();
+  update_scenario_details();
+}
+
+void GameLobbyDialog::on_local_player_starts_turn(Player *p)
+{
+  update_turn_indicator();
   update_scenario_details();
 }
 
@@ -518,25 +663,9 @@ void GameLobbyDialog::on_remote_player_ends_turn(Player *p)
     {
       RecentlyPlayedGameList *rpgl = RecentlyPlayedGameList::getInstance();
       rpgl->updateEntry(d_game_scenario);
-      rpgl->saveToFile(File::getSavePath() + "/recently-played.xml");
-    }
-  GraphicsCache *gc = GraphicsCache::getInstance();
-  Gtk::TreeModel::Children kids = player_list->children();
-  for (Gtk::TreeModel::Children::iterator i = kids.begin(); 
-       i != kids.end(); i++)
-    {
-      Gtk::TreeModel::Row row = *i;
-      if (row[player_columns.player_id] == p->getId())
-	{
-	  Glib::RefPtr<Gdk::Pixbuf> empty_pic
-	    = Gdk::Pixbuf::create(Gdk::COLORSPACE_RGB, true, 8, 1, 1);
-	  empty_pic->fill(0x00000000);
-	  row[player_columns.turn] = empty_pic;
-	}
-      Player *active = Playerlist::getActiveplayer();
-      if (row[player_columns.player_id] == active->getId())
-	(*i)[player_columns.turn] = gc->getCursorPic(GraphicsCache::SWORD)->to_pixbuf();
+      rpgl->save();
     }
+  update_turn_indicator();
   update_scenario_details();
 }
 
@@ -555,12 +684,39 @@ void GameLobbyDialog::on_remote_player_changes_name(Player *p)
     }
 }
 
+Player* GameLobbyDialog::get_selected_player(Glib::ustring &nick, bool &sitting)
+{
+  Glib::RefPtr<Gtk::TreeSelection> selection = player_treeview->get_selection();
+  Gtk::TreeModel::iterator iterrow = selection->get_selected();
+  if (iterrow)
+    {
+      Gtk::TreeModel::Row row = *iterrow;
+      nick = row[player_columns.name];
+      sitting = row[player_columns.sitting];
+      return 
+        Playerlist::getInstance()->getPlayer(row[player_columns.player_id]);
+    }
+  else
+    return NULL;
+}
+
 void GameLobbyDialog::on_play_clicked()
 {
-  hide();
-  //we only get here on the first time play is clicked
-  //otherwise it just shows the form (Driver::start_network_game_requested)
-  start_network_game.emit(d_game_scenario, d_next_turn);
+  if (d_play_button_clicked == false)
+    {
+      //we only get here on the first time play is clicked
+      //otherwise it just shows the form (Driver::start_network_game_requested)
+      hide();
+      if (d_has_ops)
+        {
+          lock_down();
+          game_may_begin.emit();
+        }
+      play_button->set_sensitive(false);
+      play_button->property_visible() = false;
+      start_network_game.emit(d_game_scenario, d_next_turn);
+      d_play_button_clicked = true;
+    }
 }
 
 void GameLobbyDialog::on_cancel_clicked()
@@ -606,24 +762,7 @@ void GameLobbyDialog::on_player_died(Player *p)
 
 void GameLobbyDialog::on_reorder_playerlist()
 {
-  int count = 0;
-  std::list<int> new_order;
-  Playerlist *pl = Playerlist::getInstance();
-  for (Playerlist::iterator it = pl->begin(); it != pl->end(); it++)
-    {
-      Gtk::TreeNodeChildren rows = player_list->children();
-      for(Gtk::TreeIter row = rows.begin(); row != rows.end(); ++row)
-	{
-	  Gtk::TreeModel::Row my_row = *row;
-	  if (my_row[player_columns.player_id] == (*it)->getId())
-	    {
-	      new_order.push_back(count);
-	      count++;
-	      break;
-	    }
-	}
-    }
-  player_list->reorder(new_order);
+  sort_player_list_by_turn_order();
 }
 
 bool GameLobbyDialog::run()
@@ -671,7 +810,86 @@ bool GameLobbyDialog::run()
     return false;
 }
 
-void GameLobbyDialog::player_is_unavailable(Player *p)
+void GameLobbyDialog::on_nickname_changed(Glib::ustring old_name, Glib::ustring new_name)
 {
-  on_local_player_starts_turn(p);
+  d_game_station->setNickname(new_name);
+  //iterate through and find the nickname
+  Gtk::TreeNodeChildren rows = people_list->children();
+  for(Gtk::TreeIter row = rows.begin(); row != rows.end(); ++row)
+    {
+      Gtk::TreeModel::Row my_row = *row;
+      if (my_row[people_columns.nickname] == old_name)
+        {
+          my_row[people_columns.nickname] = new_name;
+          return;
+        }
+      Glib::ustring match = String::ucompose ("[%1]", old_name);
+      if (my_row[people_columns.nickname] == match)
+        {
+          my_row[people_columns.nickname] = String::ucompose("[%1]", new_name);
+          return;
+        }
+    }
+  
+}
+    
+void GameLobbyDialog::lock_down ()
+{
+  name_renderer.set_sensitive(false);
+  name_renderer.property_editable() = false;
+  type_renderer.set_sensitive(false);
+  type_renderer.property_editable() = false;
+}
+
+void GameLobbyDialog::on_play_message_received()
+{
+  d_play_message_received = true;
+  update_buttons();
+  lock_down();
+}
+    
+void GameLobbyDialog::on_player_turned_off(Player *player)
+{
+  Gtk::TreeNodeChildren rows = player_list->children();
+  for(Gtk::TreeIter row = rows.begin(); row != rows.end(); ++row)
+    {
+      Gtk::TreeModel::Row my_row = *row;
+      if (my_row[player_columns.player_id] == player->getId())
+        {
+          player_list->erase(row);
+          return;
+        }
+    }
+}
+
+void GameLobbyDialog::sort_player_list_by_turn_order()
+{
+  Playerlist *pl = Playerlist::getInstance();
+  std::map<guint32, guint32> id_order;
+
+  guint32 count = 0;
+  for (Playerlist::iterator i = pl->begin(), end = pl->end(); i != end; ++i)
+    {
+      Player *player = *i;
+      if (player == pl->getNeutral())
+	continue;
+      if (player->isDead())
+	continue;
+      id_order[player->getId()] = count;
+      count++;
+    }
+
+  Gtk::TreeNodeChildren rows = player_list->children();
+  for(Gtk::TreeIter row = rows.begin(); row != rows.end(); ++row)
+    {
+      Gtk::TreeModel::Row my_row = *row;
+      my_row[player_columns.order] = 
+        id_order[my_row[player_columns.player_id]];
+    }
+}
+
+void GameLobbyDialog::clean_up_players()
+{
+  player_list->clear();
+  //player_list.reset();
 }
