@@ -46,14 +46,14 @@ GameOptionsDialog::GameOptionsDialog(bool readonly)
     xml->get_widget("notdifficultoptionstable", notdifficultoptionstable);
     xml->get_widget("view_enemies_checkbutton", view_enemies_checkbutton);
     xml->get_widget("view_production_checkbutton", view_production_checkbutton);
-    xml->get_widget("quests_checkbutton", quests_checkbutton);
+    xml->get_widget("quests_combobox", quests_combobox);
     xml->get_widget("hidden_map_checkbutton", hidden_map_checkbutton);
     xml->get_widget("neutral_combobox", neutral_cities_combobox);
     xml->get_widget("razing_combobox", razing_cities_combobox);
     xml->get_widget("diplomacy_checkbutton", diplomacy_checkbutton);
     xml->get_widget("military_advisor_checkbutton", 
                     military_advisor_checkbutton);
-    xml->get_widget("quick_start_checkbutton", quick_start_checkbutton);
+    xml->get_widget("quick_start_combobox", quick_start_combobox);
     xml->get_widget("cusp_of_war_checkbutton", cusp_of_war_checkbutton);
     xml->get_widget("intense_combat_checkbutton", intense_combat_checkbutton);
     xml->get_widget("random_turns_checkbutton", random_turns_checkbutton);
@@ -72,13 +72,13 @@ void GameOptionsDialog::fill_in_options()
 
     view_enemies_checkbutton->set_active(GameScenarioOptions::s_see_opponents_stacks);
     view_production_checkbutton->set_active(GameScenarioOptions::s_see_opponents_production);
-    quests_checkbutton->set_active(GameScenarioOptions::s_play_with_quests);
+    quests_combobox->set_active(int(GameScenarioOptions::s_play_with_quests));
     hidden_map_checkbutton->set_active(GameScenarioOptions::s_hidden_map);
     neutral_cities_combobox->set_active(int(GameScenarioOptions::s_neutral_cities));
     razing_cities_combobox->set_active(int(GameScenarioOptions::s_razing_cities));
     diplomacy_checkbutton->set_active(GameScenarioOptions::s_diplomacy);
     military_advisor_checkbutton->set_active(GameScenarioOptions::s_military_advisor);
-    quick_start_checkbutton->set_active(Configuration::s_quick_start);
+    quick_start_combobox->set_active(Configuration::s_quick_start);
     cusp_of_war_checkbutton->set_active(GameScenarioOptions::s_cusp_of_war);
     cusp_of_war_checkbutton->set_sensitive(diplomacy_checkbutton->get_active());
     intense_combat_checkbutton->set_active(GameScenarioOptions::s_intense_combat);
@@ -114,9 +114,9 @@ bool GameOptionsDialog::run()
        (sigc::mem_fun
 	(this, &GameOptionsDialog::on_view_production_checkbutton_clicked)));
     connections.push_back
-      (quests_checkbutton->signal_clicked().connect
+      (quests_combobox->signal_changed().connect
        (sigc::mem_fun
-	(this, &GameOptionsDialog::on_quests_checkbutton_clicked)));
+	(this, &GameOptionsDialog::on_quests_combobox_changed)));
     connections.push_back
       (hidden_map_checkbutton->signal_clicked().connect
        (sigc::mem_fun
@@ -142,9 +142,9 @@ bool GameOptionsDialog::run()
        (sigc::mem_fun
 	(this, &GameOptionsDialog::on_random_turns_checkbutton_clicked)));
     connections.push_back
-      (quick_start_checkbutton->signal_clicked().connect
+      (quick_start_combobox->signal_changed().connect
        (sigc::mem_fun
-	(this, &GameOptionsDialog::on_quick_start_checkbutton_clicked)));
+	(this, &GameOptionsDialog::on_quick_start_combobox_changed)));
     connections.push_back
       (intense_combat_checkbutton->signal_clicked().connect
        (sigc::mem_fun
@@ -165,8 +165,10 @@ bool GameOptionsDialog::run()
     GameScenarioOptions::s_see_opponents_stacks = g.see_opponents_stacks;
     g.see_opponents_production = view_production_checkbutton->get_active();
     GameScenarioOptions::s_see_opponents_production = g.see_opponents_production;
-    g.play_with_quests = quests_checkbutton->get_active();
+    g.play_with_quests = GameParameters::QuestPolicy (
+	quests_combobox->get_active_row_number());
     GameScenarioOptions::s_play_with_quests = g.play_with_quests;
+
     g.hidden_map = hidden_map_checkbutton->get_active();
     GameScenarioOptions::s_hidden_map = g.hidden_map;
 
@@ -181,7 +183,8 @@ bool GameOptionsDialog::run()
     GameScenarioOptions::s_diplomacy = g.diplomacy;
     g.random_turns = random_turns_checkbutton->get_active();
     GameScenarioOptions::s_random_turns = g.random_turns;
-    g.quick_start = quick_start_checkbutton->get_active();
+    g.quick_start = GameParameters::QuickStartPolicy(
+	quick_start_combobox->get_active_row_number());
     Configuration::s_quick_start = g.quick_start;
     g.cusp_of_war = cusp_of_war_checkbutton->get_active();
     GameScenarioOptions::s_cusp_of_war = g.cusp_of_war;
@@ -220,9 +223,10 @@ void GameOptionsDialog::on_view_production_checkbutton_clicked()
     view_production_checkbutton->get_active();
   difficulty_option_changed.emit();
 }
-void GameOptionsDialog::on_quests_checkbutton_clicked()
+void GameOptionsDialog::on_quests_combobox_changed()
 {
-  GameScenarioOptions::s_play_with_quests = quests_checkbutton->get_active();
+  GameScenarioOptions::s_play_with_quests = GameParameters::QuestPolicy
+    (quests_combobox->get_active_row_number());
   difficulty_option_changed.emit();
 }
 void GameOptionsDialog::on_hidden_map_checkbutton_clicked()
@@ -260,9 +264,11 @@ void GameOptionsDialog::on_random_turns_checkbutton_clicked()
 {
   GameScenarioOptions::s_random_turns = random_turns_checkbutton->get_active();
 }
-void GameOptionsDialog::on_quick_start_checkbutton_clicked()
+void GameOptionsDialog::on_quick_start_combobox_changed()
 {
-  Configuration::s_quick_start = quick_start_checkbutton->get_active();
+  Configuration::s_quick_start = GameParameters::QuickStartPolicy
+    (quick_start_combobox->get_active_row_number());
+  difficulty_option_changed.emit();
 }
 void GameOptionsDialog::on_intense_combat_checkbutton_clicked()
 {
