@@ -46,7 +46,7 @@ class GameOptionsDialog: public Decorated
     Gtk::Dialog* dialog;
     Gtk::Table *difficultoptionstable;
     Gtk::Table *notdifficultoptionstable;
-    Gtk::CheckButton *quests_checkbutton;
+    Gtk::ComboBox *quests_combobox;
     Gtk::CheckButton *view_enemies_checkbutton;
     Gtk::CheckButton *view_production_checkbutton;
     Gtk::CheckButton *hidden_map_checkbutton;
@@ -56,19 +56,19 @@ class GameOptionsDialog: public Decorated
     Gtk::CheckButton *intense_combat_checkbutton;
     Gtk::CheckButton *military_advisor_checkbutton;
     Gtk::CheckButton *random_turns_checkbutton;
-    Gtk::CheckButton *quick_start_checkbutton;
+    Gtk::ComboBox *quick_start_combobox;
     Gtk::CheckButton *cusp_of_war_checkbutton;
     void fill_in_options();
     void on_view_enemies_checkbutton_clicked();
     void on_view_production_checkbutton_clicked();
-    void on_quests_checkbutton_clicked();
+    void on_quests_combobox_changed();
     void on_hidden_map_checkbutton_clicked();
     void on_neutral_cities_combobox_changed();
     void on_razing_cities_combobox_changed();
     void on_diplomacy_checkbutton_clicked();
     void on_cusp_of_war_checkbutton_clicked();
     void on_random_turns_checkbutton_clicked();
-    void on_quick_start_checkbutton_clicked();
+    void on_quick_start_combobox_changed();
     void on_intense_combat_checkbutton_clicked();
     void on_military_advisor_checkbutton_clicked();
     bool d_readonly;
