@@ -1,5 +1,5 @@
 //  Copyright (C) 2007 Ole Laursen
-//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009, 2011 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -37,23 +37,10 @@
 #include "tilesetlist.h"
 #include "citysetlist.h"
 #include "player.h"
+#include "game-parameters.h"
 
 static bool inhibit_difficulty_combobox = false;
 
-namespace 
-{
-  GameParameters::Player::Type player_type_to_enum(const Glib::ustring &s)
-    {
-      if (s == HUMAN_PLAYER_TYPE)
-	return GameParameters::Player::HUMAN;
-      else if (s == EASY_PLAYER_TYPE)
-	return GameParameters::Player::EASY;
-      else if (s == NO_PLAYER_TYPE)
-	return GameParameters::Player::OFF;
-      else
-	return GameParameters::Player::HARD;
-    }
-}
 void GamePreferencesDialog::init(std::string filename)
 {
   d_filename = filename;
@@ -113,11 +100,10 @@ void GamePreferencesDialog::init(std::string filename)
     }
   //parse load map parameters.
 
-  int f = 0;
-  int b;
+  guint32 b;
   for (std::vector<GameParameters::Player>::const_iterator
        i = load_map_parameters.players.begin(), 
-       end = load_map_parameters.players.end(); i != end; ++i, ++f) 
+       end = load_map_parameters.players.end(); i != end; ++i) 
     {
       c = player_types.begin();
       e = player_names.begin();
@@ -203,6 +189,8 @@ void GamePreferencesDialog::add_player(GameParameters::Player::Type type,
   player_type->signal_changed().connect
     (sigc::mem_fun(this, &GamePreferencesDialog::on_player_type_changed));
   Gtk::Entry *player_name = new Gtk::Entry();
+  player_name->signal_changed().connect
+    (sigc::mem_fun(this, &GamePreferencesDialog::on_player_name_changed));
   player_name->set_text(name);
 
   if (type == GameParameters::Player::HUMAN)
@@ -250,7 +238,8 @@ void GamePreferencesDialog::update_shields()
 {
   if (dialog->is_realized() == false)
     return;
-  Shieldsetlist::getInstance()->instantiateImages();
+  bool broken = false;
+  Shieldsetlist::getInstance()->instantiateImages(broken);
 
   std::vector<Gtk::Widget*> list;
   list = players_vbox->get_children();
@@ -270,19 +259,55 @@ void GamePreferencesDialog::update_shields()
 
 void GamePreferencesDialog::on_player_type_changed()
 {
+  update_buttons();
+  update_difficulty_rating();
+}
+
+void GamePreferencesDialog::on_player_name_changed()
+{
+  update_buttons();
+  update_difficulty_rating();
+}
+
+void GamePreferencesDialog::update_buttons()
+{
+  std::map<guint32, bool> offplayers;
   guint32 offcount = 0;
+  guint32 count = 0;
   std::list<Gtk::ComboBoxText *>::iterator c = player_types.begin();
   for (; c != player_types.end(); c++)
     {
-      if (player_type_to_enum((*c)->get_active_text()) ==
-	  GameParameters::Player::OFF)
-	offcount++;
+      if (GameParameters::player_param_string_to_player_param((*c)->get_active_text()) == GameParameters::Player::OFF)
+        {
+          offplayers[count] = true;
+          offcount++;
+        }
+      else
+        offplayers[count] = false;
+      count++;
     }
-  if (offcount > player_types.size() - 2)
+  bool found_empty_name = false;
+  std::list<Gtk::Entry *>::iterator e = player_names.begin();
+  count = 0;
+  for (; e != player_names.end(); e++)
+    {
+      if (offplayers[count] == true)
+        continue;
+      if (String::utrim((*e)->get_text())== "")
+        {
+          found_empty_name = true;
+          break;
+        }
+      count++;
+    }
+  if (offcount > player_types.size() - 2 || found_empty_name)
     start_game_button->set_sensitive(false);
   else
-    start_game_button->set_sensitive(true);
-  update_difficulty_rating();
+    {
+      start_game_button->set_sensitive(true);
+      start_game_button->property_can_focus() = true;
+      start_game_button->receives_default();
+    }
 }
 
 void GamePreferencesDialog::update_difficulty_rating()
@@ -292,7 +317,7 @@ void GamePreferencesDialog::update_difficulty_rating()
   for (; c != player_types.end(); c++)
     {
       GameParameters::Player p;
-      p.type = player_type_to_enum((*c)->get_active_text());
+      p.type = GameParameters::player_param_string_to_player_param((*c)->get_active_text());
       g.players.push_back(p);
     }
 
@@ -329,8 +354,8 @@ void GamePreferencesDialog::on_start_game_clicked()
   for (; c != player_types.end(); c++, e++, id++)
     {
       GameParameters::Player p;
-      p.type = player_type_to_enum((*c)->get_active_text());
-      Glib::ustring name = (*e)->get_text();
+      p.type = GameParameters::player_param_string_to_player_param((*c)->get_active_text());
+      Glib::ustring name = String::utrim((*e)->get_text());
       p.name = name;
       p.id = id;
       g.players.push_back(p);
@@ -353,7 +378,7 @@ void GamePreferencesDialog::on_start_game_clicked()
   g.difficulty = GameScenario::calculate_difficulty_rating(g);
 
   if (mode == GameScenario::NETWORKED)
-    g.name = game_name_entry->get_text();
+    g.name = String::utrim(game_name_entry->get_text());
 
   // and call callback
   dialog->hide();
