@@ -1,5 +1,5 @@
 //  Copyright (C) 2007, 2008 Ole Laursen
-//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009, 2011 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -330,6 +330,7 @@ class GameWindow: public Decorated
     void on_gold_stolen(Player *victim, guint32 gold_pieces);
     void on_ships_sunk(Player *victim, guint32 num_armies);
     void on_bags_picked_up(Hero *hero, guint32 num_bags);
+    void on_worms_killed(Hero *hero, guint32 num_worms_killed);
     void on_mp_added_to_hero_stack(Hero *hero, guint32 mp);
     void on_stack_moves(Stack *stack, Vector<int> pos);
     void end_turn_play_by_mail ();
@@ -364,8 +365,6 @@ class GameWindow: public Decorated
     void give_some_cheese(Player *game_winner);
 
 public:
-    std::vector<PixMask* > d_button_images;
-    std::vector<PixMask* > d_arrow_images;
     bool d_quick_fights; //do we speed up fights for this player's turn?
     std::string stop_action; //hackhackhack
     std::string d_scenario;
