@@ -1,5 +1,5 @@
 //  Copyright (C) 2007 Ole Laursen
-//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009, 2010 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -246,7 +246,7 @@ void HeroDialog::run()
   show_hero();
   dialog->run();
   if (gm->getTile(pos)->getBackpack()->size() > 0 && 
-      gm->getTile(pos)->getMaptileType() == Tile::WATER)
+      gm->getTile(pos)->getType() == Tile::WATER)
     {
       // splash, items lost forever
       while (gm->getTile(pos)->getBackpack()->size())
@@ -316,13 +316,18 @@ void HeroDialog::on_drop_clicked()
 {
     Gtk::TreeIter i = item_treeview->get_selection()->get_selected();
     if (i)
-    {
+      {
+        bool splash = false;
 	Item *item = (*i)[item_columns.item];
-	hero->getOwner()->heroDropItem (hero, item, pos);
-	(*i)[item_columns.status] = _("On the ground");
-	on_item_selection_changed();
+	hero->getOwner()->heroDropItem (hero, item, pos, splash);
+        if (splash == false)
+          (*i)[item_columns.status] = _("On the ground");
+        else
+          item_list->erase(i); //splash
+            
+        on_item_selection_changed();
 	fill_in_info_labels();
-    }
+      }
 }
 
 void HeroDialog::on_next_clicked()
