@@ -1,9 +1,9 @@
 //  Copyright (C) 2007 Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -21,14 +21,10 @@
 
 #include <memory>
 #include <sigc++/trackable.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/label.h>
-#include <gtkmm/liststore.h>
-#include <gtkmm/treemodelcolumn.h>
-#include <gtkmm/treeview.h>
-#include <gtkmm/button.h>
+#include <gtkmm.h>
 
 #include "vector.h"
+#include "heroesmap.h"
 
 class Hero;
 class Item;
@@ -41,6 +37,7 @@ class HeroDialog: public Decorated
 {
  public:
     HeroDialog(Hero *hero, Vector<int> pos);
+    ~HeroDialog();
 
     void set_parent_window(Gtk::Window &parent);
 
@@ -48,23 +45,39 @@ class HeroDialog: public Decorated
     void hide();
     
  private:
-    std::auto_ptr<Gtk::Dialog> dialog;
+    Gtk::Dialog* dialog;
+    HeroesMap* heroesmap;
 
     Hero *hero;
     Vector<int> pos;
+    Gtk::Image *map_image;
+    Gtk::TreeView *heroes_treeview;
     Gtk::TreeView *item_treeview;
     Gtk::TreeView *events_treeview;
     Gtk::Button *drop_button;
     Gtk::Button *pickup_button;
     Gtk::Label *info_label1;
     Gtk::Label *info_label2;
+    Gtk::Button *next_button;
+    Gtk::Button *prev_button;
+
+    class HeroesColumns: public Gtk::TreeModelColumnRecord {
+    public:
+	HeroesColumns() 
+        { add(hero); add(name); }
+	
+	Gtk::TreeModelColumn<Hero *> hero;
+	Gtk::TreeModelColumn<Glib::ustring> name;
+    };
+    const HeroesColumns heroes_columns;
+    Glib::RefPtr<Gtk::ListStore> heroes_list;
 
     class ItemColumns: public Gtk::TreeModelColumnRecord {
     public:
 	ItemColumns() 
         { add(image); add(name); add(attributes); add(status); add(item); }
 	
-	Gtk::TreeModelColumn<Glib::RefPtr<Gdk::Pixbuf> > image;
+	Gtk::TreeModelColumn<Glib::RefPtr<Gdk::Pixmap> > image;
 	Gtk::TreeModelColumn<Glib::ustring> name;
 	Gtk::TreeModelColumn<Glib::ustring> attributes;
 	Gtk::TreeModelColumn<Glib::ustring> status;
@@ -84,13 +97,24 @@ class HeroDialog: public Decorated
     const EventsColumns events_columns;
     Glib::RefPtr<Gtk::ListStore> events_list;
 
-    void on_selection_changed();
+    void on_hero_changed();
+    void on_item_selection_changed();
     void on_drop_clicked();
     void on_pickup_clicked();
+    void on_next_clicked();
+    void on_prev_clicked();
 
     void add_item(Item *item, bool in_backpack);
+    void add_hero(Hero *hero);
     void addHistoryEvent(History *event);
     void fill_in_info_labels();
+
+    void on_map_changed(Glib::RefPtr<Gdk::Pixmap> map);
+    bool on_map_mouse_button_event(GdkEventButton *e);
+    void show_hero();
+    void update_buttons();
+    bool inhibit_hero_changed;
+    void update_hero_list();
 };
 
 #endif
