@@ -209,6 +209,7 @@ void HistoryReportDialog::generatePastEventlists()
 		case History::DIPLOMATIC_WAR:
 		case History::DIPLOMATIC_PEACE:
 		case History::HERO_RUIN_EXPLORED:
+		case History::USE_ITEM:
 		  elist->push_back(new NetworkHistory(*hit[id], (*pit)->getId()));
 		  break;
 		case History::START_TURN:
@@ -271,8 +272,9 @@ void HistoryReportDialog::generatePastCitylists()
       //is the city burned to begin with?
       bool no_city_history = true;
       pit = Playerlist::getInstance()->begin();
+      guint32 age;
       for (; pit != Playerlist::getInstance()->end(); ++pit)
-	if ((*pit)->conqueredCity(*it) == true)
+	if ((*pit)->conqueredCity(*it, age) == true)
 	  no_city_history = false;
       if ((*it)->isBurnt() == true && no_city_history)
 	(*it)->setBurnt(true);
@@ -659,6 +661,21 @@ void HistoryReportDialog::addHistoryEvent(NetworkHistory *event)
                               rl->getById(ev->getRuinId())->getName());
 	  break;
 	}
+    case History::USE_ITEM:
+	{
+	  History_HeroUseItem *ev = 
+            static_cast<History_HeroUseItem*>(history);
+	  Player *opponent = pl->getPlayer(ev->getOpponentId());
+          if (ev->getItemBonus() & ItemProto::USABLE)
+            box = Box::ucompose(_("%1 %2 uses the %3 against %4 %5!"), shield, 
+                                ev->getHeroName(), ev->getItemName(),
+                                gc->getShieldPic(1, opponent)->to_pixbuf(), 
+                                opponent->getName());
+          else
+            box = Box::ucompose(_("%1 %2 uses the %3!"), shield, 
+                                ev->getHeroName(), ev->getItemName());
+	  break;
+	}
     default:
       box = NULL;
       break;
