@@ -43,6 +43,8 @@ class Main: public sigc::trackable, public boost::noncopyable
     std::string load_filename;
     std::string turn_filename;
     guint32 random_number_seed;
+    bool start_headless_server;
+    guint32 port;
     
  private:
     struct Impl;
