@@ -16,8 +16,10 @@
 //  02110-1301, USA.
 #include "new-network-game-download-window.h"
 #include "defs.h"
+#include "File.h"
+#include "decorated.h"
 
-NewNetworkGameDownloadWindow::NewNetworkGameDownloadWindow()
+NewNetworkGameDownloadWindow::NewNetworkGameDownloadWindow(Glib::ustring title)
 : m_vbox(false,10)
 {
   add(m_vbox);
@@ -25,7 +27,13 @@ NewNetworkGameDownloadWindow::NewNetworkGameDownloadWindow()
   m_vbox.pack_start(m_label);
   m_vbox.pack_start(m_pbar);
  
-  set_title(_("Downloading."));
+  Decorated decorator;
+  decorator.decorate(this);
+  decorator.window_closed.connect(sigc::mem_fun(this, &Gtk::Dialog::hide));
+  if (title == "")
+    title = _("Downloading.");
+  set_title(title);
+  set_icon_from_file(File::getMiscFile("various/castle_icon.png"));
   show_all();
 }
 
