@@ -140,7 +140,7 @@ NewRandomMapDialog::NewRandomMapDialog()
     default_id = 0;
     shield_theme_combobox = manage(new Gtk::ComboBoxText);
     Shieldsetlist *sl = Shieldsetlist::getInstance();
-    std::list<std::string> shield_themes = sl->getNames();
+    std::list<std::string> shield_themes = sl->getValidNames();
     for (std::list<std::string>::iterator i = shield_themes.begin(),
 	 end = shield_themes.end(); i != end; ++i)
       {
@@ -259,7 +259,7 @@ void NewRandomMapDialog::on_tile_size_changed()
   accept_button->set_sensitive(true);
   tile_theme_combobox->clear_items();
   Tilesetlist *tl = Tilesetlist::getInstance();
-  std::list<std::string> tile_themes = tl->getNames(get_active_tile_size());
+  std::list<std::string> tile_themes = tl->getValidNames(get_active_tile_size());
   for (std::list<std::string>::iterator i = tile_themes.begin(),
        end = tile_themes.end(); i != end; ++i)
     {
@@ -276,7 +276,7 @@ void NewRandomMapDialog::on_tile_size_changed()
 
   army_theme_combobox->clear_items();
   Armysetlist *al = Armysetlist::getInstance();
-  std::list<std::string> army_themes = al->getNames(get_active_tile_size());
+  std::list<std::string> army_themes = al->getValidNames(get_active_tile_size());
   counter = 0;
   default_id = 0;
   for (std::list<std::string>::iterator i = army_themes.begin(),
@@ -295,7 +295,7 @@ void NewRandomMapDialog::on_tile_size_changed()
 
   city_theme_combobox->clear_items();
   Citysetlist *cl = Citysetlist::getInstance();
-  std::list<std::string> city_themes = cl->getNames(get_active_tile_size());
+  std::list<std::string> city_themes = cl->getValidNames(get_active_tile_size());
   counter = 0;
   default_id = 0;
   for (std::list<std::string>::iterator i = city_themes.begin(),
@@ -329,13 +329,13 @@ GameParameters NewRandomMapDialog::getParams()
   p.id = int(Shield::YELLOW);
   p.name = random.getPlayerName(Shield::Colour(p.id));
   g.players.push_back(p);
-  p.id = int(Shield::LIGHT_BLUE);
+  p.id = int(Shield::DARK_BLUE);
   p.name = random.getPlayerName(Shield::Colour(p.id));
   g.players.push_back(p);
   p.id = int(Shield::ORANGE);
   p.name = random.getPlayerName(Shield::Colour(p.id));
   g.players.push_back(p);
-  p.id = int(Shield::DARK_BLUE);
+  p.id = int(Shield::LIGHT_BLUE);
   p.name = random.getPlayerName(Shield::Colour(p.id));
   g.players.push_back(p);
   p.id = int(Shield::RED);
@@ -510,13 +510,12 @@ std::string NewRandomMapDialog::create_and_dump_scenario(const std::string &file
   CreateScenario creator (g.map.width, g.map.height);
 
   // then fill the other players
-  int c = 0;
   int army_id = Armysetlist::getInstance()->getArmyset(g.army_theme)->getId();
   Shieldsetlist *ssl = Shieldsetlist::getInstance();
   guint32 id = ssl->getShieldset(g.shield_theme)->getId();
   for (std::vector<GameParameters::Player>::const_iterator
        i = g.players.begin(), end = g.players.end();
-       i != end; ++i, ++c) {
+       i != end; ++i) {
 
     if (i->type == GameParameters::Player::OFF)
       {
@@ -532,7 +531,7 @@ std::string NewRandomMapDialog::create_and_dump_scenario(const std::string &file
     else
       type = Player::HUMAN;
 
-    creator.addPlayer(i->name, army_id, ssl->getColor(id, c), type);
+    creator.addPlayer(i->name, army_id, ssl->getColor(id, i->id), type);
   }
 
 
