@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,10 +17,8 @@
 
 #include <config.h>
 
-#include <libglademm/xml.h>
-#include <gtkmm/eventbox.h>
+#include <gtkmm.h>
 #include <sigc++/functors/mem_fun.h>
-#include <gtkmm/label.h>
 
 #include "quest-assigned-dialog.h"
 
@@ -36,19 +34,17 @@ QuestAssignedDialog::QuestAssignedDialog(Hero *h, Quest *q)
   hero = h;
   quest = q;
     
-  Glib::RefPtr<Gnome::Glade::Xml> xml
-      = Gnome::Glade::Xml::create(get_glade_path()
-				  + "/quest-assigned-dialog.glade");
+  Glib::RefPtr<Gtk::Builder> xml
+      = Gtk::Builder::create_from_file(get_glade_path()
+				  + "/quest-assigned-dialog.ui");
 
-    Gtk::Dialog *d = 0;
-    xml->get_widget("dialog", d);
-    dialog.reset(d);
-    decorate(dialog.get());
-    window_closed.connect(sigc::mem_fun(dialog.get(), &Gtk::Dialog::hide));
+    xml->get_widget("dialog", dialog);
+    decorate(dialog);
+    window_closed.connect(sigc::mem_fun(dialog, &Gtk::Dialog::hide));
 
     xml->get_widget("map_image", map_image);
 
-    questmap.reset(new QuestMap(quest));
+    questmap = new QuestMap(quest);
     questmap->map_changed.connect(
 	sigc::mem_fun(this, &QuestAssignedDialog::on_map_changed));
 
@@ -67,6 +63,11 @@ QuestAssignedDialog::QuestAssignedDialog(Hero *h, Quest *q)
     
 }
 
+QuestAssignedDialog::~QuestAssignedDialog()
+{
+  delete dialog;
+  delete questmap;
+}
 void QuestAssignedDialog::set_parent_window(Gtk::Window &parent)
 {
     dialog->set_transient_for(parent);
@@ -87,8 +88,8 @@ void QuestAssignedDialog::run()
     dialog->run();
 }
 
-void QuestAssignedDialog::on_map_changed(SDL_Surface *map)
+void QuestAssignedDialog::on_map_changed(Glib::RefPtr<Gdk::Pixmap> map)
 {
-    map_image->property_pixbuf() = to_pixbuf(map);
+    map_image->property_pixmap() = map;
 }
 
