@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -21,16 +21,12 @@
 #include <memory>
 #include <vector>
 #include <sigc++/trackable.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/image.h>
-#include <gtkmm/radiobutton.h>
-#include <gtkmm/entry.h>
+#include <gtkmm.h>
 
 #include "questmap.h"
 #include "Quest.h"
 #include "hero.h"
 
-struct SDL_Surface;
 
 #include "decorated.h"
 // dialog for depicting a quest
@@ -38,6 +34,7 @@ class QuestAssignedDialog: public Decorated
 {
  public:
     QuestAssignedDialog(Hero *hero, Quest *quest);
+    ~QuestAssignedDialog();
 
     void set_parent_window(Gtk::Window &parent);
 
@@ -45,8 +42,8 @@ class QuestAssignedDialog: public Decorated
     void hide();
     
  private:
-    std::auto_ptr<Gtk::Dialog> dialog;
-    std::auto_ptr<QuestMap> questmap;
+    Gtk::Dialog* dialog;
+    QuestMap* questmap;
 
     Gtk::Image *map_image;
     Gtk::Label *label;
@@ -54,7 +51,7 @@ class QuestAssignedDialog: public Decorated
     Hero *hero;
     Quest *quest;
 
-    void on_map_changed(SDL_Surface *map);
+    void on_map_changed(Glib::RefPtr<Gdk::Pixmap> map);
 };
 
 #endif
