@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,10 +17,8 @@
 
 #include <config.h>
 
-#include <libglademm/xml.h>
-#include <gtkmm/eventbox.h>
+#include <gtkmm.h>
 #include <sigc++/functors/mem_fun.h>
-#include <gtkmm/label.h>
 
 #include "quest-completed-dialog.h"
 
@@ -38,19 +36,17 @@ QuestCompletedDialog::QuestCompletedDialog(Quest *q, Reward *r)
   reward = r;
   quest = q;
     
-  Glib::RefPtr<Gnome::Glade::Xml> xml
-      = Gnome::Glade::Xml::create(get_glade_path()
-				  + "/quest-assigned-dialog.glade");
+  Glib::RefPtr<Gtk::Builder> xml
+      = Gtk::Builder::create_from_file(get_glade_path()
+				  + "/quest-assigned-dialog.ui");
 
-    Gtk::Dialog *d = 0;
-    xml->get_widget("dialog", d);
-    dialog.reset(d);
-    decorate(dialog.get());
-    window_closed.connect(sigc::mem_fun(dialog.get(), &Gtk::Dialog::hide));
+    xml->get_widget("dialog", dialog);
+    decorate(dialog);
+    window_closed.connect(sigc::mem_fun(dialog, &Gtk::Dialog::hide));
 
     xml->get_widget("map_image", map_image);
 
-    questmap.reset(new QuestMap(quest));
+    questmap = new QuestMap(quest);
     questmap->map_changed.connect(
 	sigc::mem_fun(this, &QuestCompletedDialog::on_map_changed));
 
@@ -76,7 +72,7 @@ QuestCompletedDialog::QuestCompletedDialog(Quest *q, Reward *r)
     }
     if (reward->getType() == Reward::GOLD)
       {
-        Uint32 gold = dynamic_cast<Reward_Gold*>(reward)->getGold();
+        guint32 gold = dynamic_cast<Reward_Gold*>(reward)->getGold();
         s += String::ucompose(
 	    ngettext("You have been rewarded with %1 gold piece.",
 		     "You have been rewarded with %1 gold pieces.",
@@ -84,7 +80,7 @@ QuestCompletedDialog::QuestCompletedDialog(Quest *q, Reward *r)
       }
     else if (reward->getType() == Reward::ALLIES)
       {
-        Uint32 num = dynamic_cast<Reward_Allies*>(reward)->getNoOfAllies();
+        guint32 num = dynamic_cast<Reward_Allies*>(reward)->getNoOfAllies();
         s += String::ucompose(
 	    ngettext("You have been rewarded with %1 ally.",
 		     "You have been rewarded with %1 allies.",
@@ -127,6 +123,11 @@ QuestCompletedDialog::QuestCompletedDialog(Quest *q, Reward *r)
 
 }
 
+QuestCompletedDialog::~QuestCompletedDialog()
+{
+  delete dialog;
+  delete questmap;
+}
 void QuestCompletedDialog::set_parent_window(Gtk::Window &parent)
 {
   dialog->set_transient_for(parent);
@@ -147,8 +148,8 @@ void QuestCompletedDialog::run()
   dialog->run();
 }
 
-void QuestCompletedDialog::on_map_changed(SDL_Surface *map)
+void QuestCompletedDialog::on_map_changed(Glib::RefPtr<Gdk::Pixmap> map)
 {
-  map_image->property_pixbuf() = to_pixbuf(map);
+  map_image->property_pixmap() = map;
 }
 
