@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -21,14 +21,11 @@
 #include <memory>
 #include <vector>
 #include <sigc++/trackable.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/image.h>
-#include <gtkmm/label.h>
+#include <gtkmm.h>
 
 #include "ruinmap.h"
 #include "player.h"
 
-struct SDL_Surface;
 
 #include "decorated.h"
 // dialog for showing all ruins and temples
@@ -37,6 +34,7 @@ class RuinReportDialog: public Decorated
 {
  public:
     RuinReportDialog(Vector<int> pos);
+    ~RuinReportDialog();
 
     void set_parent_window(Gtk::Window &parent);
 
@@ -44,12 +42,12 @@ class RuinReportDialog: public Decorated
     void run();
     
  private:
-    std::auto_ptr<Gtk::Dialog> dialog;
-    std::auto_ptr<RuinMap> ruinmap;
+    Gtk::Dialog* dialog;
+    RuinMap* ruinmap;
 
     Gtk::Image *map_image;
     
-    void on_map_changed(SDL_Surface *map);
+    void on_map_changed(Glib::RefPtr<Gdk::Pixmap> map);
     bool on_map_mouse_button_event(GdkEventButton *e);
     void fill_in_ruin_info();
     Gtk::Label *name_label;
