@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -21,14 +21,11 @@
 #include <memory>
 #include <vector>
 #include <sigc++/trackable.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/image.h>
-#include <gtkmm/label.h>
+#include <gtkmm.h>
 
 #include "ruinmap.h"
 #include "player.h"
 
-struct SDL_Surface;
 
 #include "decorated.h"
 class Reward_Ruin;
@@ -38,6 +35,7 @@ class RuinRewardedDialog: public Decorated
 {
  public:
     RuinRewardedDialog(Reward_Ruin *reward);
+    ~RuinRewardedDialog();
 
     void set_parent_window(Gtk::Window &parent);
 
@@ -45,15 +43,15 @@ class RuinRewardedDialog: public Decorated
     void run();
     
  private:
-    std::auto_ptr<Gtk::Dialog> dialog;
-    std::auto_ptr<RuinMap> ruinmap;
+    Gtk::Dialog* dialog;
+    RuinMap* ruinmap;
 
     Gtk::Image *map_image;
     Gtk::Label *label;
     
     Reward_Ruin *d_reward;
 
-    void on_map_changed(SDL_Surface *map);
+    void on_map_changed(Glib::RefPtr<Gdk::Pixmap> map);
 };
 
 #endif
