@@ -1,5 +1,5 @@
 //  Copyright (C) 2007 Ole Laursen
-//  Copyright (C) 2007, 2008, 2009, 2010 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009, 2010, 2011 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -37,6 +37,9 @@
 #include "main-preferences-dialog.h"
 #include "timed-message-dialog.h"
 #include "new-random-map-dialog.h"
+#include "GraphicsCache.h"
+#include "new-network-game-dialog.h"
+#include "profile.h"
 
 //namespace
 //{
@@ -54,7 +57,7 @@ SplashWindow::SplashWindow()
 
     xml->get_widget("window", window);
     window->set_icon_from_file(File::getMiscFile("various/castle_icon.png"));
-    decorate(window, File::getMiscFile("various/back.bmp"));
+    decorate(window, GraphicsCache::SPLASH_BACKGROUND);
     window_closed.connect(sigc::mem_fun(this, &SplashWindow::on_window_closed));
 
     window->signal_delete_event().connect
@@ -113,6 +116,21 @@ SplashWindow::SplashWindow()
 	  }
       }
 
+    //set the window size.
+    bool broken = false;
+    PixMask *p = PixMask::create
+      (File::getMiscFile("/various/splash_screen.jpg"), broken);
+    if (broken == false)
+      {
+        guint32 decorations = 24 * 3;
+        if (Gdk::Screen::get_default()->get_height() - decorations < 
+            p->get_height())
+          window->set_default_size(Gdk::Screen::get_default()->get_width(),
+                         Gdk::Screen::get_default()->get_height());
+        else
+          window->set_default_size(p->get_width(), p->get_height() - 57);
+        delete p;
+      }
 }
 
 SplashWindow::~SplashWindow()
@@ -183,68 +201,52 @@ void SplashWindow::on_load_game_clicked()
 
 void SplashWindow::on_new_network_game_clicked()
 {
-  Glib::RefPtr<Gtk::Builder> xml
-    = Gtk::Builder::create_from_file(get_glade_path() + 
-				"/new-network-game-dialog.ui");
-  Gtk::Dialog* dialog;
-  Gtk::RadioButton *client_radiobutton;
-  xml->get_widget("dialog", dialog);
-  xml->get_widget("client_radiobutton", client_radiobutton);
-  dialog->set_transient_for(*window);
-  Gtk::Entry *nick_entry;
-  xml->get_widget("nick_entry", nick_entry);
-  std::string nick;
-  if (getenv("USER"))
-    nick = getenv("USER");
-  else if (network_game_nickname != "")
-    nick = network_game_nickname;
-  else
-    nick = "guest";
-  nick_entry->set_text(nick);
-  nick_entry->set_activates_default(true);
-  int response = dialog->run();
-  dialog->hide();
-  delete dialog;
-  if (response == Gtk::RESPONSE_ACCEPT) //we hit connect
+  NewNetworkGameDialog nngd;
+  nngd.set_parent_window (*window);
+  if (nngd.run())
     {
-      network_game_nickname = nick_entry->get_text();
-      if (client_radiobutton->get_active() == true)
-	{
-	  NetworkGameSelectorDialog ngsd;
-	  ngsd.game_selected.connect(sigc::mem_fun(*this, &SplashWindow::on_network_game_selected));
-	  ngsd.run();
-	}
+      nngd.hide();
+      network_game_nickname = nngd.getProfile()->getNickname();
+      if (nngd.isClient() == true)
+        {
+          NetworkGameSelectorDialog ngsd(nngd.getProfile());
+          ngsd.game_selected.connect(sigc::bind(sigc::mem_fun(*this, &SplashWindow::on_network_game_selected), nngd.getProfile()));
+          ngsd.run();
+        }
       else
-	{
-	  //okay, we're a server.
-	  LoadScenarioDialog d;
-	  d.set_parent_window(*window);
-	  d.run();
-	  std::string filename = d.get_scenario_filename();
-	  if (filename.empty())
-	    return;
-	  d.hide();
-	  if (filename == "random.map")
-	    {
-	      NewRandomMapDialog nrmd;
-	      nrmd.set_parent_window(*window);
-	      int res = nrmd.run();
-	      if (res == Gtk::RESPONSE_ACCEPT)
+        {
+          //okay, we're a server.
+          LoadScenarioDialog d;
+          d.set_parent_window(*window);
+          d.run();
+          std::string filename = d.get_scenario_filename();
+          if (filename.empty())
+            return;
+          d.hide();
+          if (filename == "random.map")
+            {
+              NewRandomMapDialog nrmd;
+              nrmd.set_parent_window(*window);
+              int res = nrmd.run();
+              if (res == Gtk::RESPONSE_ACCEPT)
                 filename = nrmd.getRandomMapFilename();
-	      else
-		return;
-	    }
+              else
+                return;
+            }
 
-	  GamePreferencesDialog gpd(filename, GameScenario::NETWORKED);
+          GamePreferencesDialog gpd(filename, GameScenario::NETWORKED);
 
-	  gpd.set_parent_window(*window);
-	  gpd.set_title(_("New Networked Game"));
-	  gpd.game_started.connect(sigc::mem_fun(*this, &SplashWindow::on_network_game_created));
-	  gpd.run(network_game_nickname);
-	  gpd.hide();
-	  return;
-	}
+          gpd.set_parent_window(*window);
+          gpd.set_title(_("New Networked Game"));
+          gpd.game_started.connect(sigc::bind(sigc::mem_fun(*this, &SplashWindow::on_network_game_created), nngd.getProfile(), nngd.isAdvertised(), nngd.isRemotelyHosted()));
+          gpd.run(network_game_nickname);
+          gpd.hide();
+          return;
+        }
     }
+  else
+    nngd.hide();
+
 
 }
 
@@ -308,9 +310,9 @@ void SplashWindow::on_load_scenario_clicked()
   //load_requested.emit(filename);
 }
 
-void SplashWindow::on_network_game_selected(std::string ip, unsigned short port)
+void SplashWindow::on_network_game_selected(std::string ip, unsigned short port, Profile *profile)
 {
-  new_remote_network_game_requested.emit(ip, port, network_game_nickname);
+  new_remote_network_game_requested.emit(ip, port, profile);
 }
 
 void SplashWindow::on_game_started(GameParameters g)
@@ -318,10 +320,12 @@ void SplashWindow::on_game_started(GameParameters g)
   new_game_requested.emit(g);
 }
 
-void SplashWindow::on_network_game_created(GameParameters g)
+void SplashWindow::on_network_game_created(GameParameters g, Profile *profile,
+                                           bool advertised, 
+                                           bool remotely_hosted)
 {
-  new_hosted_network_game_requested.emit(g, LORDSAWAR_PORT, 
-					 network_game_nickname);
+  new_hosted_network_game_requested.emit(g, LORDSAWAR_PORT, profile,
+                                         advertised, remotely_hosted);
 }
 
 void SplashWindow::on_pbm_game_created(GameParameters g)
