@@ -1,5 +1,5 @@
 //  Copyright (C) 2007 Ole Laursen
-//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009, 2011 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -34,6 +34,7 @@
 #include "decorated.h"
 #include "File.h"
 #include "stacktile.h"
+#include "GameScenarioOptions.h"
 
 StackInfoTip::StackInfoTip(Gtk::Widget *target, MapTipPosition mpos, StackTile *stile)
 {
@@ -44,14 +45,22 @@ StackInfoTip::StackInfoTip(Gtk::Widget *target, MapTipPosition mpos, StackTile *
 
     xml->get_widget("window", window);
     Decorated decorator;
-    decorator.decorate(window,File::getMiscFile("various/background.png"), 200);
+    decorator.decorate(window, GraphicsCache::GAME_BACKGROUND, 200);
 
     xml->get_widget("image_hbox", image_hbox);
 
     //fill up the hbox with images of the armies in the stack
 
     Player *active = Playerlist::getActiveplayer();
-    std::list<Stack *> stks = stile->getFriendlyStacks(active);
+    std::list<Stack *> stks;
+    stks = stile->getFriendlyStacks(active);
+    if (stks.empty() == true)
+      {
+        if (GameScenarioOptions::s_see_opponents_stacks)
+          stks = stile->getEnemyStacks(active);
+        else
+          return;
+      }
     for (std::list<Stack *>::iterator i = stks.begin(); i != stks.end(); i++)
       for (Stack::iterator it = (*i)->begin(); it != (*i)->end(); it++)
 	{
