@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -21,12 +21,8 @@
 #include <memory>
 #include <vector>
 #include <sigc++/trackable.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/image.h>
-#include <gtkmm/radiobutton.h>
-#include <gtkmm/entry.h>
+#include <gtkmm.h>
 
-struct SDL_Surface;
 
 #include "decorated.h"
 
@@ -35,6 +31,7 @@ class SurrenderDialog: public Decorated
 {
  public:
     SurrenderDialog(int numPlayers);
+    ~SurrenderDialog();
 
     void set_parent_window(Gtk::Window &parent);
 
@@ -42,7 +39,7 @@ class SurrenderDialog: public Decorated
     bool run();
     
  private:
-    std::auto_ptr<Gtk::Dialog> dialog;
+    Gtk::Dialog* dialog;
     Gtk::Image *image;
 
 };
