@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -21,8 +21,7 @@
 #include <memory>
 #include <vector>
 #include <sigc++/trackable.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/notebook.h>
+#include <gtkmm.h>
 
 class Player;
 
@@ -35,6 +34,7 @@ class TriumphsDialog: public Decorated
 {
  public:
     TriumphsDialog(Player *player);
+    ~TriumphsDialog();
 
     void set_parent_window(Gtk::Window &parent);
 
@@ -42,7 +42,7 @@ class TriumphsDialog: public Decorated
     void hide();
     
  private:
-    std::auto_ptr<Gtk::Dialog> dialog;
+    Gtk::Dialog* dialog;
 
     Player *d_player;
 
@@ -50,7 +50,7 @@ class TriumphsDialog: public Decorated
 
     void fill_in_info();
     void fill_in_page(Player *p);
-    Uint32 tally(Player *p, Triumphs::TriumphType type);
+    guint32 tally(Player *p, Triumphs::TriumphType type);
 };
 
 #endif
