@@ -1,5 +1,5 @@
 // Copyright (C) 2008 Ole Laursen
-// Copyright (C) 2008 Ben Asselstine 
+// Copyright (C) 2008, 2011 Ben Asselstine 
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -22,13 +22,14 @@
 #include "config.h"
 
 #include <map>
+#include <giomm.h>
+#include <giomm/socketservice.h>
+#include <glibmm.h>
 #include <sigc++/signal.h>
 #include <string>
 
 #include "network-common.h"
 
-class _GServer;
-class _GConn;
 class NetworkConnection;
 
 class NetworkServer
@@ -39,19 +40,24 @@ public:
 
   bool isListening();
   void startListening(int port);
-  void send(void *conn, MessageType type, const std::string &payload);
+  void send(void *conn, int type, const std::string &payload);
+  void sendFile(void *c, int type, const std::string &payload);
+  std::string get_hostname(void *conn);
+  bool is_local_connection(void *conn);
 
-  sigc::signal<void, void *, MessageType, std::string> got_message;
+  void stop();
+  sigc::signal<bool, void *, int, std::string> got_message;
   sigc::signal<void, void *> connection_made;
   sigc::signal<void, void *> connection_lost;
+  sigc::signal<void, int> port_in_use;
   
   // private callback
-  void gotClientConnection(_GConn* conn);
+  bool gotClientConnection(const Glib::RefPtr<Gio::SocketConnection>& c, const Glib::RefPtr<Glib::Object>& source_object);
 
 private:
   void onConnectionLost(NetworkConnection *conn);
   
-  _GServer *server;
+  Glib::RefPtr<Gio::SocketService> server;
   std::list<NetworkConnection *> connections;
 };
 
