@@ -1,4 +1,4 @@
-// Copyright (C) 2008, 2009, 2010 Ben Asselstine
+// Copyright (C) 2008, 2009, 2010, 2011 Ben Asselstine
 // Copyright (C) 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
@@ -52,11 +52,12 @@
 #include "vectoredunit.h"
 #include "Backpack.h"
 #include "MapBackpack.h"
+#include "stackreflist.h"
 
 using namespace std;
 
-//#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl<<flush;}
-#define debug(x)
+#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl<<flush;}
+//#define debug(x)
 
 NetworkPlayer::NetworkPlayer(string name, guint32 armyset, Gdk::Color color, int width,
 		       int height, Player::Type type, int player_no)
@@ -97,6 +98,7 @@ bool NetworkPlayer::save(XML_Helper* helper) const
 void NetworkPlayer::abortTurn()
 {
   d_abort_requested = true;
+    aborted_turn.emit();
 }
 
 bool NetworkPlayer::startTurn()
@@ -287,6 +289,28 @@ void NetworkPlayer::decodeAction(const Action *a)
     case Action::USE_ITEM:
       return decodeActionUseItem
 	(dynamic_cast<const Action_UseItem*>(a));
+    case Action::STACK_ORDER:
+      return decodeActionStackOrder(dynamic_cast<const Action_ReorderArmies*>(a));
+    case Action::STACKS_RESET:
+      return decodeActionStacksReset(dynamic_cast<const Action_ResetStacks*>(a));
+    case Action::RUINS_RESET:
+      return decodeActionRuinsReset(dynamic_cast<const Action_ResetRuins*>(a));
+    case Action::COLLECT_TAXES_AND_PAY_UPKEEP:
+      return decodeActionCollectTaxesAndPayUpkeep(dynamic_cast<const Action_CollectTaxesAndPayUpkeep*>(a));
+    case Action::KILL_PLAYER:
+      return decodeActionKillPlayer(dynamic_cast<const Action_Kill*>(a));
+    case Action::STACK_DEFEND:
+      return decodeActionDefendStack(dynamic_cast<const Action_DefendStack*>(a));
+    case Action::STACK_UNDEFEND:
+      return decodeActionUndefendStack(dynamic_cast<const Action_UndefendStack*>(a));
+    case Action::STACK_PARK:
+      return decodeActionParkStack(dynamic_cast<const Action_ParkStack*>(a));
+    case Action::STACK_UNPARK:
+      return decodeActionUnparkStack(dynamic_cast<const Action_UnparkStack*>(a));
+    case Action::STACK_SELECT:
+      return decodeActionSelectStack(dynamic_cast<const Action_SelectStack*>(a));
+    case Action::STACK_DESELECT:
+      return decodeActionDeselectStack(dynamic_cast<const Action_DeselectStack*>(a));
     }
 
   return;
@@ -313,21 +337,38 @@ void NetworkPlayer::decodeActionMove(const Action_Move *action)
   Stack *stack = d_stacklist->getStackById(action->getStackId());
   if (stack == NULL)
     {
-      printf ("couldn't find stack with id %d\n", action->getStackId());
-      printf ("is there a stack near the ending position?\n");
+      debug ("couldn't find stack with id " <<  action->getStackId());
+      debug ("is there a stack near the ending position?");
       for (int x = -1; x <= 1; x++)
 	for (int y = -1; y <= 1; y++)
 	  {
 	    Vector<int> dest = action->getEndingPosition() + Vector<int>(x,y);
 	    Stack *s = GameMap::getFriendlyStack(dest);
-	    printf ("stack at position %d,%d is %p\n", dest.x, dest.y, s);
+	    debug ("stack at position " << dest.x << "," << dest.y << " is " << s);
 	    if (s)
-	      printf ("stack id is %d\n", s->getId());
+              {
+                debug ("stack id is " << s->getId());
+              }
 	  }
     }
   assert (stack != NULL);
-  stack->moveToDest(action->getEndingPosition());
-  stack->sortForViewing(true);
+
+  assert (stack->getPos() == (action->getEndingPosition() - action->getPositionDelta()));
+
+  bool skipping = false;
+  if (!stack->isFlying())
+    {
+      bool on_ship = stack->hasShip();
+      if (stack->isMovingToOrFromAShip(action->getEndingPosition(), on_ship) == true)
+        {
+          //are we skipping?
+          if (GameMap::countArmyUnits(action->getEndingPosition()) + stack->size() > MAX_STACK_SIZE && GameMap::getFriendlyStack(action->getEndingPosition()) != NULL)
+            skipping = true;
+          else
+            stack->updateShipStatus(action->getEndingPosition());
+        }
+    }
+  stack->moveToDest(action->getEndingPosition(), skipping);
   supdatingStack.emit(stack);
 }
 
@@ -339,44 +380,45 @@ void NetworkPlayer::decodeActionSplit(const Action_Split *action)
   
   std::list<guint32> armies;
   for (unsigned int i = 0; i < MAX_STACK_SIZE; ++i) 
-    armies.push_back(action->getGroupedArmyId(i));
+    if (action->getGroupedArmyId(i) != 0)
+      armies.push_back(action->getGroupedArmyId(i));
 
   Stack *new_stack = NULL;
   doStackSplitArmies(stack, armies, new_stack);
   assert (new_stack != NULL);
   if (new_stack->getId() != action->getNewStackId())
     {
-      printf ("created stack with id %d, but expected %d\n", new_stack->getId(),
-	      action->getNewStackId());
+      debug ("created stack with id " << new_stack->getId() << ", but expected " << action->getNewStackId());
     }
   assert (new_stack->getId() == action->getNewStackId());
-  new_stack->sortForViewing(true);
-  stack->sortForViewing(true);
-
 }
 
 void NetworkPlayer::decodeActionFight(const Action_Fight *action)
 {
+  debug ("performing action: " <<  action->dump());
   std::list<Stack *> attackers, defenders;
-  std::list<guint32> attacker_army_ids = action->getAttackerArmyIds();
-  for (std::list<guint32>::const_iterator i = attacker_army_ids.begin(),
-         end = attacker_army_ids.end(); i != end; ++i)
+  std::list<guint32> attacker_stack_ids = action->getAttackerStackIds();
+  for (std::list<guint32>::const_iterator i = attacker_stack_ids.begin(),
+         end = attacker_stack_ids.end(); i != end; ++i)
     attackers.push_back(d_stacklist->getStackById(*i));
 
-  std::list<guint32> defender_army_ids = action->getDefenderArmyIds();
-  for (std::list<guint32>::const_iterator i = defender_army_ids.begin(),
-         end = defender_army_ids.end(); i != end; ++i)
+  std::list<guint32> defender_stack_ids = action->getDefenderStackIds();
+  for (std::list<guint32>::const_iterator i = defender_stack_ids.begin(),
+         end = defender_stack_ids.end(); i != end; ++i)
     defenders.push_back(findStackById(*i));
 
-  Stack *attack = &*attackers.front();
   Fight fight(attackers, defenders, action->getBattleHistory());
   Fight::Result result = fight.battleFromHistory();
   fight_started.emit(fight);
 
-  cleanupAfterFight(attackers, defenders);
+  std::list<History*> attacker_history;
+  std::list<History*> defender_history;
+  cleanupAfterFight(attackers, defenders, attacker_history, defender_history);
+  clearHistorylist(attacker_history);
+  clearHistorylist(defender_history);
   if (result == Fight::ATTACKER_WON)
     {
-      printf ("there are %d attackers left in %d at %d,%d\n", attack->size(),attack->getId(), attack->getPos().x, attack->getPos().y);
+      debug ("there are " << (&*attackers.front())->size() << " attackers left in " << (&*attackers.front())->getId() << " at " << (&*attackers.front())->getPos().x << "," << (&*attackers.front())->getPos().y);
     }
 }
 
@@ -388,7 +430,6 @@ void NetworkPlayer::decodeActionJoin(const Action_Join *action)
   assert (receiver != NULL);
   assert (joining != NULL);
   doStackJoin(receiver, joining);
-  receiver->sortForViewing(true);
   supdatingStack.emit(0);
 }
 
@@ -397,34 +438,44 @@ void NetworkPlayer::decodeActionRuin(const Action_Ruin *action)
   Stack *explorer = d_stacklist->getStackById(action->getStackId());
   Ruin *r = Ruinlist::getInstance()->getById(action->getRuinId());
   bool searched = action->getSearchSuccessful();
-
   Stack* keeper = r->getOccupant();
 
+  Fight::Result result = Fight::ATTACKER_WON;
+  if (searched == false)
+    result = Fight::DEFENDER_WON;
+
+  if (searched == false && keeper == NULL)
+    {
+      std::cerr << "whoops, we have an impossible situation here." << std::endl;
+      exit(0);
+    }
   // now simulate the fight that might have happened on the other side
-  if (keeper) {
-    if (searched) {
-      // whack the keeper
-      for (Stack::iterator i = keeper->begin(); i != keeper->end(); ++i)
-        (*i)->setHP(0);
-    }
-    else {
-      // whack the hero
-      explorer->getFirstHero()->setHP(0);
+  if (keeper) 
+    {
+      if (result == Fight::ATTACKER_WON) 
+        {
+          // whack the keeper
+          for (Stack::iterator i = keeper->begin(); i != keeper->end(); ++i)
+            (*i)->setHP(0);
+        }
+      else if (result == Fight::DEFENDER_WON)
+        {
+          // whack the hero
+          explorer->getFirstHero()->setHP(0);
+        }
+
+      std::list<Stack *> attackers, defenders;
+      attackers.push_back(explorer);
+      defenders.push_back(keeper);
+
+      std::list<History*> attacker_history;
+      std::list<History*> defender_history;
+      cleanupAfterFight(attackers, defenders, attacker_history, defender_history);
+      clearHistorylist(attacker_history);
+      clearHistorylist(defender_history);
     }
 
-    std::list<Stack *> attackers, defenders;
-    attackers.push_back(explorer);
-    defenders.push_back(keeper);
-    
-    cleanupAfterFight(attackers, defenders);
-
-    if (searched) {
-        r->setOccupant(0);
-        delete keeper;
-    }
-  }
-
-  r->setSearched(searched);
+  doStackSearchRuin(explorer, r, result);
 
   //the reward is given to the player via the decodeActionReward method.
   supdatingStack.emit(0);
@@ -488,7 +539,9 @@ void NetworkPlayer::decodeActionProduction(const Action_Production *action)
 void NetworkPlayer::decodeActionReward(const Action_Reward *action)
 {
   Stack *stack = d_stacklist->getStackById(action->getStackId());
-  doGiveReward(stack, action->getReward());
+  StackReflist *stacks = new StackReflist();
+  doGiveReward(stack, action->getReward(), stacks);
+  delete stacks;
   supdatingStack.emit(stack); // make sure we get a redraw
 }
 
@@ -527,7 +580,7 @@ void NetworkPlayer::decodeActionEquip(const Action_Equip *action)
   Stack *stack = d_stacklist->getArmyStackById(action->getHeroId());
   if (stack == NULL)
     {
-      printf ("couldn't find hero with id %d\n", action->getHeroId());
+      debug ("couldn't find hero with id " <<  action->getHeroId());
     }
   assert (stack != NULL);
   Hero *hero = dynamic_cast<Hero *>(stack->getArmyById(action->getHeroId()));
@@ -554,8 +607,8 @@ void NetworkPlayer::decodeActionLevel(const Action_Level *action)
   Hero*hero= dynamic_cast<Hero*>(stack->getArmyById(action->getArmyId()));
 
   doHeroGainsLevel(hero, Army::Stat(action->getStatToIncrease()));
-  printf ("army is hero? %d\n", hero->isHero());
-  printf ("new level is %d\n", hero->getLevel());
+  debug ("army is hero? " << hero->isHero());
+  debug ("new level is " << hero->getLevel());
 }
 
 void NetworkPlayer::decodeActionDisband(const Action_Disband *action)
@@ -563,7 +616,7 @@ void NetworkPlayer::decodeActionDisband(const Action_Disband *action)
   Stack *stack = d_stacklist->getStackById(action->getStackId());
   if (stack == NULL)
     {
-      printf ("couldn't find stack with id %d\n", action->getStackId());
+      debug ("couldn't find stack with id " << action->getStackId());
     }
   assert (stack != NULL);
   bool found = doStackDisband(stack);
@@ -595,7 +648,9 @@ void NetworkPlayer::decodeActionFightOrder(const Action_FightOrder *action)
 
 void NetworkPlayer::decodeActionResign(const Action_Resign *action)
 {
-  doResign();
+  std::list<History*> history;
+  doResign(history);
+  clearHistorylist(history);
 }
 
 void NetworkPlayer::decodeActionPlant(const Action_Plant *action)
@@ -612,17 +667,48 @@ void NetworkPlayer::decodeActionProduce(const Action_Produce *action)
   //if it was vectored, we just wait for the Action_ProduceVectored later on.
   if (action->getVectored() == true)
     {
-      printf ("produced unit but it's vectored.\n");
+      debug ("produced unit but it's vectored.");
+      debug ("we could put it in the vectored unit list, but why bother eh.");
+      debug ("We can just make one on demand when it \"shows up\".");
     return;
     }
-  ArmyProdBase *a = action->getArmy();
+  //ArmyProdBase *a = action->getArmy();
   City *c = Citylist::getInstance()->getById(action->getCityId());
-  Army *army = new Army (*a, this);
-  Stack *s = c->addArmy(army);
-  printf ("created army id %d, in stack %d of size %d\n", army->getId(), s->getId(), s->size());
+  //Army *army = new Army (*a, this);
+  //Stack *s = c->addArmy(army);
+  Stack *s = NULL;
+  bool vectored = false;
+  const Army *army = doCityProducesArmy(c, s, vectored);
+  if (army)
+    {
+      debug ("created army id " << army->getId() << " in stack " << s->getId() << " of size " << s->size());
+    }
+  else
+    {
+      debug ("we got a null army! how?");
+        int cost = c->getActiveProductionBase()->getProductionCost();
+          if (cost > d_gold)
+            {
+              debug ("we can't afford it.");
+            }
+          else
+            {
+              debug ("we can afford it");
+            }
+
+    exit(0);
+    }
+  debug ("expecting it to be in stack id " << action->getStackId());
+  Stack *expected = getStacklist()->getStackById(action->getStackId());
+  debug ("expected stack is " << expected);
+  if (expected)
+    {
+    debug ("expected stack has position " << expected->getPos().x << "," << expected->getPos().y);
+    }
+  assert (s != NULL);
+  assert (s->getId() == action->getStackId());
   assert (s->getPos() == action->getDestination());
   assert (army->getId() == action->getArmyId());
-  s->sortForViewing(true);
 }
 
 void NetworkPlayer::decodeActionProduceVectored(const Action_ProduceVectored *action)
@@ -630,11 +716,12 @@ void NetworkPlayer::decodeActionProduceVectored(const Action_ProduceVectored *ac
   //create a vectored unit.
   VectoredUnit v(action->getOrigination(), action->getDestination(),
 		 action->getArmy(), 0, this);
-  Army *army = doVectoredUnitArrives(&v);
-  printf ("army is %p\n", army);
-  Stack *s = d_stacklist->getArmyStackById(army->getId());
-  s->sortForViewing(true);
-  printf ("created vectored army id %d, in stack %d of size %d\n", army->getId(), s->getId(), s->size());
+  Stack *s = NULL;
+  Army *army = doVectoredUnitArrives(&v, s);
+  debug ("army is " << army);
+  debug ("stack is " << s);
+  assert (army != NULL);
+  assert (s != NULL);
 }
 
 void NetworkPlayer::decodeActionDiplomacyState(const Action_DiplomacyState *action)
@@ -657,31 +744,34 @@ void NetworkPlayer::decodeActionDiplomacyScore(const Action_DiplomacyScore *acti
 
 void NetworkPlayer::decodeActionEndTurn(const Action_EndTurn *action)
 {
-  printf ("ending turn!!\n");
+  debug ("ending turn!!");
   ending_turn.emit();
 }
 
 void NetworkPlayer::decodeActionConquerCity(const Action_ConquerCity *action)
 {
   City *city = Citylist::getInstance()->getById(action->getCityId());
-  Stack *stack = d_stacklist->getStackById(action->getStackId());
-  doConquerCity(city, stack);
+  doConquerCity(city);
 }
 
 void NetworkPlayer::decodeActionRecruitHero(const Action_RecruitHero *action)
 {
-
   City *city = Citylist::getInstance()->getById(action->getCityId());
   ArmyProto *ally = 0;
   if (action->getNumAllies())
     ally = Armysetlist::getInstance()->getArmy(getArmyset(),
                                                action->getAllyArmyType());
+  StackReflist *stacks = new StackReflist();
   Hero *hero = doRecruitHero(action->getHero(), city, action->getCost(), 
-			     action->getNumAllies(), ally);
-  printf ("created hero with id %d, in stack %d\n", hero->getId(),
-	 d_stacklist->getArmyStackById(hero->getId())->getId());
-  //hero->syncNewId();
-  d_stacklist->getArmyStackById(hero->getId())->sortForViewing(true);
+			     action->getNumAllies(), ally, stacks);
+  if (hero)
+    {
+      debug ("created hero with id " << hero->getId() << ", in stack " << d_stacklist->getArmyStackById(hero->getId())->getId());
+    }
+
+  if (stacks->size())
+    supdatingStack.emit(stacks->front()); // make sure we get a redraw
+  delete stacks;
 }
 
 void NetworkPlayer::decodeActionRenamePlayer(const Action_RenamePlayer *action)
@@ -696,6 +786,12 @@ void NetworkPlayer::decodeActionCityTooPoorToProduce(const Action_CityTooPoorToP
 
 void NetworkPlayer::decodeActionInitTurn(const Action_InitTurn*action)
 {
+  debug ("remote: dumping " << d_actions.size() << " actions");
+  for (std::list<Action*>::iterator i = d_actions.begin(); i != d_actions.end(); i++)
+    {
+      debug ("\t" << Action::actionTypeToString((*i)->getType()) << " " << (*i)->dump().c_str());
+    }
+  clearActionlist();
 }
 
 void NetworkPlayer::decodeActionLoot (const Action_Loot *action)
@@ -710,7 +806,7 @@ void NetworkPlayer::decodeActionUseItem(const Action_UseItem *action)
   Stack *stack = d_stacklist->getArmyStackById(action->getHeroId());
   if (stack == NULL)
     {
-      printf ("couldn't find hero with id %d\n", action->getHeroId());
+      debug ("couldn't find hero with id " << action->getHeroId());
     }
   assert (stack != NULL);
   Hero *hero = dynamic_cast<Hero *>(stack->getArmyById(action->getHeroId()));
@@ -720,5 +816,147 @@ void NetworkPlayer::decodeActionUseItem(const Action_UseItem *action)
   Player *victim = Playerlist::getInstance()->getPlayer(action->getVictimPlayerId());
   doHeroUseItem(hero, item, victim);
 }
+      
+void NetworkPlayer::decodeActionStackOrder(const Action_ReorderArmies* action)
+{
+  //sort the buggers.
+  Player *p = Playerlist::getInstance()->getPlayer(action->getPlayerId());
+  if (!p)
+    {
+      debug ("we don't have player id " << action->getPlayerId());
+      exit(0);
+    }
+  Stack *s = p->getStacklist()->getStackById(action->getStackId());
+  if (!s)
+    {
+      debug ("we don't have stack id %d" <<  action->getStackId());
+      exit(0);
+    }
+  assert (action->getArmyIds().size() == s->size());
+  std::list<guint32> ids = action->getArmyIds();
+  bool success = true;
+  for (std::list<guint32>::iterator i = ids.begin(); i != ids.end(); i++)
+    {
+      if (s->getArmyById(*i) == NULL)
+        {
+          debug ("stack " << s->getId() << " does not have army id " << *i);
+          success = false;
+        }
+    }
+  if (!success)
+    {
+      exit(0);
+    }
+  printf("started out with this ordering: ");
+  for (Stack::iterator i = s->begin(); i != s->end(); i++)
+    printf ("%d ", (*i)->getId());
+  printf("\n");
+  printf("we say order like: ");
+  for (std::list<guint32>::iterator i = ids.begin(); i != ids.end(); i++)
+    printf ("%d ", *i);
+  printf("\n");
+  doStackSort(s, ids);
+  printf("changed it to: ");
+  for (Stack::iterator i = s->begin(); i != s->end(); i++)
+    printf ("%d ", (*i)->getId());
+  printf("\n");
+}
 
+void NetworkPlayer::decodeActionStacksReset(const Action_ResetStacks *action)
+{
+  Player *p = Playerlist::getInstance()->getPlayer(action->getPlayerId());
+  if (!p)
+    {
+      debug ("couldn't find player " << action->getPlayerId());
+      exit(0);
+    }
+  if (p->getId() != getId())
+    {
+      debug ("can't heal another player's stacks?");
+      exit(0);
+    }
+  doStacksReset();
+}
+
+void NetworkPlayer::decodeActionRuinsReset(const Action_ResetRuins *action)
+{
+  doRuinsReset();
+}
+
+void NetworkPlayer::decodeActionCollectTaxesAndPayUpkeep(const Action_CollectTaxesAndPayUpkeep *action)
+{
+  doCollectTaxesAndPayUpkeep();
+}
+
+void NetworkPlayer::decodeActionKillPlayer(const Action_Kill *action)
+{
+  if (isDead() == false)
+    {
+      doKill();
+      Playerlist::getInstance()->splayerDead.emit(this);
+    }
+}
+
+void NetworkPlayer::decodeActionDefendStack(const Action_DefendStack *action)
+{
+  Stack *stack = d_stacklist->getStackById(action->getStackId());
+  if (!stack)
+    {
+      debug ("couldn't find stack id " << action->getStackId());
+      exit(0);
+    }
+  doStackDefend(stack);
+}
+
+void NetworkPlayer::decodeActionUndefendStack(const Action_UndefendStack *action)
+{
+  Stack *stack = d_stacklist->getStackById(action->getStackId());
+  if (!stack)
+    {
+      debug ("couldn't find stack id " << action->getStackId());
+      exit(0);
+    }
+  doStackUndefend(stack);
+}
+
+void NetworkPlayer::decodeActionParkStack(const Action_ParkStack *action)
+{
+  Stack *stack = d_stacklist->getStackById(action->getStackId());
+  if (!stack)
+    {
+      debug ("couldn't find stack id " << action->getStackId());
+      exit(0);
+    }
+  doStackPark(stack);
+}
+
+void NetworkPlayer::decodeActionUnparkStack(const Action_UnparkStack *action)
+{
+  debug ("here i am, decoding unpark stack.\n");
+  Stack *stack = d_stacklist->getStackById(action->getStackId());
+  if (!stack)
+    {
+      debug ("couldn't find stack id " << action->getStackId());
+      exit(0);
+    }
+  doStackUnpark(stack);
+}
+
+void NetworkPlayer::decodeActionSelectStack(const Action_SelectStack *action)
+{
+  Stack *stack = d_stacklist->getStackById(action->getStackId());
+  if (!stack)
+    {
+      debug ("couldn't find stack id " << action->getStackId());
+      exit(0);
+    }
+  doStackSelect(stack);
+  supdatingStack.emit(stack);
+}
+
+void NetworkPlayer::decodeActionDeselectStack(const Action_DeselectStack *action)
+{
+  doStackDeselect();
+  supdatingStack.emit(0);
+}
 // End of file
