@@ -36,6 +36,7 @@
 #include "GraphicsCache.h"
 #include "FogMap.h"
 #include "GameScenarioOptions.h"
+#include "tilesetlist.h"
 
 OverviewMap::OverviewMap()
 {
@@ -48,7 +49,7 @@ OverviewMap::~OverviewMap()
 {
 }
 
-bool OverviewMap::isShadowed(guint32 type, int i, int j)
+bool OverviewMap::isShadowed(Tile::Type type, int i, int j)
 {
   GameMap *gm = GameMap::getInstance();
   int x = int(i / pixels_per_tile);
@@ -125,7 +126,7 @@ void OverviewMap::choose_surface(bool front, Glib::RefPtr<Gdk::Pixmap> &surf,
     }
 }
 void
-OverviewMap::draw_pixel(Glib::RefPtr<Gdk::Pixmap> surf, Glib::RefPtr<Gdk::GC> gc, int x, int y, Gdk::Color color)
+OverviewMap::draw_pixel(Glib::RefPtr<Gdk::Pixmap> surf, Glib::RefPtr<Gdk::GC> gc, int x, int y, const Gdk::Color color)
 {
   gc->set_rgb_fg_color(color);
   surf->draw_point(gc, x, y);
@@ -133,13 +134,13 @@ OverviewMap::draw_pixel(Glib::RefPtr<Gdk::Pixmap> surf, Glib::RefPtr<Gdk::GC> gc
 }
 
 void
-OverviewMap::draw_filled_rect(int x, int y, int width, int height, Gdk::Color color)
+OverviewMap::draw_filled_rect(int x, int y, int width, int height, const Gdk::Color color)
 {
   draw_filled_rect(true, x, y, width, height, color);
 }
 
 void
-OverviewMap::draw_filled_rect(bool front, int x, int y, int width, int height, Gdk::Color color)
+OverviewMap::draw_filled_rect(bool front, int x, int y, int width, int height, const Gdk::Color color)
 {
   Glib::RefPtr<Gdk::Pixmap> surf;
   Glib::RefPtr<Gdk::GC> gc;
@@ -149,7 +150,7 @@ OverviewMap::draw_filled_rect(bool front, int x, int y, int width, int height, G
 }
 
 void
-OverviewMap::draw_line(int src_x, int src_y, int dst_x, int dst_y, Gdk::Color color)
+OverviewMap::draw_line(int src_x, int src_y, int dst_x, int dst_y, const Gdk::Color color)
 {
   draw_line(true, src_x, src_y, dst_x, dst_y, color);
 }
@@ -165,13 +166,13 @@ OverviewMap::draw_line(bool front, int src_x, int src_y, int dst_x, int dst_y, G
 }
 
 void
-OverviewMap::draw_rect(int x, int y, int width, int height, Gdk::Color color)
+OverviewMap::draw_rect(int x, int y, int width, int height, const Gdk::Color color)
 {
   draw_rect (true, x, y, width, height, color);
 }
 
 void
-OverviewMap::draw_rect(bool front, int x, int y, int width, int height, Gdk::Color color)
+OverviewMap::draw_rect(bool front, int x, int y, int width, int height, const Gdk::Color color)
 {
   Glib::RefPtr<Gdk::Pixmap> surf;
   Glib::RefPtr<Gdk::GC> gc;
@@ -423,10 +424,10 @@ Maptile* OverviewMap::getTile(int x, int y)
 
 void OverviewMap::draw_terrain_tiles(Rectangle r)
 {
-    GameMap *gm = GameMap::getInstance();
     unsigned int oldrand = rand();
     srand(0);
-    Gdk::Color rd = GameMap::getInstance()->getTileset()->getRoadColor();
+    Tileset *ts = GameMap::getTileset();
+    Gdk::Color rd = ts->getRoadColor();
     for (int i = r.x; i < r.x + r.w; i+=int(map_tiles_per_tile))
       for (int j = r.y; j < r.y + r.h; j+=int(map_tiles_per_tile))
         {
@@ -448,6 +449,7 @@ void OverviewMap::after_draw()
 
 void OverviewMap::draw(Player *player)
 {
+    Tileset *ts = GameMap::getTileset();
     Playerlist::getInstance()->setViewingplayer(player);
     int size = int(pixels_per_tile) > 1 ? int(pixels_per_tile) : 1;
     assert(surface);
@@ -467,8 +469,7 @@ void OverviewMap::draw(Player *player)
 
     // Draw ruins as a white dot
 	
-    Gdk::Color ruindotcolor = Gdk::Color();
-    ruindotcolor.set_rgb_p(100,100,100);
+    Gdk::Color ruindotcolor = ts->getRuinColor();
     for (Ruinlist::iterator it = Ruinlist::getInstance()->begin();
         it != Ruinlist::getInstance()->end(); it++)
     {
@@ -485,8 +486,7 @@ void OverviewMap::draw(Player *player)
     }
 
     // Draw temples as a white dot
-    Gdk::Color templedotcolor = Gdk::Color();
-    templedotcolor.set_rgb_p(100,100,100);
+    Gdk::Color templedotcolor = ts->getTempleColor();
     for (Templelist::iterator it = Templelist::getInstance()->begin();
         it != Templelist::getInstance()->end(); it++)
     {
@@ -500,8 +500,6 @@ void OverviewMap::draw(Player *player)
     }
 
     //fog it up
-    Gdk::Color fog_color = Gdk::Color();
-    fog_color.set_rgb_p(0,0,0);
     for (int i = 0; i < GameMap::getWidth(); i++)
         for (int j = 0; j < GameMap::getHeight(); j++)
         {
@@ -511,7 +509,7 @@ void OverviewMap::draw(Player *player)
           if (Playerlist::getViewingplayer()->getFogMap()->isFogged(pos) == true)
             {
               pos = mapToSurface(pos);
-              draw_filled_rect(true, pos.x, pos.y, size, size, fog_color);
+              draw_filled_rect(true, pos.x, pos.y, size, size, FOG_COLOUR);
             }
         }
 
@@ -524,17 +522,15 @@ void OverviewMap::draw(Player *player)
 	int width = 0;
 	int height = 0;
 	surface->get_size(width, height);
-	draw_filled_rect(true, 0, 0, width, height, fog_color);
+	draw_filled_rect(true, 0, 0, width, height, FOG_COLOUR);
       }
 
   if (blank_screen)
     {
-      Gdk::Color fog_color = Gdk::Color();
-      fog_color.set_rgb_p(0.0,0.0,0.0);
       int width = 0;
       int height = 0;
       surface->get_size(width, height);
-      surface_gc->set_rgb_fg_color(fog_color);
+      surface_gc->set_rgb_fg_color(FOG_COLOUR);
       surface->draw_rectangle(surface_gc, true, 0,0,width, height);
     }
     // let derived classes do their job
@@ -557,6 +553,12 @@ Vector<int> OverviewMap::mapFromScreen(Vector<int> pos)
 
     if (y >= GameMap::getHeight())
         y = GameMap::getHeight() - 1;
+
+    if (x < 0)
+      x = 0;
+    
+    if (y < 0)
+      y = 0;
     
     return Vector<int>(x,y);
 }
@@ -629,3 +631,18 @@ void OverviewMap::draw_hero(Vector<int> pos, bool white)
     PixMask *heropic = gc->getSmallHeroPic(white);
     heropic->blit_centered(surface, start);
 }
+
+void OverviewMap::draw_target_box(Vector<int> pos, const Gdk::Color c)
+{
+  Vector<int> start = mapToSurface(pos);
+  start += Vector<int>(int(pixels_per_tile/2), int(pixels_per_tile/2));
+  int xsize = 8;
+  int ysize = 8;
+  //draw an 8 by 8 box, with a smaller box inside of it
+  draw_rect(start.x - (xsize / 2), start.y - (ysize / 2), 
+	    xsize, ysize, c);
+  xsize = 5;
+  ysize = 5;
+  draw_filled_rect(start.x - (xsize / 2), start.y - (ysize / 2), 
+		   xsize, ysize, c);
+}
