@@ -1,8 +1,8 @@
-// Copyright (C) 2008 Ben Asselstine
+// Copyright (C) 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -26,14 +26,17 @@
 #include "File.h"
 
 #include "pbm.h"
+#include "vector.h"
 
 using namespace std;
 
+int max_vector_width;
 int main(int argc, char* argv[])
 {
   srand(time(NULL));         // set the random seed
 
   initialize_configuration();
+  Vector<int>::setMaximumWidth(1000);
 
   setlocale(LC_ALL, Configuration::s_lang.c_str());
 
