@@ -3,7 +3,7 @@
 // Copyright (C) 2003 Marek Publicewicz
 // Copyright (C) 2004 John Farrell
 // Copyright (C) 2005 Bryan Duff
-// Copyright (C) 2006, 2007, 2008, 2009, 2010 Ben Asselstine
+// Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011 Ben Asselstine
 // Copyright (C) 2007, 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
@@ -61,6 +61,8 @@ class ArmyProto;
 class Item;
 class Triumphs;
 class Sage;
+class StackReflist;
+class Maptile;
 
 //! The abstract player class.
 /** 
@@ -279,7 +281,7 @@ class Player: public sigc::trackable
         int getGold() const {return d_gold;}
 
         //! Returns the name of the player.
-        std::string getName(bool translate = true) const;
+        std::string getName() const;
 
 	//! Returns the player's current score.
         guint32 getScore() const;
@@ -307,11 +309,8 @@ class Player: public sigc::trackable
 
 	//! Returns a list of the players unit production actions for this turn.
 	std::list<Action_Produce *> getUnitsProducedThisTurn() const;
-
-	//! Return the amount of gold pieces for the newly produced armies.
-	guint32 getCostOfUnitsProducedThisTurn() const;
-
-	//! Returns a list of the player's actions to show in a report.
+	
+        //! Returns a list of the player's actions to show in a report.
 	std::list<Action *> getReportableActions() const;
 
         //! Returns the number of times we fought so far this turn.
@@ -338,6 +337,9 @@ class Player: public sigc::trackable
 	//! Check to see if it's our turn.
 	bool hasAlreadyInitializedTurn() const;
 
+	//! Check to see if we've already collected from cities and paid troops
+	bool hasAlreadyCollectedTaxesAndPaidUpkeep() const;
+
 	//! Check to see if we've ended our turn this round.
 	bool hasAlreadyEndedTurn() const;
 
@@ -424,11 +426,8 @@ class Player: public sigc::trackable
 	//! Get the diplomatic score with respect to an opponent.
 	guint32 getDiplomaticScore (Player *p) const;
 
-
         void adjustDiplomacyFromConqueringCity(City *city);
 
-
-
         //! Add some gold pieces to the player's treasury.
         void addGold(int gold);
 
@@ -526,28 +525,6 @@ class Player: public sigc::trackable
 	//! Callback to adjudicate fights.
         Fight::Result stackFight(Stack** attacker, Stack** defender);
         
-        /** 
-	 * Called to adjudicate a fight between two lists of stacks in a ruin.
-         *
-         * @param attacker         The list of attacking stacks.  This list
-	 *                         consists of a single Stack containing at
-	 *                         least one Hero unit.
-         * @param defender         The list of defending stacks.  This list
-	 *                         consists of a single Army unit in a 
-	 *                         single Stack.
-         * @param stackdied        Whether or not the stack went away because
-         *                         of the searching of the ruin.
-	 *
-         *  If the defender dies in the fight, the defender pointer is set 
-	 *  to 0.
-	 *  If the Hero loses the battle, only the Hero unit is removed
-	 *  from the attacker's stack.
-         *
-         * @return One of Fight::ATTACKER_WON, Fight::DEFENDER_WON, or
-	 *         Fight::DRAW (Fight::Result).
-         */
-	//! Callback to adjudicate fights in ruins.
-        Fight::Result stackRuinFight(Stack** attacker, Stack** defender, bool &stackdied);
         /** 
 	 * A stack searches a ruin.  The stack must contain a hero.
 	 *
@@ -610,6 +587,14 @@ class Player: public sigc::trackable
         //! Callback to disband a player's stack.
         bool stackDisband(Stack* stack);
 
+        //! Recharge the player's stacks with hp and movement points.
+        void stacksReset();
+
+        //! Recharge the monsters in all of the ruins. (neutral does this)
+        void ruinsReset();
+
+        void collectTaxesAndPayUpkeep();
+
 	/**
 	 * Modifying a signpost entails changing the message on the sign.
 	 * When playing in a hidden map, the hope is that we change the
@@ -777,10 +762,11 @@ class Player: public sigc::trackable
          * @param  city    The city where the hero is emerging.
          * @param  cost    The amount of gold pieces neccessary to recruit 
 	 *                 the hero.
+         * @param stacks   Where the allies ended up (if any).
 	 * 
          * @note Only change the name and gender attributes of the Hero.
          */
-        void recruitHero(HeroProto* hero, City *city, int cost, int alliesCount, const ArmyProto *ally);
+        void recruitHero(HeroProto* hero, City *city, int cost, int alliesCount, const ArmyProto *ally, StackReflist *stacks);
 
         /** 
 	 * Called whenever a hero advances a level.
@@ -860,6 +846,9 @@ class Player: public sigc::trackable
 	//! Callback to make a mass change to vectoring.
 	bool changeVectorDestination(Vector<int> src, Vector<int> dest);
 
+        //! The player's stack takes a city.  Stack can be NULL.
+        void conquerCity(City *city, Stack *stack);
+
         /** 
 	 * Callback to have the active player occupy a given city.
 	 * The player has defeated a City and now it has been decided
@@ -996,7 +985,7 @@ class Player: public sigc::trackable
          */
 	//! Callback to change the Army unit being produced within a City.
         bool cityChangeProduction(City* city, int slot);
-
+        
 	//! A player's city produces an army unit.
 	/**
 	 * @param city  The city that has produced an army unit.
@@ -1076,6 +1065,11 @@ class Player: public sigc::trackable
 
         virtual void endTurn() = 0;
         
+        //! record the player's score for this round.
+        void reportEndOfRound(guint32 score);
+
+        //! record the player's end of turn.
+        void reportEndOfTurn();
 
         /** 
 	 * This method gives the player the specified Reward.  There are 
@@ -1092,11 +1086,15 @@ class Player: public sigc::trackable
          * @param stack            The stack which has caused the reward.
          * @param reward           A pointer for storing the Reward being 
 	 *                         given to the player.
+         * @param stacks           Where the allies ended up (if any).
 	 *
          * @return False on error, true otherwise.
          */
 	//! Callback to give a Reward to the Player or the player's Stack.
-        bool giveReward (Stack *stack, Reward *reward);
+        bool giveReward (Stack *stack, Reward *reward, StackReflist *stacks);
+
+        //! A method to make a reward, give it, and record a history item.
+        Reward* giveQuestReward(Quest *quest, Stack *stack);
 
 	//! Give the player a new name.
 	void rename (std::string name);
@@ -1107,6 +1105,24 @@ class Player: public sigc::trackable
         //! Mark the player as dead. Kills all Army units in the Stacklist.
         void kill();
 
+        //! Put the given stack into defend-mode.
+        void stackDefend(Stack *s);
+
+        //! Take the given stack out of defend-mode.
+        void stackUndefend(Stack *s);
+
+        //! Put the given stack into parked-mode.
+        void stackPark(Stack *s);
+
+        //! Take the given stack out of parked-mode.
+        void stackUnpark(Stack *s);
+
+        //! Select the given stack.
+        void stackSelect(Stack *s);
+
+        //! Deselect any and all stacks.
+        void stackDeselect();
+
 	//! Go to a temple if we're near enough.
 	/**
 	 * Helper method to take a stack on a mission to get blessed.
@@ -1188,7 +1204,7 @@ class Player: public sigc::trackable
         void resign();
 
 	//! Declare a new diplomatic state with respect to an opponent.
-	void declareDiplomacy(DiplomaticState state, Player *player);
+	void declareDiplomacy(DiplomaticState state, Player *player, bool treachery);
 
 	//! Negotiate diplomatic talks with an opponent, and return a new state.
 	DiplomaticState negotiateDiplomacy (Player *player);
@@ -1384,6 +1400,12 @@ class Player: public sigc::trackable
         //! Emitted whenever the active stack comes to a stop.
         sigc::signal<void, Stack*> shaltedStack;
 
+        //! Emitted whenever the active stack comes to a stop.
+        sigc::signal<void> sstoppingStack;
+
+        //! Emitted whenever the active stack starts moving.
+        sigc::signal<void, Stack*> smovingStack;
+
 	/**
 	 * Emitted whenever a city is conquered or razed.
 	 *
@@ -1448,6 +1470,7 @@ class Player: public sigc::trackable
         sigc::signal<void, Player*, guint32> sunk_ships;
         sigc::signal<void, Hero *, guint32> bags_picked_up;
         sigc::signal<void, Hero *, guint32> mp_added_to_hero_stack;
+        sigc::signal<void, Hero *, guint32> worms_killed;
         
 	void loadPbmGame();
 	//! Check the history to see if we ever conquered the given city.
@@ -1513,8 +1536,11 @@ class Player: public sigc::trackable
     protected:
         // do some fight cleaning up, setting
         void cleanupAfterFight(std::list<Stack*> &attackers,
-                               std::list<Stack*> &defenders);
+                               std::list<Stack*> &defenders,
+                               std::list<History*> &attacker_history,
+                               std::list<History*> &defender_history);
         
+        void clearHistorylist(std::list<History*> &history);
         //! Move stack s one step forward on it's Path.
         bool stackMoveOneStep(Stack* s);
 
@@ -1605,7 +1631,6 @@ class Player: public sigc::trackable
 	//! assists in scorekeeping for diplomacy
 	void alterDiplomaticRelationshipScore (Player *player, int amount);
 
-        void conquerCity(City *city, Stack *stack);
 
         // return the new stack if split succeeded
         Stack *doStackSplit(Stack *s);
@@ -1618,7 +1643,7 @@ class Player: public sigc::trackable
         void doCityRaze(City *c);
         void doCityBuyProduction(City *c, int slot, int type);
         void doCityChangeProduction(City *c, int slot);
-        void doGiveReward(Stack *s, Reward *reward);
+        void doGiveReward(Stack *s, Reward *reward, StackReflist *stacks);
         void doHeroDropItem(Hero *hero, Item *item, Vector<int> pos, bool &splash);
 	bool doHeroDropAllItems(Hero *h, Vector<int> pos, bool &splash);
         bool doHeroUseItem(Hero *h, Item *item, Player *victim);
@@ -1626,21 +1651,30 @@ class Player: public sigc::trackable
         bool doHeroPickupAllItems(Hero *h, Vector<int> pos);
         void doHeroGainsLevel(Hero *hero, Army::Stat stat);
         bool doStackDisband(Stack *stack);
+        void doStacksReset();
+        void doRuinsReset();
+        void doCollectTaxesAndPayUpkeep();
         void doSignpostChange(Signpost *signpost, std::string message);
         void doCityRename(City *c, std::string name);
         void doVectorFromCity(City * c, Vector<int> dest);
         void doSetFightOrder(std::list<guint32> order);
-        void doResign();
+        void doResign(std::list<History*> &history);
         void doHeroPlantStandard(Hero *hero, Item *item, Vector<int> pos);
         void doDeclareDiplomacy (DiplomaticState state, Player *player);
         void doProposeDiplomacy (DiplomaticProposal proposal, Player *player);
-        void doConquerCity(City *city, Stack *stack);
+        void doConquerCity(City *city);
 	void doLootCity(Player *looted, guint32 added, guint32 subtracted);
-        Hero* doRecruitHero(HeroProto* hero, City *city, int cost, int alliesCount, const ArmyProto *ally);
+        Hero* doRecruitHero(HeroProto* hero, City *city, int cost, int alliesCount, const ArmyProto *ally, StackReflist *stacks);
         void doRename(std::string name);
 	void doKill();
-	const Army *doCityProducesArmy(City *city, Vector<int> &pos);
-	Army *doVectoredUnitArrives(VectoredUnit *unit);
+        void doStackDefend(Stack *stack);
+        void doStackUndefend(Stack *stack);
+        void doStackPark(Stack *stack);
+        void doStackUnpark(Stack *stack);
+        void doStackSelect(Stack *stack);
+        void doStackDeselect();
+	const Army *doCityProducesArmy(City *city, Stack *& stack, bool &vectored);
+	Army *doVectoredUnitArrives(VectoredUnit *unit, Stack *& stack);
 	bool doChangeVectorDestination(Vector<int> src, Vector<int> dest,
 				       std::list<City*> &vectored);
 
@@ -1649,6 +1683,32 @@ class Player: public sigc::trackable
 
         Quest* doHeroGetQuest(Hero *hero, Temple* t, bool except_raze);
 
+        void doStackSort(Stack *s, std::list<guint32> army_ids);
+
+        void doStackSearchRuin(Stack *s, Ruin *r, Fight::Result result);
+        /** 
+	 * Called to adjudicate a fight between two lists of stacks in a ruin.
+         *
+         * @param attacker         The list of attacking stacks.  This list
+	 *                         consists of a single Stack containing at
+	 *                         least one Hero unit.
+         * @param defender         The list of defending stacks.  This list
+	 *                         consists of a single Army unit in a 
+	 *                         single Stack.
+         * @param stackdied        Whether or not the stack went away because
+         *                         of the searching of the ruin.
+	 *
+         *  If the defender dies in the fight, the defender pointer is set 
+	 *  to 0.
+	 *  If the Hero loses the battle, only the Hero unit is removed
+	 *  from the attacker's stack.
+         *
+         * @return One of Fight::ATTACKER_WON, Fight::DEFENDER_WON, or
+	 *         Fight::DRAW (Fight::Result).
+         */
+	//! Callback to adjudicate fights in ruins.
+        Fight::Result stackRuinFight(Stack** attacker, Stack** defender, bool &stackdied, std::list<History*> &attacker_history, std::list<History*> &defender_history);
+
 	void AI_maybeBuyScout(City *c);
 
 	bool AI_maybeVector(City *c, guint32 safe_mp, guint32 min_defenders,
@@ -1693,15 +1753,17 @@ class Player: public sigc::trackable
          */
 	//! Remove dead Armies from a list of stacks after a fight.
         guint32 removeDeadArmies(std::list<Stack*>& stacks,
-                                std::vector<guint32>& culprits);
+                                std::vector<guint32>& culprits, 
+                                std::list<History*> &history);
 
-        guint32 removeDeadArmies(std::list<Stack*>& stacks);
+        guint32 removeDeadArmies(std::list<Stack*>& stacks, std::list<History*> &history);
 
-        guint32 removeDeadArmies(Stack *stack);
+        guint32 removeDeadArmies(Stack *stack, std::list<History*> &history);
 
         double countXPFromDeadArmies(std::list<Stack*>& stacks);
 
-        void handleDeadHeroes(std::list<Stack*> &stacks);
+        void handleDeadHeroes(std::list<Stack*> &stacks, std::list<History*> &history);
+        History* handleDeadHero(Hero *h, Maptile *tile, Vector<int> pos);
 
         void healInjuredArmies(std::list<Stack*> &stacks);
 
