@@ -203,10 +203,9 @@ Player* Playerlist::getPlayer(string name) const
 Player* Playerlist::getPlayer(guint32 id) const
 {
   IdMap::const_iterator it = d_id.find(id);
-
   if (it == d_id.end())
     return NULL;
-  return  (*it).second;
+  return (*it).second;
 }
 
 guint32 Playerlist::getNoOfPlayers() const
@@ -311,20 +310,33 @@ bool compareDiplomaticScores (const struct rankable_t lhs,
   else
     return lhs.score < rhs.score;
 }
+
+Glib::ustring Playerlist::get_title(int rank)
+{
+  if (rank == 0)
+    return _("Statesman");
+  else if (rank == 1)
+    return _("Diplomat");
+  else if (rank == 2)
+    return _("Pragmatist");
+  else if (rank == 3)
+    return _("Politician");
+  else if (rank == 4)
+    return _("Deceiver");
+  else if (rank == 5)
+    return _("Scoundrel");
+  else if (rank == 6)
+    return _("Turncoat");
+  else if (rank == 7)
+    return _("Running Dog");
+  return _("unknown");
+}
+
 void Playerlist::calculateDiplomaticRankings()
 {
   unsigned int i = 0;
-  const char* titles[MAX_PLAYERS] =
-    {
-      _("Statesman"),
-      _("Diplomat"),
-      _("Pragmatist"),
-      _("Politician"),
-      _("Deceiver"),
-      _("Scoundrel"),
-      _("Turncoat"),
-      _("Running Dog"),
-    };
+  int used_titles[MAX_PLAYERS];
+  memset (used_titles, 0, sizeof (used_titles));
 
   //determine the rank for each player
   //add up the scores for all living players, and sort
@@ -375,13 +387,13 @@ void Playerlist::calculateDiplomaticRankings()
       for (unsigned int j = 0; j < MAX_PLAYERS; j++)
 	{
 	  if (deplete[j] == i)
-	    titles[j] = "";
+            used_titles[j] = 1;
 	}
     }
   for (unsigned int i = 0; i < MAX_PLAYERS; i++)
     {
-      if (titles[i][0] != '\0')
-	available_titles.push_back (std::string(titles[i]));
+      if (used_titles[i] != 1)
+	available_titles.push_back (get_title(i));
     }
 
   for (const_iterator it = begin (); it != end (); it++)
@@ -431,13 +443,7 @@ void Playerlist::calculateWinners()
 	  ((float) (*it)->getStacklist()->countArmies() / 
 	   (float)total_armies) * 20.0;
 	score = (guint32) (city_component + gold_component + army_component);
-	History_Score *item = new History_Score();
-	item->fillData(score);
-	(*it)->addHistory(item);
-
-	History_GoldTotal* gold = new History_GoldTotal();
-	gold->fillData((*it)->getGold());
-	(*it)->addHistory(gold);
+        (*it)->reportEndOfRound(score);
       }
 
     return;
@@ -492,9 +498,9 @@ void Playerlist::negotiateDiplomacy()
   
 	  Player::DiplomaticState old_state = (*pit)->getDiplomaticState(*it);
 	  Player::DiplomaticState new_state = (*pit)->negotiateDiplomacy(*it);
-	  (*pit)->declareDiplomacy (new_state, (*it));
+	  (*pit)->declareDiplomacy (new_state, (*it), false);
 	  (*pit)->proposeDiplomacy (Player::NO_PROPOSAL, (*it));
-	  (*it)->declareDiplomacy (new_state, (*pit));
+	  (*it)->declareDiplomacy (new_state, (*pit), false);
 	  (*it)->proposeDiplomacy (Player::NO_PROPOSAL, (*pit));
 	  if (old_state != new_state)
 	    {
@@ -508,10 +514,6 @@ void Playerlist::negotiateDiplomacy()
 		  me->improveAlliesRelationship (them, 1, Player::AT_PEACE);
 		  //their enemies think less of me
 		  them->deteriorateAlliesRelationship (me, 1, Player::AT_WAR);
-
-		  History_DiplomacyPeace *item = new History_DiplomacyPeace();
-		  item->fillData(*it);
-		  (*pit)->addHistory(item);
 		}
 	      else if (new_state == Player::AT_WAR)
 		{
@@ -521,10 +523,6 @@ void Playerlist::negotiateDiplomacy()
 		  them->deteriorateAlliesRelationship(me, 1, Player::AT_PEACE);
 		  //their enemies view of me goes up
 		  me->improveAlliesRelationship(them, 1, Player::AT_WAR);
-
-		  History_DiplomacyWar *item = new History_DiplomacyWar();
-		  item->fillData(them);
-		  me->addHistory(item);
 		}
 	    }
 	}
@@ -535,12 +533,9 @@ void Playerlist::swap(Player *old_player, Player *new_player)
 {
   std::replace(begin(), end(), old_player, new_player);
   //point cities to the new owner
-  Citylist *clist = Citylist::getInstance();
-  clist->changeOwnership (old_player, new_player);
-  Ruinlist *rlist = Ruinlist::getInstance();
-  rlist->changeOwnership (old_player, new_player);
-  VectoredUnitlist *vlist = VectoredUnitlist::getInstance();
-  vlist->changeOwnership (old_player, new_player);
+  Citylist::getInstance()->changeOwnership (old_player, new_player);
+  Ruinlist::getInstance()->changeOwnership (old_player, new_player);
+  VectoredUnitlist::getInstance()->changeOwnership (old_player, new_player);
   AI_Analysis::changeOwnership(old_player, new_player);
   if (old_player == d_activeplayer)
     {
@@ -550,6 +545,8 @@ void Playerlist::swap(Player *old_player, Player *new_player)
   if (old_player == viewingplayer)
     viewingplayer = new_player;
   d_id[new_player->getId()] = new_player;
+  GameMap::getInstance()->clearStackPositions();
+  GameMap::getInstance()->updateStackPositions();
   /* note, we don't have to change the player associated with flag graphics
      because it's stored as an id. */
 }
@@ -664,6 +661,7 @@ void Playerlist::syncPlayer(GameParameters::Player player)
   else
     p->setName(player.name);
 
+          
   switch (player.type)
     {
     case GameParameters::Player::HUMAN:
@@ -690,13 +688,17 @@ void Playerlist::syncPlayer(GameParameters::Player player)
     case GameParameters::Player::OFF:
 	{
 	  //point owned cities to neutral
-	  Citylist *clist = Citylist::getInstance();
-	  clist->changeOwnership (p, d_neutral);
+          Citylist::getInstance()->changeOwnership (p, d_neutral);
 	  //point owned ruins to neutral
-	  Ruinlist *rlist = Ruinlist::getInstance();
-	  rlist->changeOwnership (p, d_neutral);
+          Ruinlist::getInstance()->changeOwnership (p, d_neutral);
+          //also copy over the stacks to neutral
+          p->getStacklist()->changeOwnership(p, d_neutral);
 	  //now get rid of the player entirely
+          GameMap::getInstance()->clearStackPositions();
+          if (d_id.find(p->getId()) != d_id.end())
+            d_id.erase(d_id.find(p->getId()));
 	  flErase(find(begin(), end(), p));
+          GameMap::getInstance()->updateStackPositions();
 	}
       break;
     default:
@@ -720,12 +722,14 @@ void Playerlist::syncPlayers(std::vector<GameParameters::Player> players)
 
 }
 	
-void Playerlist::turnHumansIntoNetworkPlayers()
+guint32 Playerlist::turnHumansIntoNetworkPlayers()
 {
+  guint32 count = 0;
   for (iterator i = begin(); i != end(); i++)
     {
       if ((*i)->getType() == Player::HUMAN)
 	{
+          count++;
 	  NetworkPlayer *new_p = new NetworkPlayer(**i);
 	  swap((*i), new_p);
 	  //delete *i; fixme
@@ -733,9 +737,10 @@ void Playerlist::turnHumansIntoNetworkPlayers()
 	  continue;
 	}
     }
+  return count;
 }
 
-void Playerlist::turnHumansInto(Player::Type type, int number_of_players)
+guint32 Playerlist::turnHumansInto(Player::Type type, int number_of_players)
 {
   int count = 0;
   for (iterator i = begin(); i != end(); i++)
@@ -791,6 +796,7 @@ void Playerlist::turnHumansInto(Player::Type type, int number_of_players)
 	    }
 	}
     }
+  return count;
 }
 
 std::list<guint32> given_turn_order;
@@ -817,7 +823,7 @@ bool Playerlist::inGivenOrder(const Player *lhs, const Player *rhs)
 	break;
     }
   int rhs_rank = count;
-  return lhs_rank > rhs_rank;
+  return lhs_rank < rhs_rank;
 }
 
 
@@ -940,3 +946,21 @@ guint32 Playerlist::countBlessings() const
     count += (*it)->getStacklist()->countBlessingsOnArmyUnits();
   return count;
 }
+
+void Playerlist::clearAllActions()
+{
+  for (iterator it = begin(); it != end(); it++)
+    (*it)->clearActionlist();
+}
+
+void Playerlist::syncNeutral()
+{
+  if (d_neutral == NULL)
+    return;
+  if (d_neutral->getType() == Player::AI_DUMMY)
+    return;
+  //okay, let's sync it.
+  Player *p = new AI_Dummy(*d_neutral);
+  swap(d_neutral, p);
+  d_neutral = p;
+}
