@@ -1,4 +1,4 @@
-//  Copyright (C) 2008, 2009, 2010 Ben Asselstine
+//  Copyright (C) 2008, 2009, 2010, 2011 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -270,10 +270,10 @@ bool Shieldset::save(XML_Helper *helper) const
   return retval;
 }
 
-void Shieldset::instantiateImages()
+void Shieldset::instantiateImages(bool &broken)
 {
   for (iterator it = begin(); it != end(); it++)
-    (*it)->instantiateImages(this);
+    (*it)->instantiateImages(this, broken);
 }
 
 void Shieldset::uninstantiateImages()
@@ -301,7 +301,6 @@ std::list<std::string> Shieldset::scanSystemCollection()
       std::cerr << "Couldn't find any shieldsets (*" << file_extension << 
         ") in : " << File::getShieldsetDir() << std::endl;
       std::cerr << "Please check the path settings in ~/.lordsawarrc" << std::endl;
-      std::cerr << "Exiting!" << std::endl;
       exit(-1);
     }
   return retlist;
@@ -381,9 +380,9 @@ bool Shieldset::validateShieldImages(Shield::Colour c) const
   return true;
 }
 
-void Shieldset::reload()
+void Shieldset::reload(bool &broken)
 {
-  bool broken = false;
+  broken = false;
   bool unsupported_version = false;
   ShieldsetLoader d(getConfigurationFile(), broken, unsupported_version);
   if (broken == false && d.shieldset && d.shieldset->validate())
@@ -394,7 +393,7 @@ void Shieldset::reload()
         delete *it;
       std::string basename = d_basename;
       *this = *d.shieldset;
-      instantiateImages();
+      instantiateImages(broken);
       d_basename = basename;
     }
 }
